;; Duration models autotrained by festvox
;; dur.S15.tree
(set! cmu_us_bdl::phone_durs '
((pau 0.2 0.1)
 (uh_3 0.011265 0.00686)
 (uh_2 0.019382 0.025051)
 (uh_1 0.025765 0.031819)
 (ow_3 0.031324 0.027373)
 (ow_2 0.054683 0.045769)
 (ow_1 0.036302 0.032757)
 (zh_3 0.024545 0.014435)
 (zh_2 0.051818 0.02657)
 (zh_1 0.025606 0.017667)
 (v_3 0.019553 0.017727)
 (v_2 0.021529 0.015633)
 (v_1 0.017955 0.012855)
 (ah_3 0.010185 0.009247)
 (ah_2 0.020789 0.0206)
 (ah_1 0.035171 0.037479)
 (aw_3 0.043176 0.028754)
 (aw_2 0.046762 0.033609)
 (aw_1 0.071762 0.044859)
 (g_3 0.015467 0.017955)
 (g_2 0.026456 0.022976)
 (g_1 0.03331 0.025661)
 (l_3 0.02305 0.021042)
 (l_2 0.051414 0.039511)
 (l_1 0.029086 0.033251)
 (oy_3 0.050443 0.034364)
 (oy_2 0.050886 0.028293)
 (oy_1 0.094747 0.034898)
 (f_3 0.015183 0.01192)
 (f_2 0.042725 0.034501)
 (f_1 0.037336 0.034183)
 (ay_3 0.048668 0.026339)
 (ay_2 0.03941 0.023944)
 (ay_1 0.056434 0.044571)
 (z_3 0.020469 0.022538)
 (z_2 0.037598 0.028376)
 (z_1 0.030628 0.023171)
 (iy_3 0.022783 0.025385)
 (iy_2 0.046351 0.041171)
 (iy_1 0.02913 0.034338)
 (n_3 0.017837 0.016378)
 (n_2 0.034726 0.022664)
 (n_1 0.016926 0.019256)
 (s_3 0.016584 0.014082)
 (s_2 0.054394 0.039385)
 (s_1 0.040395 0.036462)
 (b_3 0.011667 0.008941)
 (b_2 0.022425 0.027651)
 (b_1 0.032134 0.024766)
 (ax_3 0.009831 0.010695)
 (ax_2 0.01476 0.017846)
 (ax_1 0.013022 0.013797)
 (ae_3 0.016159 0.014854)
 (ae_2 0.035915 0.044649)
 (ae_1 0.036984 0.037221)
 (hh_3 0.019103 0.022468)
 (hh_2 0.01726 0.021944)
 (hh_1 0.017948 0.020016)
 (d_3 0.013556 0.014673)
 (d_2 0.016308 0.015688)
 (d_1 0.012103 0.010503)
 (jh_3 0.026667 0.017756)
 (jh_2 0.044251 0.019297)
 (jh_1 0.03471 0.023419)
 (ch_3 0.028605 0.018403)
 (ch_2 0.055632 0.023752)
 (ch_1 0.032263 0.019851)
 (th_3 0.018842 0.020411)
 (th_2 0.0417 0.034263)
 (th_1 0.037069 0.03029)
 (r_3 0.021815 0.023886)
 (r_2 0.032004 0.02978)
 (r_1 0.028054 0.032735)
 (pau_3 0.040334 0.023898)
 (p_3 0.034991 0.024273)
 (p_2 0.035379 0.019727)
 (p_1 0.019897 0.012391)
 (aa_3 0.016053 0.015168)
 (aa_2 0.034111 0.044226)
 (aa_1 0.037852 0.053005)
 (sh_3 0.01824 0.011295)
 (sh_2 0.07176 0.030046)
 (sh_1 0.029338 0.02629)
 (ao_3 0.025861 0.023468)
 (ao_2 0.051283 0.061166)
 (ao_1 0.027537 0.031742)
 (t_3 0.023229 0.021442)
 (t_2 0.007277 0.005296)
 (t_1 0.025058 0.021325)
 (pau_5 0.026011 0.0288)
 (eh_3 0.017041 0.019402)
 (eh_2 0.035112 0.034817)
 (eh_1 0.023261 0.023216)
 (dh_3 0.017487 0.024073)
 (dh_2 0.013961 0.01043)
 (dh_1 0.022099 0.021933)
 (ng_3 0.03281 0.028258)
 (ng_2 0.039049 0.02711)
 (ng_1 0.030014 0.024363)
 (ih_3 0.014015 0.014403)
 (ih_2 0.022461 0.023911)
 (ih_1 0.014257 0.019242)
 (k_3 0.038292 0.024005)
 (k_2 0.019513 0.019114)
 (k_1 0.029167 0.020509)
 (ey_3 0.026337 0.029893)
 (ey_2 0.054688 0.035102)
 (ey_1 0.048396 0.038656)
 (m_3 0.016993 0.02024)
 (m_2 0.028966 0.023793)
 (m_1 0.023818 0.023051)
 (er_3 0.025873 0.028208)
 (er_2 0.039723 0.038806)
 (er_1 0.042471 0.045591)
 (w_3 0.019798 0.014282)
 (w_2 0.023164 0.022226)
 (w_1 0.036371 0.031624)
 (uw_3 0.029241 0.037042)
 (uw_2 0.032792 0.036)
 (uw_1 0.02639 0.030334)
 (y_3 0.02 0.019547)
 (y_2 0.040677 0.03355)
 (y_1 0.018609 0.017982)
 (pau_2 0.014428 0.017833)
 (pau_1 0.026014 0.023734))
)


(set! cmu_us_bdl::zdur_tree '
((name is pau)
 ((p.R:SylStructure.parent.parent.pbreak is BB)
  ((0.0 2.0))
  ((0.0 0.0)))
((R:segstate.parent.R:SylStructure.parent.lisp_cg_break < 1.2)
 ((p.name is 0)
  ((R:segstate.parent.n.name is pau)
   ((R:segstate.parent.nn.ph_cplace is a)
    ((0.404445 -0.548327))
    ((R:segstate.parent.nn.ph_cplace is d)
     ((0.415814 -0.50356))
     ((0.529929 -0.321859))))
   ((R:segstate.parent.n.seg_onsetcoda is coda)
    ((R:segstate.parent.n.name is ay)
     ((R:segstate.parent.nn.ph_cplace is a)
      ((0.44037 1.06328))
      ((R:segstate.parent.nn.ph_cplace is 0)
       ((0.229167 1.14229))
       ((0.228993 1.15646))))
     ((R:segstate.parent.n.name is ax)
      ((0.161645 1.16383))
      ((R:segstate.parent.nn.ph_cplace is a)
       ((R:segstate.parent.n.name is ae)
        ((0.23286 1.23445))
        ((R:segstate.parent.n.name is ih)
         ((0.153687 1.20022))
         ((0.161817 1.12859))))
       ((0.183101 1.26917)))))
    ((R:segstate.parent.n.name is f)
     ((0.737666 0.0580309))
     ((R:segstate.parent.n.name is y)
      ((0.953681 0.231145))
      ((R:segstate.parent.n.name is hh)
       ((R:segstate.parent.nn.ph_vlng is l)
        ((0.414939 0.546067))
        ((0.362454 0.597084)))
       ((R:segstate.parent.n.name is b)
        ((0.617525 0.498995))
        ((R:segstate.parent.n.name is w)
         ((R:segstate.parent.nn.ph_vlng is s)
          ((0.338602 1.05275))
          ((0.782665 0.708355)))
         ((R:segstate.parent.n.name is s)
          ((0.589441 0.619377))
          ((R:segstate.parent.nn.ph_vrnd is +)
           ((0.449122 0.845093))
           ((R:segstate.parent.n.name is n)
            ((0.805854 0.465359))
            ((R:segstate.parent.nn.ph_vlng is l)
             ((0.379152 0.852617))
             ((R:segstate.parent.n.name is m)
              ((0.831628 0.510281))
              ((R:segstate.parent.nn.ph_vlng is d)
               ((0.50581 0.923872))
               ((R:segstate.parent.nn.ph_vlng is s)
                ((R:segstate.parent.n.name is dh)
                 ((0.456914 0.804631))
                 ((0.593947 0.823357)))
                ((R:segstate.parent.n.name is dh)
                 ((0.592672 0.778263))
                 ((0.661768 0.514928)))))))))))))))))
  ((R:segstate.parent.p.name is ax)
   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
     <
     0.3)
    ((name is l_1)
     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
       is
       0)
      ((R:segstate.parent.pp.ph_cplace is l)
       ((0.309564 -0.624122))
       ((R:segstate.parent.R:SylStructure.parent.syl_in < 10)
        ((0.972229 -0.0638089))
        ((0.345742 -0.542341))))
      ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 6)
       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
         is
         0)
        ((0.176326 -0.630387))
        ((0.0364703 -0.715524)))
       ((0.316101 -0.521695))))
     ((name is z_1)
      ((1.54482 1.51748))
      ((name is l_2)
       ((R:segstate.parent.pp.ph_vc is +)
        ((0.5983 0.132943))
        ((R:segstate.parent.pp.ph_ctype is f)
         ((0.753105 0.95128))
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
           is
           0)
          ((R:segstate.parent.pp.ph_cplace is a)
           ((0.592915 0.554765))
           ((0.617096 1.0808)))
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
            is
            0)
           ((0.591692 0.699391))
           ((0.59252 0.343854))))))
       ((R:segstate.parent.lisp_onset_stop is 0)
        ((name is p_1)
         ((0.955573 1.2794))
         ((name is p_3)
          ((0.435118 -0.92168))
          ((name is p_2)
           ((0.619165 -0.88328))
           ((R:segstate.parent.lisp_coda_glide is 0)
            ((R:segstate.parent.ph_ctype is r)
             ((R:segstate.parent.nn.ph_vc is +)
              ((1.65294 0.95554))
              ((1.32831 0.557124)))
             ((R:segstate.parent.n.name is z)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                is
                0)
               ((1.44948 0.690998))
               ((0.7376 0.121709)))
              ((R:segstate.parent.R:SylStructure.parent.position_type
                is
                initial)
               ((1.54646 0.663416))
               ((R:segstate.parent.lisp_coda_fric is 0)
                ((name is m_3)
                 ((0.391821 -0.382102))
                 ((R:segstate.parent.ph_cplace is l)
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    2.7)
                   ((1.00834 0.479827))
                   ((name is m_2)
                    ((0.985342 0.488473))
                    ((0.972931 -0.0176593))))
                  ((R:segstate.parent.pp.ph_cplace is v)
                   ((0.573267 -0.490714))
                   ((R:segstate.parent.n.name is f)
                    ((0.339134 -0.467623))
                    ((R:segstate.parent.ph_ctype is s)
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       4.6)
                      ((0.942577 -0.073845))
                      ((0.291331 -0.501628)))
                     ((R:segstate.parent.n.name is hh)
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        1.8)
                       ((0.442828 -0.382107))
                       ((0.498599 -0.147815)))
                      ((R:segstate.parent.nn.ph_vlng is a)
                       ((1.00997 -0.365113))
                       ((name is n_3)
                        ((R:segstate.parent.n.name is t)
                         ((0.773628 0.426049))
                         ((R:segstate.parent.nn.ph_vlng is s)
                          ((1.23986 0.344442))
                          ((R:segstate.parent.n.name is pau)
                           ((0.62919 -0.0569204))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                             is
                             0)
                            ((0.335385 -0.562724))
                            ((R:segstate.parent.R:SylStructure.parent.syl_in
                              <
                              5)
                             ((0.691043 -0.437804))
                             ((0.531932 -0.258021)))))))
                        ((R:segstate.parent.n.name is t)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                           is
                           0)
                          ((0.333226 -0.443951))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                            is
                            0)
                           ((0.698842 -0.218988))
                           ((0.607659 -0.006313))))
                         ((name is n_2)
                          ((R:segstate.parent.R:SylStructure.parent.asyl_out
                            <
                            3.6)
                           ((R:segstate.parent.R:SylStructure.parent.asyl_out
                             <
                             1.2)
                            ((1.06695 0.570115))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                              <
                              0.3)
                             ((0.647227 -0.383178))
                             ((R:segstate.parent.n.name is pau)
                              ((0.764229 0.0120889))
                              ((0.929079 0.427363)))))
                           ((1.1321 0.850424)))
                          ((R:segstate.parent.n.seg_onsetcoda is onset)
                           ((R:segstate.parent.lisp_onset_glide is 0)
                            ((R:segstate.parent.nn.ph_vrnd is -)
                             ((name is n_1)
                              ((0.312671 -0.457052))
                              ((0.831646 -0.0930251)))
                             ((0.431556 -0.397697)))
                            ((1.14675 0.32707)))
                           ((p.name is ax_3)
                            ((R:segstate.parent.R:SylStructure.parent.asyl_out
                              <
                              2.4)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                               <
                               0.3)
                              ((R:segstate.parent.nn.ph_cplace is a)
                               ((0.741946 0.206505))
                               ((1.3442 0.881227)))
                              ((0.94425 0.22187)))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                               <
                               0.2)
                              ((0.452271 -0.391794))
                              ((R:segstate.parent.pos_in_syl is 2)
                               ((1.11119 0.322928))
                               ((0.728738 0.184962)))))
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                              <
                              4.4)
                             ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                               <
                               1.2)
                              ((0.752452 -0.383278))
                              ((R:segstate.parent.pp.ph_cplace is a)
                               ((R:segstate.parent.ph_cplace is a)
                                ((0.586862 -0.386156))
                                ((0.753741 -0.0696469)))
                               ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                 <
                                 1.2)
                                ((0.742098 0.442202))
                                ((1.36182 0.000661046)))))
                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                               <
                               10.2)
                              ((1.03618 0.408324))
                              ((1.0118 0.285592))))))))))))))))
                ((R:segstate.parent.n.name is s)
                 ((1.23504 0.177142))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                   <
                   0.3)
                  ((name is s_1)
                   ((0.175201 -0.640014))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     1.2)
                    ((R:segstate.parent.pos_in_syl is 0)
                     ((0.655832 -0.0929316))
                     ((0.317137 -0.644643)))
                    ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                      <
                      2.2)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       4.1)
                      ((0.548019 -0.0834284))
                      ((0.699831 0.0857184)))
                     ((0.494187 -0.342582)))))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    4.2)
                   ((name is s_2)
                    ((0.684309 -0.282674))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       3.7)
                      ((0.603564 -0.0111175))
                      ((0.813639 0.4681)))
                     ((R:segstate.parent.pp.ph_cplace is a)
                      ((1.40752 0.140716))
                      ((0.855454 -0.338863)))))
                   ((0.665014 -0.355069)))))))))
            ((R:segstate.parent.ph_ctype is f)
             ((0.821072 0.130398))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
               <
               0.2)
              ((0.778715 -0.216925))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 3.7)
               ((0.158267 -0.767196))
               ((0.578538 -0.428293)))))))))
        ((name is l_3)
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
           is
           0)
          ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.2)
           ((0.390104 -0.493458))
           ((0.196767 -0.76276)))
          ((0.632051 -0.290161)))
         ((name is k_2)
          ((0.383351 -0.510153))
          ((name is b_2)
           ((0.142111 -0.566356))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
             <
             0.3)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
              is
              0)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
               is
               0)
              ((R:segstate.parent.n.seg_onsetcoda is coda)
               ((R:segstate.parent.pp.ph_cplace is a)
                ((0.916785 0.235095))
                ((0.829072 0.812359)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                 is
                 0)
                ((1.02667 0.520569))
                ((1.11567 0.890162))))
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 6.9)
               ((1.32454 0.318104))
               ((0.950352 -0.236949))))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
               <
               0.2)
              ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                <
                3.2)
               ((0.494608 -0.156754))
               ((0.447193 -0.450441)))
              ((p.name is ax_3)
               ((R:segstate.parent.nn.ph_cplace is a)
                ((0.72305 0.610171))
                ((0.729183 -0.0580275)))
               ((R:segstate.parent.n.name is ax)
                ((0.311708 -0.440419))
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  1.5)
                 ((0.659994 -0.144945))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                   is
                   0)
                  ((1.15548 0.491305))
                  ((0.797083 0.0437976))))))))
            ((name is d_3)
             ((R:segstate.parent.R:SylStructure.parent.syl_out < 3.6)
              ((0.843848 0.238725))
              ((0.690815 -0.230179)))
             ((name is g_2)
              ((0.943093 -0.295497))
              ((R:segstate.parent.n.name is eh)
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 7)
                ((1.6678 1.67586))
                ((0.708917 0.940601)))
               ((R:segstate.parent.n.name is aa)
                ((0.805466 -0.064065))
                ((R:segstate.parent.pp.ph_ctype is r)
                 ((R:segstate.parent.lisp_coda_stop is 0)
                  ((0.581568 -0.0833754))
                  ((0.756427 0.227719)))
                 ((name is n_3)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    4.5)
                   ((0.980548 -0.101388))
                   ((1.13526 0.254181)))
                  ((R:segstate.parent.nn.ph_vrnd is -)
                   ((p.name is ax_3)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                      is
                      0)
                     ((0.732978 0.358849))
                     ((0.557873 -0.217957)))
                    ((R:segstate.parent.ph_ctype is s)
                     ((0.962925 0.887358))
                     ((1.22534 0.352355))))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                     <
                     1.2)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                       is
                       0)
                      ((p.name is ax_3)
                       ((0.766278 1.22936))
                       ((0.628473 0.565598)))
                      ((0.888686 0.3974)))
                     ((R:segstate.parent.R:SylStructure.parent.position_type
                       is
                       final)
                      ((R:segstate.parent.syl_final is 0)
                       ((1.04562 1.04593))
                       ((2.19262 1.54545)))
                      ((0.489883 0.805931))))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      5.8)
                     ((1.20861 0.324485))
                     ((1.2486 0.346461)))))))))))))))))))
    ((name is t_3)
     ((0.602681 2.4246))
     ((name is r_1)
      ((1.06456 2.03745))
      ((p.name is ax_3)
       ((name is hh_1)
        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
          <
          0.3)
         ((0.436887 -0.397083))
         ((0.153774 -0.596923)))
        ((R:segstate.parent.n.name is t)
         ((R:segstate.parent.nn.ph_vrnd is -)
          ((0.981821 -0.15734))
          ((0.242063 -0.748867)))
         ((name is l_1)
          ((R:segstate.parent.R:SylStructure.parent.syl_in < 5.5)
           ((0.505213 -0.179273))
           ((0.252047 -0.523874)))
          ((R:segstate.parent.ph_ctype is n)
           ((name is m_1)
            ((R:segstate.parent.pp.ph_ctype is f)
             ((1.16116 0.563186))
             ((0.836347 -0.111407)))
            ((0.662239 -0.299759)))
           ((R:segstate.parent.ph_vheight is 2)
            ((R:segstate.parent.nn.ph_cplace is 0)
             ((1.5376 0.523355))
             ((0.768954 -0.366139)))
            ((R:segstate.parent.nn.ph_vrnd is -)
             ((R:segstate.parent.lisp_onset_stop is 0)
              ((R:segstate.parent.nn.ph_vlng is s)
               ((0.497982 -0.150847))
               ((0.992066 0.440426)))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                <
                0.3)
               ((0.782252 0.497832))
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 4.6)
                ((0.693864 0.857462))
                ((0.770617 1.39947)))))
             ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
               <
               3.5)
              ((R:segstate.parent.lisp_onset_stop is 0)
               ((name is f_1)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                  is
                  0)
                 ((1.03938 1.15346))
                 ((0.996654 0.478256)))
                ((R:segstate.parent.lisp_coda_stop is 0)
                 ((R:segstate.parent.ph_cplace is p)
                  ((1.22077 0.5201))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    1.2)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     3)
                    ((1.01744 0.571617))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      2.4)
                     ((1.66244 2.03694))
                     ((1.30755 1.10149))))
                   ((1.00132 1.82011))))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   1.8)
                  ((2.00211 2.23133))
                  ((1.47173 1.9247)))))
               ((name is b_1)
                ((0.628287 1.41756))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                  is
                  0)
                 ((0.855481 0.923975))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                   <
                   0.3)
                  ((0.67133 0.153757))
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    2.5)
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     6.5)
                    ((1.05398 0.463451))
                    ((0.835751 0.744846)))
                   ((0.735546 0.955852)))))))
              ((0.717555 0.301299)))))))))
       ((name is l_2)
        ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 1.2)
         ((0.777837 1.19594))
         ((0.399843 1.62514)))
        ((name is d_3)
         ((1.00867 1.63995))
         ((name is d_2)
          ((1.10787 1.48248))
          ((name is hh_3)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
             is
             0)
            ((1.56669 1.4447))
            ((1.73273 0.70754)))
           ((name is k_3)
            ((R:segstate.parent.pp.ph_ctype is f)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
               is
               0)
              ((0.502889 1.46409))
              ((0.735983 0.879807)))
             ((1.05439 0.279441)))
            ((name is p_3)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 1.8)
              ((0.819782 1.26378))
              ((0.639206 0.656964)))
             ((name is m_2)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 2.7)
               ((1.21491 0.427203))
               ((1.08101 1.12046)))
              ((name is w_2)
               ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 1.6)
                ((2.35154 1.76232))
                ((1.12691 0.199587)))
               ((R:segstate.parent.ph_cplace is l)
                ((name is p_2)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   2.7)
                  ((0.74329 0.424342))
                  ((0.861124 -0.120596)))
                 ((R:segstate.parent.nn.ph_vlng is s)
                  ((0.795723 0.0695721))
                  ((R:segstate.parent.nn.ph_cplace is v)
                   ((0.25541 -0.610045))
                   ((R:segstate.parent.lisp_onset_nasal is 0)
                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                      <
                      2.1)
                     ((R:segstate.parent.lisp_onset_glide is 0)
                      ((R:segstate.parent.nn.ph_cplace is a)
                       ((0.488052 -0.0957275))
                       ((0.288163 -0.458066)))
                      ((0.644383 0.125352)))
                     ((0.739449 -0.472613)))
                    ((R:segstate.parent.R:SylStructure.parent.last_accent
                      <
                      1.8)
                     ((0.0970736 -0.548946))
                     ((0.139545 -0.501045)))))))
                ((R:segstate.parent.R:SylStructure.parent.last_accent
                  <
                  3.6)
                 ((R:segstate.parent.ph_cplace is p)
                  ((R:segstate.parent.nn.ph_cplace is a)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     3.4)
                    ((1.15514 0.893377))
                    ((1.02033 0.325209)))
                   ((0.971776 0.168327)))
                  ((R:segstate.parent.n.ph_vc is +)
                   ((name is s_2)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                      <
                      0.3)
                     ((1.0123 -0.222649))
                     ((0.697248 -0.930982)))
                    ((R:segstate.parent.n.name is ih)
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       1.7)
                      ((0.927417 -0.157996))
                      ((1.51068 0.897442)))
                     ((R:segstate.parent.lisp_onset_glide is 0)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                        is
                        0)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         8.5)
                        ((R:segstate.parent.n.name is eh)
                         ((0.554654 0.226598))
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                           <
                           6)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                            <
                            0.2)
                           ((0.579369 -0.446612))
                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                             <
                             5.5)
                            ((0.612054 -0.0054209))
                            ((0.593631 -0.21314))))
                          ((R:segstate.parent.R:SylStructure.parent.last_accent
                            <
                            1.2)
                           ((0.916419 0.206172))
                           ((0.935102 -0.109462)))))
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          10.4)
                         ((1.97624 0.899451))
                         ((1.10951 -0.104276))))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         4.8)
                        ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                          <
                          1.2)
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           4.5)
                          ((0.62258 -0.304268))
                          ((0.736587 -0.0267729)))
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           3.3)
                          ((0.373427 -0.354842))
                          ((0.266173 -0.544742))))
                        ((0.674783 0.0429629))))
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        2.1)
                       ((0.310863 -0.565856))
                       ((0.4337 -0.277009))))))
                   ((R:segstate.parent.ph_ctype is s)
                    ((R:segstate.parent.n.name is r)
                     ((0.835123 -0.00895574))
                     ((0.445333 -0.462105)))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      6)
                     ((R:segstate.parent.lisp_coda_stop is 0)
                      ((name is s_2)
                       ((0.702021 0.603374))
                       ((R:segstate.parent.pos_in_syl is 0)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                          is
                          0)
                         ((R:segstate.parent.R:SylStructure.parent.last_accent
                           <
                           1.2)
                          ((0.842521 0.105358))
                          ((1.67379 0.564509)))
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           4.8)
                          ((0.817882 -0.120601))
                          ((0.354829 -0.433728))))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          1.5)
                         ((0.892375 0.352141))
                         ((1.40069 0.65501)))))
                      ((3.54402 1.17721)))
                     ((R:segstate.parent.n.seg_onsetcoda is coda)
                      ((0.476972 -0.474399))
                      ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                        <
                        0.3)
                       ((0.682117 -0.0724296))
                       ((0.721336 0.254939))))))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                   <
                   0.3)
                  ((R:segstate.parent.pp.ph_ctype is f)
                   ((0.645172 -0.395357))
                   ((0.975796 0.253967)))
                  ((R:segstate.parent.nn.ph_cplace is 0)
                   ((R:segstate.parent.n.seg_onsetcoda is coda)
                    ((2.97271 1.47397))
                    ((1.91433 0.693588)))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                     is
                     0)
                    ((1.01097 0.0122862))
                    ((1.39789 0.604582)))))))))))))))))))
   ((name is pau_1)
    ((p.name is pau_3)
     ((R:segstate.parent.pp.ph_vc is 0)
      ((0.700218 -0.544315))
      ((R:segstate.parent.pp.ph_cplace is a)
       ((2.21619 1.53729))
       ((4.68151 2.8013))))
     ((p.name is pau_2)
      ((R:segstate.parent.pp.ph_vc is 0)
       ((R:segstate.parent.nn.ph_vrnd is -)
        ((0.434386 -0.341736))
        ((0.531297 -0.439275)))
       ((R:segstate.parent.n.seg_onsetcoda is coda)
        ((R:segstate.parent.pp.ph_ctype is 0)
         ((0.831073 0.31278))
         ((1.12782 0.541402)))
        ((1.5659 0.957951))))
      ((R:segstate.parent.pp.ph_cplace is p)
       ((R:segstate.parent.n.name is 0)
        ((0.826978 0.266258))
        ((1.09857 0.0392032)))
       ((R:segstate.parent.n.name is ax)
        ((1.38031 0.260112))
        ((p.name is t_3)
         ((R:segstate.parent.n.ph_vc is +)
          ((0.715687 -0.617273))
          ((R:segstate.parent.pp.ph_vfront is 1)
           ((R:segstate.parent.n.name is 0)
            ((0.62981 -0.216215))
            ((1.16591 0.0231094)))
           ((R:segstate.parent.n.seg_onsetcoda is onset)
            ((0.728377 -0.604505))
            ((R:segstate.parent.pp.ph_ctype is n)
             ((0.495558 0.00994374))
             ((R:segstate.parent.pp.ph_vfront is 2)
              ((0.504433 -0.183169))
              ((R:segstate.parent.pp.ph_ctype is f)
               ((0.540833 -0.342094))
               ((0.608861 -0.323615))))))))
         ((R:segstate.parent.n.seg_onsetcoda is onset)
          ((p.name is s_3)
           ((1.00069 -0.244614))
           ((R:segstate.parent.nn.ph_vlng is a)
            ((R:segstate.parent.n.name is t)
             ((0.309278 -0.769528))
             ((R:segstate.parent.pp.ph_ctype is 0)
              ((0.684764 -0.522579))
              ((1.68836 0.0231099))))
            ((R:segstate.parent.pp.ph_cplace is a)
             ((R:segstate.parent.pp.ph_ctype is s)
              ((0.27111 -0.729685))
              ((R:segstate.parent.p.ph_vc is +)
               ((0.122692 -0.81887))
               ((0.178857 -0.776161))))
             ((p.name is d_3)
              ((0.161127 -0.82128))
              ((R:segstate.parent.n.name is dh)
               ((0.328507 -0.737928))
               ((p.name is n_3)
                ((R:segstate.parent.pp.ph_vfront is 2)
                 ((0.333096 -0.639616))
                 ((0.316879 -0.766895)))
                ((R:segstate.parent.pp.ph_vlng is d)
                 ((0.285615 -0.77304))
                 ((R:segstate.parent.pp.ph_vlng is l)
                  ((0.624267 -0.309569))
                  ((R:segstate.parent.nn.ph_vrnd is +)
                   ((0.879503 -0.398227))
                   ((R:segstate.parent.p.ph_vc is +)
                    ((0.292607 -0.687894))
                    ((R:segstate.parent.pp.ph_vfront is 1)
                     ((0.496833 -0.57441))
                     ((0.415487 -0.563198)))))))))))))
          ((R:segstate.parent.n.name is ih)
           ((R:segstate.parent.pp.ph_vc is +)
            ((0.153852 -0.815173))
            ((0.405373 -0.686433)))
           ((p.name is s_3)
            ((R:segstate.parent.pp.ph_vfront is 1)
             ((0.214785 -0.727395))
             ((R:segstate.parent.pp.ph_ctype is n)
              ((0.217576 -0.660682))
              ((R:segstate.parent.pp.ph_cplace is a)
               ((0.428845 -0.581097))
               ((R:segstate.parent.pp.ph_vfront is 2)
                ((0.667942 -0.569395))
                ((0.223329 -0.702817))))))
            ((R:segstate.parent.pp.ph_ctype is r)
             ((p.name is d_3)
              ((0.153249 -0.766894))
              ((p.name is z_3)
               ((0.247029 -0.674728))
               ((R:segstate.parent.p.ph_vc is +)
                ((0.507632 -0.564815))
                ((0.407827 -0.474091)))))
             ((R:segstate.parent.n.name is pau)
              ((R:segstate.parent.nn.ph_vc is +)
               ((0.870109 -0.265784))
               ((1.1348 -0.0708125)))
              ((p.name is n_3)
               ((R:segstate.parent.n.name is 0)
                ((R:segstate.parent.pp.ph_vlng is a)
                 ((0.411484 -0.177767))
                 ((R:segstate.parent.pp.ph_vlng is s)
                  ((0.498334 -0.402098))
                  ((0.557377 -0.295526))))
                ((0.522315 -0.569395)))
               ((p.name is iy_3)
                ((R:segstate.parent.pp.ph_ctype is l)
                 ((0.423767 -0.516728))
                 ((R:segstate.parent.pp.ph_cplace is a)
                  ((0.379037 -0.601451))
                  ((0.476865 -0.646639))))
                ((R:segstate.parent.pp.ph_ctype is l)
                 ((0.696838 -0.191431))
                 ((p.name is k_3)
                  ((0.737656 -0.263925))
                  ((R:segstate.parent.pp.ph_vrnd is +)
                   ((R:segstate.parent.pp.ph_vlng is d)
                    ((0.234841 -0.600375))
                    ((0.354442 -0.5393)))
                   ((R:segstate.parent.p.ph_vlng is d)
                    ((R:segstate.parent.pp.ph_cplace is a)
                     ((0.443966 -0.625159))
                     ((0.401826 -0.450015)))
                    ((p.name is z_3)
                     ((R:segstate.parent.pp.ph_vc is +)
                      ((0.184477 -0.610612))
                      ((R:segstate.parent.pp.ph_cplace is a)
                       ((0.427104 -0.439274))
                       ((0.540592 -0.430795))))
                     ((R:segstate.parent.pp.ph_ctype is f)
                      ((0.346804 -0.523047))
                      ((R:segstate.parent.nn.ph_cplace is a)
                       ((R:segstate.parent.pp.ph_vfront is 1)
                        ((0.220472 -0.744951))
                        ((0.478392 -0.425047)))
                       ((p.name is d_3)
                        ((R:segstate.parent.pp.ph_vfront is 1)
                         ((0.33173 -0.552763))
                         ((R:segstate.parent.pp.ph_ctype is n)
                          ((0.509169 -0.423547))
                          ((0.453403 -0.502364))))
                        ((R:segstate.parent.pp.ph_vlng is a)
                         ((0.284084 -0.537792))
                         ((R:segstate.parent.pp.ph_ctype is s)
                          ((0.398991 -0.516725))
                          ((p.name is l_3)
                           ((0.473306 -0.474091))
                           ((p.name is r_3)
                            ((0.408046 -0.440653))
                            ((R:segstate.parent.pp.ph_vlng is d)
                             ((0.475877 -0.37043))
                             ((R:segstate.parent.pp.ph_vfront is 1)
                              ((p.name is ng_3)
                               ((0.522724 -0.32923))
                               ((p.name is m_3)
                                ((0.688955 -0.361918))
                                ((0.593942 -0.317508))))
                              ((0.659731 -0.220128))))))))))))))))))))))))))))
    ((R:segstate.parent.p.ph_vheight is 1)
     ((name is p_1)
      ((R:segstate.parent.pp.ph_ctype is r)
       ((0.586298 0.81535))
       ((R:segstate.parent.lisp_coda_stop is 0)
        ((0.504397 0.941449))
        ((1.19573 1.51478))))
      ((name is dh_1)
       ((R:segstate.parent.n.ph_vc is +)
        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
          <
          0.3)
         ((0.783629 0.869808))
         ((0.484891 1.43252)))
        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
          <
          2.5)
         ((R:segstate.parent.R:SylStructure.parent.last_accent < 0.3)
          ((0.783132 -0.239678))
          ((1.26477 0.755377)))
         ((0.866788 0.861762))))
       ((R:segstate.parent.nn.ph_vc is 0)
        ((p.name is pau_2)
         ((0.36181 -0.482236))
         ((R:segstate.parent.p.name is iy)
          ((R:segstate.parent.pp.ph_ctype is l)
           ((0.934349 0.733022))
           ((R:segstate.parent.pp.ph_cplace is a)
            ((1.28323 1.19269))
            ((0.897723 1.60531))))
          ((0.673057 0.465473))))
        ((name is r_3)
         ((R:segstate.parent.p.name is ih)
          ((R:segstate.parent.nn.ph_cplace is 0)
           ((1.91707 1.94448))
           ((1.44313 0.731421)))
          ((R:segstate.parent.R:SylStructure.parent.syl_in < 3.9)
           ((0.648262 -0.197176))
           ((0.948157 0.159508))))
         ((name is m_3)
          ((R:segstate.parent.n.ph_vc is +)
           ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 2.7)
            ((0.929836 -0.124023))
            ((R:segstate.parent.R:SylStructure.parent.syl_out < 9)
             ((0.104185 -0.538837))
             ((0.197583 -0.461756))))
           ((R:segstate.parent.R:SylStructure.parent.syl_out < 5.5)
            ((1.27326 2.06041))
            ((R:segstate.parent.R:SylStructure.parent.asyl_out < 3.5)
             ((1.13053 0.860029))
             ((1.14351 1.56577)))))
          ((name is n_2)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
             <
             0.3)
            ((R:segstate.parent.syl_final is 0)
             ((1.01208 0.208191))
             ((0.549841 -0.366106)))
            ((R:segstate.parent.nn.ph_vlng is a)
             ((R:segstate.parent.R:SylStructure.parent.syl_out < 4.8)
              ((0.781667 -0.412167))
              ((R:segstate.parent.pp.ph_ctype is 0)
               ((1.08869 0.173874))
               ((0.612998 0.518204))))
             ((R:segstate.parent.R:SylStructure.parent.position_type
               is
               initial)
              ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.5)
               ((0.390694 1.02849))
               ((0.522549 0.64798)))
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 2.2)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                 <
                 1.2)
                ((0.76095 0.568421))
                ((0.836017 1.08921)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  2.2)
                 ((0.985083 -0.196269))
                 ((0.780898 0.549836)))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  1.8)
                 ((0.83323 1.00485))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                   is
                   0)
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    6.3)
                   ((1.02626 0.336522))
                   ((0.607047 0.673933)))
                  ((0.771458 0.163036)))))))))
           ((p.name is ih_3)
            ((name is r_1)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 3)
              ((0.837335 -0.390739))
              ((0.0400587 -0.693351)))
             ((name is g_1)
              ((R:segstate.parent.R:SylStructure.parent.position_type
                is
                single)
               ((1.119 1.71557))
               ((0.616164 0.455554)))
              ((R:segstate.parent.pp.ph_ctype is 0)
               ((R:segstate.parent.syl_final is 0)
                ((0.976719 0.505589))
                ((R:segstate.parent.n.name is w)
                 ((0.470399 -0.557342))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   1.8)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    4.5)
                   ((name is t_1)
                    ((0.362513 -0.493983))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      5.5)
                     ((0.487707 -0.107972))
                     ((0.330315 -0.507284))))
                   ((1.17862 0.0901521)))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    7.8)
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     5)
                    ((0.682341 -0.0782027))
                    ((0.850795 0.711546)))
                   ((name is n_1)
                    ((0.457613 -0.350728))
                    ((0.966678 0.176639)))))))
               ((name is z_1)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                  <
                  0.3)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   5)
                  ((1.18135 1.35393))
                  ((0.778206 0.552115)))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   4.4)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    5)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     2.4)
                    ((1.00905 0.645156))
                    ((0.766572 -0.0725318)))
                   ((R:segstate.parent.nn.ph_vc is +)
                    ((0.880191 0.821661))
                    ((0.462813 0.566312))))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    6.2)
                   ((0.587913 -0.0646302))
                   ((0.608906 0.256118)))))
                ((R:segstate.parent.pp.ph_ctype is s)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6)
                  ((R:segstate.parent.R:SylStructure.parent.position_type
                    is
                    mid)
                   ((0.901107 0.711027))
                   ((R:segstate.parent.pp.ph_cplace is a)
                    ((R:segstate.parent.pos_in_syl is 0)
                     ((0.520068 -0.30719))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       1.4)
                      ((R:segstate.parent.R:SylStructure.parent.sub_phrases
                        <
                        0.2)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                         is
                         0)
                        ((R:segstate.parent.R:SylStructure.parent.position_type
                          is
                          final)
                         ((0.688098 0.308955))
                         ((R:segstate.parent.ph_ctype is s)
                          ((0.738858 0.0464948))
                          ((0.470692 -0.142505))))
                        ((0.371594 -0.288904)))
                       ((0.630774 0.404442)))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        5.2)
                       ((0.755905 0.18346))
                       ((0.968393 0.718324)))))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_in
                      <
                      1.2)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                       <
                       0.3)
                      ((1.50369 1.07983))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        3)
                       ((0.950502 0.686302))
                       ((0.657172 0.107961))))
                     ((0.568843 -0.069355)))))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    11.6)
                   ((1.40139 1.13418))
                   ((1.18112 0.417959))))
                 ((R:segstate.parent.lisp_onset_nasal is 0)
                  ((R:segstate.parent.n.name is dh)
                   ((1.69419 0.846786))
                   ((R:segstate.parent.n.name is ih)
                    ((1.72269 0.726141))
                    ((name is k_1)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                       <
                       0.1)
                      ((0.773515 0.511953))
                      ((1.01025 0.576966)))
                     ((R:segstate.parent.ph_ctype is a)
                      ((0.616727 0.566009))
                      ((R:segstate.parent.pp.ph_ctype is l)
                       ((name is t_1)
                        ((0.248557 -0.831168))
                        ((name is ng_1)
                         ((0.395653 -0.74453))
                         ((1.02229 0.272031))))
                       ((R:segstate.parent.pp.ph_cplace is l)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          3.4)
                         ((0.309676 -0.620815))
                         ((0.595287 -0.234753)))
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          5)
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                           <
                           0.4)
                          ((0.822917 0.503888))
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            2.2)
                           ((R:segstate.parent.R:SylStructure.parent.syl_in
                             <
                             8)
                            ((1.02236 0.118753))
                            ((R:segstate.parent.ph_cplace is a)
                             ((0.392294 -0.441116))
                             ((0.449193 -0.205434))))
                           ((R:segstate.parent.nn.ph_cplace is a)
                            ((0.772362 -0.0663088))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                              is
                              0)
                             ((0.610113 0.090522))
                             ((1.07417 0.61807))))))
                         ((R:segstate.parent.nn.ph_cplace is 0)
                          ((R:segstate.parent.pp.ph_cplace is a)
                           ((0.322586 -0.614946))
                           ((R:segstate.parent.R:SylStructure.parent.syl_in
                             <
                             2.2)
                            ((0.876961 0.154987))
                            ((0.586732 -0.348702))))
                          ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                            <
                            7.4)
                           ((R:segstate.parent.nn.ph_cplace is a)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                              <
                              0.1)
                             ((0.688588 -0.11039))
                             ((0.236005 -0.564329)))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                              <
                              0.3)
                             ((0.691135 -0.127545))
                             ((0.987186 0.349931))))
                           ((0.84685 0.48541)))))))))))
                  ((R:segstate.parent.nn.ph_vrnd is -)
                   ((0.745673 0.82137))
                   ((R:segstate.parent.ph_cplace is a)
                    ((1.42587 0.729971))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                      is
                      0)
                     ((0.920635 0.252765))
                     ((0.76099 -0.1744)))))))))))
            ((R:segstate.parent.pos_in_syl is 0)
             ((name is m_2)
              ((R:segstate.parent.p.ph_vlng is l)
               ((R:segstate.parent.pp.ph_cplace is a)
                ((0.922754 1.53783))
                ((0.974898 0.756126)))
               ((1.27983 0.303639)))
              ((R:segstate.parent.lisp_onset_glide is 0)
               ((R:segstate.parent.n.name is pau)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                  is
                  0)
                 ((1.78329 1.23154))
                 ((1.68652 0.527445)))
                ((R:segstate.parent.lisp_onset_nasal is 0)
                 ((name is d_3)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                    <
                    0.1)
                   ((0.449864 -0.174198))
                   ((0.727291 1.17181)))
                  ((name is k_3)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                     is
                     0)
                    ((0.708587 0.931479))
                    ((0.531037 -0.0329929)))
                   ((name is g_3)
                    ((1.40112 0.636567))
                    ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                      <
                      1.2)
                     ((name is s_3)
                      ((R:segstate.parent.nn.ph_vrnd is -)
                       ((0.542368 -0.20125))
                       ((0.199527 -0.467546)))
                      ((R:segstate.parent.ph_cplace is d)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                         <
                         0.3)
                        ((0.61942 0.0423766))
                        ((1.77853 0.86384)))
                       ((R:segstate.parent.p.name is iy)
                        ((R:segstate.parent.nn.ph_cplace is a)
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           1.5)
                          ((R:segstate.parent.R:SylStructure.parent.position_type
                            is
                            mid)
                           ((0.688806 0.14791))
                           ((R:segstate.parent.pp.ph_cplace is a)
                            ((1.64145 0.785181))
                            ((1.36684 0.687519))))
                          ((R:segstate.parent.R:SylStructure.parent.position_type
                            is
                            initial)
                           ((0.811359 0.00836656))
                           ((0.924433 0.305484))))
                         ((name is pau_2)
                          ((0.322454 -0.364322))
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            4)
                           ((p.name is iy_3)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                              <
                              0.2)
                             ((R:segstate.parent.pp.ph_cplace is a)
                              ((1.39938 0.672945))
                              ((0.676366 -0.0753685)))
                             ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                               <
                               4.8)
                              ((0.731839 -0.0176807))
                              ((0.751779 -0.410496))))
                            ((R:segstate.parent.pp.ph_ctype is f)
                             ((1.0437 0.740395))
                             ((R:segstate.parent.R:SylStructure.parent.position_type
                               is
                               initial)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                <
                                1.2)
                               ((1.7049 0.923432))
                               ((0.901857 0.0489775)))
                              ((0.72762 0.104275)))))
                           ((p.name is iy_3)
                            ((R:segstate.parent.R:SylStructure.parent.position_type
                              is
                              initial)
                             ((0.873831 0.615251))
                             ((0.826312 0.00856423)))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                              is
                              0)
                             ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                               <
                               1.6)
                              ((0.880433 0.239945))
                              ((0.637422 -0.194829)))
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               4)
                              ((0.469139 -0.447328))
                              ((0.45513 -0.300867))))))))
                        ((R:segstate.parent.n.name is er)
                         ((R:segstate.parent.R:SylStructure.parent.last_accent
                           <
                           0.4)
                          ((0.813564 -0.158623))
                          ((1.05894 0.647353)))
                         ((R:segstate.parent.ph_vheight is 2)
                          ((R:segstate.parent.R:SylStructure.parent.asyl_in
                            <
                            3.5)
                           ((R:segstate.parent.R:SylStructure.parent.asyl_in
                             <
                             1.2)
                            ((0.689789 -0.302516))
                            ((0.614541 -0.106249)))
                           ((0.349979 -0.448489)))
                          ((R:segstate.parent.p.name is ih)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                             is
                             0)
                            ((R:segstate.parent.pp.ph_cplace is a)
                             ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                               <
                               2.4)
                              ((0.689656 -0.136062))
                              ((0.44646 -0.358483)))
                             ((0.876428 0.135631)))
                            ((0.607186 -0.377348)))
                           ((R:segstate.parent.n.name is ax)
                            ((0.621174 -0.166618))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                              <
                              0.3)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                               <
                               0.2)
                              ((1.34295 0.109515))
                              ((0.800659 -0.258028)))
                             ((R:segstate.parent.R:SylStructure.parent.asyl_out
                               <
                               2.5)
                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                <
                                2.4)
                               ((0.840767 0.283299))
                               ((1.06319 0.603743)))
                              ((0.761679 -0.0555632)))))))))))
                     ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                       <
                       2.2)
                      ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                        <
                        0.1)
                       ((R:segstate.parent.R:SylStructure.parent.next_accent
                         <
                         2.1)
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          1.2)
                         ((R:segstate.parent.R:SylStructure.parent.syl_in
                           <
                           3.4)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                            is
                            0)
                           ((1.96771 0.938764))
                           ((0.653144 0.318488)))
                          ((0.754037 0.213147)))
                         ((p.name is iy_3)
                          ((1.05963 0.339513))
                          ((R:segstate.parent.R:SylStructure.parent.position_type
                            is
                            initial)
                           ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                             <
                             0.1)
                            ((0.380258 -0.555888))
                            ((0.771153 -0.243183)))
                           ((0.899619 0.321235)))))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                          is
                          0)
                         ((0.766113 -0.17207))
                         ((0.294653 -0.653332))))
                       ((name is t_3)
                        ((0.223654 -0.71236))
                        ((R:segstate.parent.n.name is s)
                         ((0.813791 0.334981))
                         ((R:segstate.parent.n.name is ao)
                          ((name is f_3)
                           ((0.937949 0.404111))
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                             <
                             3.2)
                            ((1.10253 0.187394))
                            ((0.642407 -0.0659323))))
                          ((name is hh_2)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                             <
                             0.1)
                            ((0.808352 0.326425))
                            ((0.567916 -0.166282)))
                           ((R:segstate.parent.ph_cplace is p)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                              <
                              0.1)
                             ((R:segstate.parent.p.name is ih)
                              ((1.05459 -0.0704945))
                              ((0.924767 0.0096163)))
                             ((0.824154 0.274532)))
                            ((name is s_1)
                             ((1.20746 0.297707))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                               is
                               0)
                              ((R:segstate.parent.ph_cplace is d)
                               ((0.745832 -0.00236259))
                               ((R:segstate.parent.ph_cplace is a)
                                ((R:segstate.parent.nn.ph_cplace is a)
                                 ((0.556189 -0.360043))
                                 ((0.82154 -0.0569349)))
                                ((R:segstate.parent.R:SylStructure.parent.syl_out
                                  <
                                  4.4)
                                 ((R:segstate.parent.ph_ctype is f)
                                  ((0.356134 -0.463322))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                    <
                                    0.2)
                                   ((0.667275 -0.121616))
                                   ((0.595166 -0.320101))))
                                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                   <
                                   5.5)
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                    is
                                    0)
                                   ((0.461386 -0.643282))
                                   ((0.328233 -0.481996)))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                    <
                                    0.1)
                                   ((0.512375 -0.494829))
                                   ((0.472824 -0.332746)))))))
                              ((R:segstate.parent.pp.ph_cplace is l)
                               ((p.name is iy_3)
                                ((0.94302 0.0523159))
                                ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                                  is
                                  in)
                                 ((0.584594 -0.239191))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                   <
                                   0.2)
                                  ((0.355859 -0.735231))
                                  ((0.376851 -0.526821)))))
                               ((name is hh_3)
                                ((0.199585 -0.460788))
                                ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                                  <
                                  2.2)
                                 ((R:segstate.parent.n.name is v)
                                  ((0.520222 -0.470588))
                                  ((p.name is iy_3)
                                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                     <
                                     0.5)
                                    ((0.480728 0.0374297))
                                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                                      <
                                      5.6)
                                     ((0.55042 -0.503295))
                                     ((0.403308 -0.281243))))
                                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                                     <
                                     6.7)
                                    ((R:segstate.parent.nn.ph_cplace
                                      is
                                      0)
                                     ((1.18364 0.636661))
                                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                       <
                                       5.5)
                                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                        is
                                        0)
                                       ((0.615269 0.389346))
                                       ((0.7163 -0.0303566)))
                                      ((0.782392 -0.262026))))
                                    ((R:segstate.parent.lisp_coda_nasal
                                      is
                                      0)
                                     ((R:segstate.parent.ph_cplace
                                       is
                                       a)
                                      ((0.731305 0.095113))
                                      ((0.572485 -0.139004)))
                                     ((0.554477 -0.298031))))))
                                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                   <
                                   2.7)
                                  ((0.433617 -0.498545))
                                  ((0.45718 -0.233902))))))))))))))
                      ((R:segstate.parent.pp.ph_cplace is l)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                         is
                         0)
                        ((1.10646 0.265601))
                        ((1.52705 0.891387)))
                       ((R:segstate.parent.ph_ctype is s)
                        ((R:segstate.parent.ph_cplace is a)
                         ((1.17454 0.61507))
                         ((0.67459 -0.0255196)))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          1.5)
                         ((0.801676 0.138201))
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                           <
                           4.5)
                          ((R:segstate.parent.R:SylStructure.parent.asyl_in
                            <
                            2.4)
                           ((0.379919 -0.607477))
                           ((0.835946 -0.128706)))
                          ((0.940131 0.0347226)))))))))))
                 ((R:segstate.parent.nn.ph_vc is +)
                  ((0.953545 0.0161793))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                    is
                    0)
                   ((R:segstate.parent.nn.ph_cplace is a)
                    ((1.04877 -0.0467717))
                    ((R:segstate.parent.p.name is iy)
                     ((0.132752 -0.676604))
                     ((0.336097 -0.466025))))
                   ((name is n_3)
                    ((0.330422 -0.539566))
                    ((0.104682 -0.719896)))))))
               ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                 is
                 aux)
                ((R:segstate.parent.n.name is aa)
                 ((p.name is iy_3)
                  ((0.656773 -0.335245))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                    <
                    0.1)
                   ((1.05989 0.486359))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     3.7)
                    ((0.552422 -0.0903487))
                    ((0.540996 0.231234)))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                   <
                   0.3)
                  ((0.561132 -0.157377))
                  ((0.634382 -0.476247))))
                ((name is l_1)
                 ((0.497132 -0.344483))
                 ((name is p_2)
                  ((0.713471 -0.340261))
                  ((R:segstate.parent.n.name is uw)
                   ((0.958511 -0.103066))
                   ((R:segstate.parent.pp.ph_ctype is l)
                    ((1.43375 1.35626))
                    ((R:segstate.parent.n.name is r)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                       is
                       0)
                      ((1.26809 1.12028))
                      ((1.12782 0.698262)))
                     ((R:segstate.parent.lisp_coda_stop is 0)
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                        <
                        3.9)
                       ((R:segstate.parent.n.name is y)
                        ((0.836662 0.0713996))
                        ((R:segstate.parent.nn.ph_vlng is l)
                         ((1.24029 1.24216))
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           10)
                          ((R:segstate.parent.n.name is ih)
                           ((1.20485 0.449291))
                           ((R:segstate.parent.R:SylStructure.parent.asyl_out
                             <
                             1.3)
                            ((2.2884 1.27853))
                            ((0.689009 0.662691))))
                          ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                            <
                            0.1)
                           ((0.926084 0.181094))
                           ((1.02336 0.409044))))))
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         7.1)
                        ((0.58676 -0.149926))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                          <
                          5.8)
                         ((1.47394 0.700539))
                         ((R:segstate.parent.R:SylStructure.parent.asyl_in
                           <
                           3.1)
                          ((0.931408 -0.0736373))
                          ((1.10449 0.43824))))))
                      ((R:segstate.parent.lisp_coda_nasal is 0)
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         6.1)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          8.8)
                         ((0.597693 0.369055))
                         ((0.626067 0.100246)))
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          13.6)
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           3.5)
                          ((0.627509 -0.124719))
                          ((R:segstate.parent.p.name is ih)
                           ((0.418439 0.333232))
                           ((0.96505 0.125771))))
                         ((0.744911 -0.300359))))
                       ((0.913971 0.720332))))))))))))
             ((name is k_3)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                <
                0.3)
               ((0.522493 -0.707671))
               ((R:segstate.parent.n.seg_onsetcoda is coda)
                ((0.347943 -0.95046))
                ((R:segstate.parent.pos_in_syl is 2)
                 ((0.246084 -1.16557))
                 ((0.211331 -1.00706)))))
              ((name is t_3)
               ((R:segstate.parent.n.name is w)
                ((0.102862 -0.81799))
                ((R:segstate.parent.nn.ph_vrnd is -)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   3.5)
                  ((0.483695 -0.442076))
                  ((0.236592 -0.658117)))
                 ((R:segstate.parent.pp.ph_ctype is s)
                  ((0.0976722 -0.801061))
                  ((R:segstate.parent.nn.ph_cplace is l)
                   ((0.253663 -0.762708))
                   ((R:segstate.parent.R:SylStructure.parent.last_accent
                     <
                     1.2)
                    ((0.233008 -0.607998))
                    ((0.222726 -0.702879)))))))
               ((name is d_2)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                  <
                  0.3)
                 ((0.510083 -0.301445))
                 ((R:segstate.parent.pp.ph_cplace is a)
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    5.8)
                   ((1.37225 1.59407))
                   ((1.2298 0.801944)))
                  ((R:segstate.parent.n.name is n)
                   ((0.587682 -0.210861))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                     <
                     0.3)
                    ((0.915031 0.760281))
                    ((0.878236 0.0904682))))))
                ((p.name is uh_3)
                 ((R:segstate.parent.lisp_coda_glide is 0)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    0.5)
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     1.4)
                    ((1.54672 1.44344))
                    ((0.873873 0.188784)))
                   ((R:segstate.parent.pp.ph_cplace is l)
                    ((0.577662 -0.16654))
                    ((name is d_1)
                     ((0.768289 -0.0150954))
                     ((0.848756 0.644626)))))
                  ((0.822389 -0.285622)))
                 ((name is ng_2)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    2.7)
                   ((R:segstate.parent.lisp_onset_fric is 0)
                    ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                      <
                      2.2)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       6)
                      ((0.935342 0.0511179))
                      ((0.691097 -0.421151)))
                     ((0.635955 -0.615863)))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      7.8)
                     ((0.776878 0.2564))
                     ((1.22141 0.219514))))
                   ((R:segstate.parent.n.seg_onsetcoda is coda)
                    ((R:segstate.parent.lisp_onset_fric is 0)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                       is
                       0)
                      ((0.983444 0.0156656))
                      ((0.800496 -0.247719)))
                     ((0.96895 0.52423)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                      is
                      0)
                     ((0.892774 0.440833))
                     ((0.943261 0.806969)))))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    3.6)
                   ((name is dh_2)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                      <
                      0.2)
                     ((1.327 1.08835))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       0.4)
                      ((1.47052 0.0356957))
                      ((1.6946 0.249426))))
                    ((name is r_2)
                     ((1.41978 0.552192))
                     ((R:segstate.parent.n.name is l)
                      ((1.13009 0.51135))
                      ((name is t_2)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                         <
                         4)
                        ((1.20479 0.596256))
                        ((0.651494 -0.0253288)))
                       ((name is n_3)
                        ((R:segstate.parent.R:SylStructure.parent.sub_phrases
                          <
                          0.2)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                           is
                           0)
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            2.5)
                           ((0.917349 -0.125017))
                           ((0.367615 -0.440346)))
                          ((R:segstate.parent.R:SylStructure.parent.asyl_out
                            <
                            1.2)
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                             <
                             1.2)
                            ((0.812602 -0.00361781))
                            ((0.546115 -0.325865)))
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                             <
                             4.2)
                            ((0.969839 0.0557459))
                            ((1.43595 0.701938)))))
                         ((1.16512 0.522158)))
                        ((R:segstate.parent.n.name is s)
                         ((R:segstate.parent.ph_cplace is v)
                          ((0.522765 -0.213222))
                          ((R:segstate.parent.ph_cplace is a)
                           ((0.509378 -0.674672))
                           ((0.398244 -0.596508))))
                         ((R:segstate.parent.pp.ph_cplace is g)
                          ((R:segstate.parent.n.name is f)
                           ((1.09397 0.508824))
                           ((R:segstate.parent.nn.ph_vlng is s)
                            ((0.828459 0.338007))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                              is
                              0)
                             ((0.593134 -0.383533))
                             ((R:segstate.parent.n.name is pau)
                              ((0.575211 -0.217486))
                              ((0.768908 0.234827))))))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                            <
                            0.3)
                           ((R:segstate.parent.ph_ctype is f)
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              2.8)
                             ((R:segstate.parent.lisp_onset_glide is 0)
                              ((0.971474 0.395941))
                              ((0.413108 -0.401762)))
                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                               <
                               3.7)
                              ((0.479328 -0.639509))
                              ((R:segstate.parent.R:SylStructure.parent.syl_in
                                <
                                4.5)
                               ((0.443555 -0.498893))
                               ((1.00354 -0.0640894)))))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                              is
                              0)
                             ((R:segstate.parent.R:SylStructure.parent.asyl_in
                               <
                               1.5)
                              ((0.668358 -0.352773))
                              ((0.634622 -0.0903508)))
                             ((R:segstate.parent.pp.ph_ctype is s)
                              ((R:segstate.parent.ph_ctype is s)
                               ((0.834678 -0.284414))
                               ((1.15939 0.263019)))
                              ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                <
                                1.2)
                               ((1.41025 0.757285))
                               ((1.03048 0.126597))))))
                           ((name is l_3)
                            ((0.362061 -0.595176))
                            ((R:segstate.parent.R:SylStructure.parent.next_accent
                              <
                              2.4)
                             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                               is
                               in)
                              ((0.290262 -0.431414))
                              ((R:segstate.parent.ph_cplace is l)
                               ((0.762195 -0.481601))
                               ((name is d_3)
                                ((0.382035 -0.390506))
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                  <
                                  1.2)
                                 ((R:segstate.parent.R:SylStructure.parent.position_type
                                   is
                                   initial)
                                  ((0.415094 -0.548277))
                                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                    <
                                    6.6)
                                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                                     <
                                     3.2)
                                    ((R:segstate.parent.lisp_onset_glide
                                      is
                                      0)
                                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                       <
                                       1.2)
                                      ((0.651343 -0.145872))
                                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                        is
                                        0)
                                       ((0.623306 -0.38034))
                                       ((0.345633 -0.65774))))
                                     ((0.833946 -0.0688469)))
                                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                      <
                                      2.1)
                                     ((R:segstate.parent.ph_ctype is f)
                                      ((0.733195 0.0712758))
                                      ((1.1384 0.525486)))
                                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                                       <
                                       1.2)
                                      ((0.505025 -0.523915))
                                      ((0.729121 -0.109065)))))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                     <
                                     0.2)
                                    ((0.571353 -0.277744))
                                    ((1.06178 0.382111)))))
                                 ((R:segstate.parent.lisp_coda_fric
                                   is
                                   0)
                                  ((1.10451 0.19427))
                                  ((0.755153 -0.193588)))))))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                               is
                               0)
                              ((0.321562 -0.690817))
                              ((0.652921 -0.254344)))))))))))))
                   ((name is l_2)
                    ((R:segstate.parent.nn.ph_vc is +)
                     ((0.828049 0.0609839))
                     ((1.1932 0.745827)))
                    ((name is t_2)
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       8.8)
                      ((R:segstate.parent.nn.ph_vc is +)
                       ((5.58417e-06 -0.429946))
                       ((0.478752 -0.052303)))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        12.3)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                         is
                         0)
                        ((0.915923 0.19946))
                        ((1.20835 0.765926)))
                       ((0.536159 -0.129549))))
                     ((R:segstate.parent.pp.ph_cplace is p)
                      ((R:segstate.parent.pos_in_syl is 2)
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         9.8)
                        ((R:segstate.parent.lisp_coda_fric is 0)
                         ((1.24307 0.412115))
                         ((0.804205 -0.275368)))
                        ((0.804385 -0.286451)))
                       ((1.12155 0.467075)))
                      ((name is z_2)
                       ((R:segstate.parent.nn.ph_cplace is l)
                        ((0.497467 -0.744552))
                        ((R:segstate.parent.nn.ph_vlng is s)
                         ((0.597732 0.364504))
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                           <
                           7.2)
                          ((R:segstate.parent.n.seg_onsetcoda is coda)
                           ((0.586399 0.00803849))
                           ((0.79905 -0.40481)))
                          ((0.847479 0.333409)))))
                       ((R:segstate.parent.nn.ph_vrnd is -)
                        ((R:segstate.parent.n.name is w)
                         ((0.669874 0.0121333))
                         ((R:segstate.parent.R:SylStructure.parent.syl_in
                           <
                           5.6)
                          ((R:segstate.parent.R:SylStructure.parent.asyl_out
                            <
                            5.6)
                           ((R:segstate.parent.nn.ph_vlng is l)
                            ((R:segstate.parent.R:SylStructure.parent.asyl_out
                              <
                              3.5)
                             ((0.370538 -0.750052))
                             ((0.540814 -0.458515)))
                            ((R:segstate.parent.pp.ph_ctype is r)
                             ((0.731167 -0.0922128))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                               <
                               0.1)
                              ((R:segstate.parent.p.name is ih)
                               ((0.811279 -0.0144387))
                               ((0.570744 -0.388773)))
                              ((R:segstate.parent.R:SylStructure.parent.last_accent
                                <
                                1.2)
                               ((R:segstate.parent.ph_ctype is n)
                                ((R:segstate.parent.ph_cplace is a)
                                 ((0.287645 -0.564608))
                                 ((0.248642 -0.767299)))
                                ((R:segstate.parent.R:SylStructure.parent.last_accent
                                  <
                                  0.1)
                                 ((0.563502 -0.289014))
                                 ((0.555848 -0.522177))))
                               ((R:segstate.parent.R:SylStructure.parent.syl_in
                                 <
                                 3.2)
                                ((1.05305 -0.150793))
                                ((1.09359 -0.143054)))))))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                             <
                             0.2)
                            ((0.257041 -0.762158))
                            ((0.435298 -0.484361))))
                          ((R:segstate.parent.pp.ph_ctype is s)
                           ((0.811243 -0.290901))
                           ((name is n_3)
                            ((0.28073 -0.568298))
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              7.3)
                             ((0.304732 -0.641468))
                             ((0.397057 -0.833012)))))))
                        ((R:segstate.parent.R:SylStructure.parent.last_accent
                          <
                          4.8)
                         ((R:segstate.parent.ph_cplace is v)
                          ((R:segstate.parent.lisp_onset_stop is 0)
                           ((R:segstate.parent.lisp_coda_stop is 0)
                            ((0.366633 -0.754778))
                            ((0.470035 -0.39304)))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                             is
                             0)
                            ((0.594801 -0.431344))
                            ((0.845315 -0.167939))))
                          ((R:segstate.parent.nn.ph_vc is +)
                           ((R:segstate.parent.R:SylStructure.parent.syl_in
                             <
                             5.6)
                            ((0.596934 -0.261959))
                            ((0.592283 0.440725)))
                           ((name is m_2)
                            ((0.928154 0.167074))
                            ((R:segstate.parent.nn.ph_cplace is l)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                               is
                               0)
                              ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                <
                                4.6)
                               ((1.07695 0.154609))
                               ((0.593158 -0.166387)))
                              ((0.992109 -0.4348)))
                             ((R:segstate.parent.p.ph_vlng is l)
                              ((R:segstate.parent.lisp_coda_stop is 0)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                 <
                                 1.2)
                                ((0.772569 0.104687))
                                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                  <
                                  5.2)
                                 ((0.592008 -0.490343))
                                 ((0.79165 -0.170885))))
                               ((0.510699 -0.445442)))
                              ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                <
                                4.7)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                 <
                                 0.3)
                                ((0.584408 -0.432528))
                                ((0.750403 -0.00530174)))
                               ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                 <
                                 1.4)
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                  is
                                  0)
                                 ((0.638619 -0.187837))
                                 ((R:segstate.parent.ph_cplace is a)
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                    is
                                    0)
                                   ((0.245425 -0.704645))
                                   ((0.420849 -0.405576)))
                                  ((0.593037 -0.341081))))
                                ((0.558532 -0.634324)))))))))
                         ((1.26412 0.360611))))))))))))))))))))))
     ((R:segstate.parent.R:SylStructure.parent.parent.gpos is cc)
      ((R:segstate.parent.pos_in_syl is 1)
       ((R:segstate.parent.nn.ph_cplace is l)
        ((R:segstate.parent.R:SylStructure.parent.syl_in < 5.4)
         ((name is n_2)
          ((0.924543 0.604991))
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
            is
            0)
           ((0.962266 0.179559))
           ((0.569815 -0.291334))))
         ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.2)
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
            <
            0.3)
           ((0.665613 0.204607))
           ((1.07951 0.559116)))
          ((1.09086 0.712964))))
        ((R:segstate.parent.nn.ph_vrnd is -)
         ((name is n_3)
          ((R:segstate.parent.R:SylStructure.parent.syl_out < 6)
           ((0.355024 -0.397098))
           ((0.219022 -0.640131)))
          ((name is n_2)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
             is
             0)
            ((0.570739 -0.233037))
            ((0.516938 -0.628743)))
           ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.5)
            ((R:segstate.parent.R:SylStructure.parent.syl_out < 7)
             ((0.491817 -0.255171))
             ((0.644207 -0.0422141)))
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 6.9)
             ((1.27448 0.345055))
             ((0.727108 -0.00315755))))))
         ((R:segstate.parent.R:SylStructure.parent.syl_out < 4.8)
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
            is
            0)
           ((R:segstate.parent.pp.ph_cplace is a)
            ((1.2549 0.549126))
            ((name is n_2)
             ((1.03805 0.557138))
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 6.4)
              ((0.47305 -0.179897))
              ((1.25773 0.228124)))))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
             <
             0.3)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
              is
              0)
             ((0.721199 -0.279453))
             ((0.440261 -0.074674)))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
              is
              0)
             ((0.749992 -0.0869317))
             ((0.99082 0.251083)))))
          ((name is ah_2)
           ((0.552174 0.396037))
           ((name is n_2)
            ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3.5)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
               <
               1.2)
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 3.5)
               ((0.68577 -0.194736))
               ((0.572861 0.15484)))
              ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.2)
               ((0.768686 0.639098))
               ((1.08994 0.220448))))
             ((1.10831 -0.355601)))
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 3.2)
             ((name is n_3)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                <
                1.2)
               ((R:segstate.parent.R:SylStructure.parent.syl_out
                 <
                 10.5)
                ((0.354668 -0.461547))
                ((0.224932 -0.66168)))
               ((0.323634 -0.213926)))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                is
                0)
               ((0.298295 -0.424249))
               ((R:segstate.parent.R:SylStructure.parent.syl_out
                 <
                 12.2)
                ((name is n_1)
                 ((0.38881 -0.26351))
                 ((0.847062 -0.0303904)))
                ((0.244878 -0.312007)))))
             ((name is n_1)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                is
                0)
               ((0.599657 -0.013467))
               ((0.977179 0.370612)))
              ((R:segstate.parent.nn.ph_cplace is a)
               ((0.48427 -0.410377))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                 is
                 0)
                ((1.00507 0.141291))
                ((0.672828 -0.180525)))))))))))
       ((name is b_3)
        ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 6.5)
         ((1.18247 0.624426))
         ((0.615022 0.782873)))
        ((R:segstate.parent.pp.ph_vfront is 1)
         ((name is d_2)
          ((R:segstate.parent.n.name is pau)
           ((0.363447 -0.443661))
           ((R:segstate.parent.n.name is dh)
            ((0.293077 -0.495829))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
              <
              0.3)
             ((R:segstate.parent.R:SylStructure.parent.sub_phrases
               <
               0.2)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                is
                0)
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 8)
                ((4.00138e-06 -0.720807))
                ((0.0751217 -0.703099)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                 is
                 0)
                ((0.0772998 -0.702058))
                ((0.183105 -0.632273))))
              ((0.150013 -0.622741)))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
               is
               0)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3.5)
               ((0.842354 -0.364596))
               ((0.155518 -0.61457)))
              ((R:segstate.parent.nn.ph_vrnd is -)
               ((0.174757 -0.64998))
               ((0.0772997 -0.702058)))))))
          ((R:segstate.parent.n.name is t)
           ((0.479544 -0.201509))
           ((R:segstate.parent.n.name is pau)
            ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 3.1)
             ((0.767499 -0.193273))
             ((0.244996 -0.517233)))
            ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.3)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
               <
               0.3)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                is
                0)
               ((name is d_1)
                ((0.0952109 -0.657242))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  1.2)
                 ((0.18831 -0.513419))
                 ((3.24799e-06 -0.583112))))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 2.4)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  5.2)
                 ((0.0730522 -0.65063))
                 ((0.252698 -0.431316)))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                  is
                  0)
                 ((0.312141 -0.38722))
                 ((0.296586 -0.515087)))))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                <
                2.4)
               ((R:segstate.parent.R:SylStructure.parent.last_accent
                 <
                 0.5)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                  is
                  0)
                 ((R:segstate.parent.pp.ph_vlng is l)
                  ((0.205583 -0.624153))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                     <
                     1.2)
                    ((0.196854 -0.51015))
                    ((0.118507 -0.594854)))
                   ((R:segstate.parent.nn.ph_vlng is l)
                    ((0.199652 -0.498304))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      5.5)
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       2.2)
                      ((0.244588 -0.402762))
                      ((0.185654 -0.529085)))
                     ((0.537959 -0.327898))))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                   is
                   0)
                  ((0.625617 -0.210559))
                  ((0.361288 -0.37463))))
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  2.5)
                 ((0.218175 -0.477809))
                 ((0.101255 -0.614215))))
               ((name is d_1)
                ((0.191552 -0.585607))
                ((0.139846 -0.514961)))))
             ((0.159856 -0.629612))))))
         ((name is ae_2)
          ((R:segstate.parent.R:SylStructure.parent.syl_in < 5.4)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
             is
             0)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
              is
              0)
             ((0.0336841 -0.681736))
             ((0.0949304 -0.621138)))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
              <
              1.2)
             ((R:segstate.parent.pp.ph_cplace is 0)
              ((6.42893e-07 -0.692401))
              ((0.0223969 -0.687921)))
             ((0.0459573 -0.670004))))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
             <
             0.1)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
              is
              0)
             ((0.2097 -0.611523))
             ((0.495586 -0.46221)))
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 7.4)
             ((0.14165 -0.636408))
             ((0.0371907 -0.679226)))))
          ((name is b_1)
           ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 5.4)
            ((0.349492 -0.904942))
            ((0.0979309 -1.07186)))
           ((R:segstate.parent.pp.ph_ctype is 0)
            ((p.name is pau_2)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
               is
               0)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                is
                0)
               ((0.591841 0.77156))
               ((0.662368 0.920075)))
              ((0.513711 0.0149538)))
             ((R:segstate.parent.pp.ph_vc is +)
              ((name is ae_1)
               ((0.276546 -0.769744))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                 <
                 0.3)
                ((0.86156 -0.123487))
                ((1.43637 0.703675))))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                is
                0)
               ((0.162077 -0.653417))
               ((name is ae_3)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  5.5)
                 ((0.514899 -0.452037))
                 ((0.212892 -0.616601)))
                ((0.527031 -0.23559))))))
            ((name is ae_1)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
               <
               2.2)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                <
                0.2)
               ((0.815019 -0.0383776))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  2.7)
                 ((0.541315 -0.0980805))
                 ((0.593407 -0.445969)))
                ((0.388892 -0.635412))))
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 5.4)
               ((0.589744 -0.550335))
               ((0.108302 -0.808925))))
             ((name is t_3)
              ((R:segstate.parent.n.seg_onsetcoda is coda)
               ((0.426954 -0.554783))
               ((0.803442 -0.445145)))
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 3.1)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                 is
                 0)
                ((R:segstate.parent.lisp_onset_stop is 0)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                   <
                   1.2)
                  ((0.177177 -0.655893))
                  ((0.538032 -0.420053)))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   4.4)
                  ((0.728074 -0.00498933))
                  ((0.330924 -0.479718))))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                  is
                  0)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   2.4)
                  ((0.745517 -0.177197))
                  ((0.990273 0.360744)))
                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                   <
                   6.4)
                  ((0.36641 -0.540157))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    2)
                   ((0.793192 -0.0395855))
                   ((0.601308 -0.250131))))))
               ((name is t_2)
                ((0.395443 -0.231188))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  6.6)
                 ((0.799142 -0.114251))
                 ((1.02422 0.36745)))))))))))))
      ((R:segstate.parent.lisp_onset_glide is 0)
       ((name is l_1)
        ((R:segstate.parent.p.ph_vlng is d)
         ((p.name is ow_3)
          ((0.594774 -0.360971))
          ((0.327956 0.231564)))
         ((R:segstate.parent.p.ph_vlng is l)
          ((R:segstate.parent.nn.ph_vlng is s)
           ((1.41655 2.01239))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
             is
             0)
            ((1.25181 1.60012))
            ((1.35709 0.578849))))
          ((R:segstate.parent.R:SylStructure.parent.last_accent < 2.1)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
             is
             0)
            ((0.371688 0.623603))
            ((0.405341 0.198365)))
           ((0.762461 1.13021)))))
        ((R:segstate.parent.ph_ctype is 0)
         ((R:segstate.parent.n.name is l)
          ((name is eh_3)
           ((R:segstate.parent.pp.ph_cplace is a)
            ((0.828406 0.603494))
            ((R:segstate.parent.R:SylStructure.parent.last_accent
              <
              1.4)
             ((0.825538 1.23242))
             ((0.862487 1.79078))))
           ((name is ih_3)
            ((R:segstate.parent.lisp_onset_stop is 0)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
               is
               0)
              ((1.27482 1.15068))
              ((0.817752 0.285358)))
             ((0.823301 -0.112732)))
            ((name is ay_3)
             ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
               <
               0.2)
              ((0.369125 -1.48074))
              ((0.794018 -0.885936)))
             ((name is aa_1)
              ((0.839762 0.36255))
              ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                <
                0.4)
               ((R:segstate.parent.nn.ph_vrnd is +)
                ((0.824589 -0.197068))
                ((R:segstate.parent.pp.ph_vrnd is -)
                 ((3.42402 0.72057))
                 ((0.401222 -0.155854))))
               ((name is ae_2)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                  is
                  0)
                 ((0.682861 0.0774931))
                 ((0.63282 0.455442)))
                ((R:segstate.parent.lisp_onset_nasal is 0)
                 ((name is ao_3)
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    3.2)
                   ((0.538251 -0.550529))
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     1.8)
                    ((0.253013 -0.770549))
                    ((0.0532638 -0.875596))))
                  ((name is ow_3)
                   ((0.170812 -0.911861))
                   ((name is ao_2)
                    ((R:segstate.parent.R:SylStructure.parent.position_type
                      is
                      single)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       3.6)
                      ((1.03261 0.469493))
                      ((0.788179 0.024438)))
                     ((0.521752 -0.356411)))
                    ((R:segstate.parent.p.name is d)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       1.4)
                      ((2.93816 0.896198))
                      ((R:segstate.parent.ph_vheight is 2)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                         is
                         0)
                        ((0.405288 -0.327516))
                        ((0.534211 -0.121318)))
                       ((0.43278 -0.465771))))
                     ((name is ae_3)
                      ((0.612617 0.0244198))
                      ((name is iy_2)
                       ((0.935041 0.110062))
                       ((name is ow_1)
                        ((0.271344 -0.761314))
                        ((name is ax_1)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                           <
                           0.2)
                          ((0.304845 -0.409769))
                          ((R:segstate.parent.pp.ph_vlng is l)
                           ((0.202508 -0.471137))
                           ((R:segstate.parent.R:SylStructure.parent.syl_in
                             <
                             10.2)
                            ((p.name is t_3)
                             ((0.123784 -0.536133))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                               <
                               1.2)
                              ((R:segstate.parent.nn.ph_cplace is 0)
                               ((1.64627e-06 -0.581431))
                               ((3.57841e-06 -0.581429)))
                              ((2.93022e-06 -0.581432))))
                            ((0.161001 -0.490831)))))
                         ((name is ih_2)
                          ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                            <
                            0.1)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                             <
                             0.1)
                            ((0.206256 -0.629301))
                            ((2.86578e-06 -0.730248)))
                           ((0.618913 -0.367061)))
                          ((R:segstate.parent.nn.ph_cplace is 0)
                           ((name is aa_3)
                            ((3.81645e-06 -0.728705))
                            ((R:segstate.parent.p.name is f)
                             ((R:segstate.parent.nn.ph_vrnd is -)
                              ((p.name is f_3)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                 is
                                 0)
                                ((0.237884 -0.35982))
                                ((0.146756 -0.519352)))
                               ((0.580654 -0.24146)))
                              ((0.142087 -0.654661)))
                             ((R:segstate.parent.ph_vheight is 2)
                              ((R:segstate.parent.R:SylStructure.parent.next_accent
                                <
                                1.5)
                               ((R:segstate.parent.pp.ph_vlng is s)
                                ((0.185194 -0.487546))
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                  is
                                  0)
                                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                                   <
                                   8)
                                  ((0.31667 -0.356061))
                                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                                    <
                                    2.6)
                                   ((0.399522 -0.183917))
                                   ((0.409103 -0.300778))))
                                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                   <
                                   5)
                                  ((0.160281 -0.546527))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                    is
                                    0)
                                   ((0.386604 -0.272833))
                                   ((0.14126 -0.464964))))))
                               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                 <
                                 4.5)
                                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                  <
                                  2.5)
                                 ((0.933469 0.0943696))
                                 ((0.591986 -0.340133)))
                                ((0.405195 -0.419231))))
                              ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                <
                                1.1)
                               ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                 <
                                 0.7)
                                ((R:segstate.parent.nn.ph_vlng is l)
                                 ((1.5166 0.75281))
                                 ((0.990131 -0.0919678)))
                                ((R:segstate.parent.lisp_onset_stop
                                  is
                                  0)
                                 ((0.874728 0.101926))
                                 ((0.133875 -0.536577))))
                               ((R:segstate.parent.R:SylStructure.parent.syl_out
                                 <
                                 5.8)
                                ((0.62269 -0.227275))
                                ((0.555448 -0.531638)))))))
                           ((R:segstate.parent.R:SylStructure.parent.position_type
                             is
                             initial)
                            ((R:segstate.parent.ph_vheight is 2)
                             ((0.266247 -0.691971))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                               <
                               1.2)
                              ((0.160075 -0.643104))
                              ((0.370287 -0.455338))))
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                              <
                              5)
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               5.1)
                              ((R:segstate.parent.R:SylStructure.parent.last_accent
                                <
                                1.2)
                               ((R:segstate.parent.R:SylStructure.parent.position_type
                                 is
                                 single)
                                ((1.1575 -0.137732))
                                ((0.315923 -0.397036)))
                               ((1.22172 0.185182)))
                              ((R:segstate.parent.pp.ph_ctype is n)
                               ((0.274844 -0.618969))
                               ((R:segstate.parent.pp.ph_ctype is 0)
                                ((R:segstate.parent.lisp_onset_stop
                                  is
                                  0)
                                 ((0.258699 -0.669691))
                                 ((name is ax_2)
                                  ((5.56866e-06 -0.5469))
                                  ((0.340867 -0.320568))))
                                ((0.654413 -0.175724)))))
                             ((R:segstate.parent.ph_vheight is 3)
                              ((0.47938 -0.830413))
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                <
                                0.1)
                               ((0.251411 -0.613845))
                               ((R:segstate.parent.pp.ph_cplace is 0)
                                ((R:segstate.parent.ph_vheight is 1)
                                 ((0.361166 -0.472859))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                   is
                                   0)
                                  ((0.713386 -0.172385))
                                  ((0.54693 -0.316188))))
                                ((0.331913 -0.54954)))))))))))))))))
                 ((R:segstate.parent.ph_vheight is 2)
                  ((R:segstate.parent.p.name is m)
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     8.6)
                    ((0.0858211 -0.505699))
                    ((0.664385 -0.356006)))
                   ((0.690978 -0.0911647)))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    2.5)
                   ((0.993205 0.63062))
                   ((0.709033 -0.0596088)))))))))))
          ((R:segstate.parent.R:SylStructure.parent.parent.gpos
            is
            content)
           ((name is eh_3)
            ((R:segstate.parent.lisp_coda_glide is 0)
             ((R:segstate.parent.n.name is m)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                is
                0)
               ((0.467728 0.0666076))
               ((0.505655 -0.266262)))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.6)
               ((R:segstate.parent.n.name is d)
                ((0.468053 -0.15205))
                ((R:segstate.parent.p.name is g)
                 ((0.494342 -0.152051))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   2.1)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     7.5)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                      is
                      0)
                     ((0.38264 -0.432283))
                     ((0.133603 -0.564584)))
                    ((0.242474 -0.32776)))
                   ((0.136998 -0.556179)))
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    0.7)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     6.2)
                    ((0.140167 -0.572286))
                    ((0.423914 -0.448803)))
                   ((R:segstate.parent.nn.ph_vrnd is -)
                    ((0.864472 -0.0794245))
                    ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                      <
                      0.1)
                     ((0.116589 -0.552788))
                     ((0.4296 -0.208277))))))))
               ((0.731716 -0.0561091))))
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 1.5)
              ((0.130494 -0.563338))
              ((3.67572e-06 -0.620605))))
            ((name is iy_3)
             ((R:segstate.parent.n.name is pau)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                is
                0)
               ((0.533003 -0.250322))
               ((1.97098 0.973685)))
              ((R:segstate.parent.n.ph_vc is +)
               ((R:segstate.parent.n.name is ih)
                ((0.511014 -0.462099))
                ((R:segstate.parent.pp.ph_ctype is 0)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                   <
                   1.2)
                  ((0.571164 0.0601675))
                  ((0.388841 -0.212398)))
                 ((1.15669 0.360058))))
               ((R:segstate.parent.n.name is n)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  1.2)
                 ((0.107931 -0.637222))
                 ((0.286684 -0.511141)))
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  0.6)
                 ((R:segstate.parent.n.name is w)
                  ((0.28347 -0.321189))
                  ((R:segstate.parent.nn.ph_vlng is s)
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     3.4)
                    ((0.368835 -0.361311))
                    ((0.28262 -0.515151)))
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     9.5)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                      <
                      0.3)
                     ((0.206133 -0.437909))
                     ((0.208804 -0.529827)))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      0.5)
                     ((0.090159 -0.648007))
                     ((0.216621 -0.55609))))))
                 ((R:segstate.parent.lisp_coda_stop is 0)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                     is
                     0)
                    ((0.179292 -0.531704))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_in
                      <
                      2.5)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                       <
                       1.2)
                      ((0.304875 -0.392772))
                      ((0.503004 -0.118585)))
                     ((0.353946 -0.466634))))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     4.2)
                    ((R:segstate.parent.pp.ph_cplace is 0)
                     ((0.950368 0.100919))
                     ((0.629061 -0.257356)))
                    ((0.426804 -0.336901))))
                  ((0.298757 -0.547335)))))))
             ((R:segstate.parent.n.name is ng)
              ((R:segstate.parent.R:SylStructure.parent.position_type
                is
                single)
               ((name is ih_3)
                ((0.299204 -0.348192))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                  is
                  0)
                 ((1.0048 0.218152))
                 ((1.50475 0.962647))))
               ((name is ih_3)
                ((R:segstate.parent.pp.ph_cplace is a)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                   is
                   0)
                  ((0.403708 -0.371334))
                  ((0.760237 -0.0834912)))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   6.6)
                  ((R:segstate.parent.pp.ph_vlng is s)
                   ((0.247102 -0.473165))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                     is
                     0)
                    ((0.259783 -0.514823))
                    ((R:segstate.parent.nn.ph_cplace is 0)
                     ((0.075754 -0.609379))
                     ((4.27838e-06 -0.625912)))))
                  ((0.3691 -0.384413))))
                ((p.name is t_3)
                 ((R:segstate.parent.pp.ph_vfront is 1)
                  ((1.34233 0.45437))
                  ((0.459464 -0.248861)))
                 ((R:segstate.parent.pp.ph_vlng is d)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    6.3)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                     is
                     0)
                    ((0.337494 -0.47047))
                    ((0.229938 -0.493849)))
                   ((0.307755 -0.305855)))
                  ((R:segstate.parent.lisp_onset_stop is 0)
                   ((R:segstate.parent.p.name is th)
                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                      <
                      1.4)
                     ((0.237594 -0.223334))
                     ((0.52829 -0.0711086)))
                    ((p.name is ow_3)
                     ((0.23181 -0.107552))
                     ((R:segstate.parent.p.ph_vheight is 2)
                      ((0.253081 -0.473513))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        10.6)
                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                         <
                         1.6)
                        ((0.43449 -0.363482))
                        ((name is ih_1)
                         ((0.221929 -0.374782))
                         ((R:segstate.parent.R:SylStructure.parent.next_accent
                           <
                           1.2)
                          ((0.600849 -0.0141078))
                          ((0.517686 -0.205095)))))
                       ((0.398436 -0.407379))))))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                     is
                     0)
                    ((0.60559 0.27617))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      2.4)
                     ((0.542831 -0.146979))
                     ((0.41909 -0.286271)))))))))
              ((R:segstate.parent.n.seg_onsetcoda is coda)
               ((R:segstate.parent.lisp_coda_nasal is 0)
                ((name is ax_1)
                 ((R:segstate.parent.n.name is d)
                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                    <
                    1.2)
                   ((1.21356 1.38388))
                   ((1.26027 2.77552)))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    3.2)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                     <
                     0.3)
                    ((1.31855 1.71375))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                      is
                      0)
                     ((0.56962 0.143363))
                     ((0.377479 -0.420365))))
                   ((1.71696 1.98686))))
                 ((name is ae_2)
                  ((R:segstate.parent.R:SylStructure.parent.position_type
                    is
                    initial)
                   ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                     <
                     0.1)
                    ((0.826969 0.0354997))
                    ((0.713671 1.14912)))
                   ((R:segstate.parent.n.name is k)
                    ((0.592255 1.91618))
                    ((R:segstate.parent.lisp_onset_stop is 0)
                     ((0.807936 1.7))
                     ((0.841789 1.14135)))))
                  ((p.name is pau_2)
                   ((R:segstate.parent.ph_vheight is 3)
                    ((0.66597 -0.342255))
                    ((R:segstate.parent.nn.ph_cplace is 0)
                     ((1.56288 2.47365))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       3.4)
                      ((1.01529 1.04336))
                      ((0.902287 1.63411)))))
                   ((name is aa_3)
                    ((R:segstate.parent.n.name is r)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       8.4)
                      ((R:segstate.parent.pp.ph_vc is +)
                       ((0.195682 -0.640801))
                       ((0.0672876 -0.71497)))
                      ((0.631214 -0.399064)))
                     ((R:segstate.parent.R:SylStructure.parent.next_accent
                       <
                       1.6)
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        4.5)
                       ((0.613002 -0.274027))
                       ((0.594764 0.0204803)))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        2.4)
                       ((0.199875 -0.612361))
                       ((0.358662 -0.418455)))))
                    ((name is ih_3)
                     ((R:segstate.parent.lisp_coda_fric is 0)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                        <
                        2.4)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         2.2)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                          <
                          1.2)
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           1.2)
                          ((0.222157 -0.440764))
                          ((0.992351 -0.209332)))
                         ((1.52485 0.21526)))
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          13.5)
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           3.4)
                          ((R:segstate.parent.p.name is t)
                           ((0.532439 -0.186188))
                           ((R:segstate.parent.nn.ph_cplace is 0)
                            ((0.133126 -0.568053))
                            ((R:segstate.parent.R:SylStructure.parent.asyl_in
                              <
                              0.3)
                             ((0.516137 -0.278761))
                             ((0.260108 -0.516285)))))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                            <
                            0.3)
                           ((R:segstate.parent.pp.ph_vc is -)
                            ((0.169392 -0.510195))
                            ((0.176038 -0.487051)))
                           ((0.0867875 -0.604215))))
                         ((0.648574 -0.196107))))
                       ((1.61127 0.623828)))
                      ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                        <
                        2.2)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                         is
                         0)
                        ((0.834673 0.0915328))
                        ((1.61662 0.896207)))
                       ((0.71589 -0.139901))))
                     ((R:segstate.parent.p.name is b)
                      ((R:segstate.parent.n.name is aa)
                       ((2.38196 1.7597))
                       ((R:segstate.parent.n.name is k)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          4.9)
                         ((0.345844 -0.479065))
                         ((0.647637 0.300086)))
                        ((name is ih_1)
                         ((0.905151 -0.0624391))
                         ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                           <
                           0.1)
                          ((0.985399 0.121196))
                          ((R:segstate.parent.R:SylStructure.parent.asyl_out
                            <
                            2.5)
                           ((R:segstate.parent.R:SylStructure.parent.last_accent
                             <
                             1.6)
                            ((0.998424 0.26064))
                            ((1.4355 1.00373)))
                           ((R:segstate.parent.ph_vrnd is +)
                            ((1.19797 0.860318))
                            ((1.11085 1.75978))))))))
                      ((R:segstate.parent.p.name is n)
                       ((name is aa_2)
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          4.9)
                         ((0.41532 2.06264))
                         ((0.689862 1.52881)))
                        ((name is aa_1)
                         ((R:segstate.parent.pp.ph_ctype is 0)
                          ((0.0305046 -0.609309))
                          ((0.531164 -0.427356)))
                         ((R:segstate.parent.nn.ph_vlng is s)
                          ((1.8634 1.23238))
                          ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                            <
                            2.2)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                             <
                             0.1)
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                              <
                              3.3)
                             ((R:segstate.parent.pp.ph_vlng is s)
                              ((0.261237 -0.320993))
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                <
                                0.1)
                               ((0.920549 0.174717))
                               ((0.639552 -0.224818))))
                             ((0.911032 0.412869)))
                            ((R:segstate.parent.n.ph_vc is +)
                             ((R:segstate.parent.ph_vheight is 2)
                              ((0.781474 0.403078))
                              ((0.899508 0.848268)))
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               2.3)
                              ((0.857883 0.0912422))
                              ((R:segstate.parent.R:SylStructure.parent.last_accent
                                <
                                2.4)
                               ((1.02682 0.661003))
                               ((0.881315 0.152313))))))
                           ((R:segstate.parent.R:SylStructure.parent.position_type
                             is
                             final)
                            ((1.463 1.21345))
                            ((1.01475 0.446812)))))))
                       ((name is ah_2)
                        ((R:segstate.parent.lisp_coda_stop is 0)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                           <
                           0.3)
                          ((0.974785 1.5242))
                          ((1.30923 0.727196)))
                         ((1.31171 0.406683)))
                        ((R:segstate.parent.p.name is d)
                         ((name is iy_1)
                          ((1.04251 -0.195591))
                          ((R:segstate.parent.n.ph_vc is +)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                             <
                             0.1)
                            ((0.999694 1.4071))
                            ((R:segstate.parent.nn.ph_cplace is a)
                             ((1.35711 0.284001))
                             ((1.87248 1.10053))))
                           ((R:segstate.parent.R:SylStructure.parent.position_type
                             is
                             initial)
                            ((0.637022 -0.267743))
                            ((R:segstate.parent.R:SylStructure.parent.last_accent
                              <
                              0.8)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                               <
                               0.3)
                              ((0.794656 -0.170131))
                              ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                <
                                2.1)
                               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                 <
                                 1.2)
                                ((0.819917 0.168843))
                                ((0.657178 -0.284749)))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                 <
                                 1.2)
                                ((1.05113 0.459619))
                                ((1.60765 0.965)))))
                             ((R:segstate.parent.nn.ph_cplace is a)
                              ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                <
                                1.5)
                               ((0.776673 -0.0448495))
                               ((1.15689 0.360303)))
                              ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                <
                                0.1)
                               ((1.06872 0.227639))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                 is
                                 0)
                                ((R:segstate.parent.R:SylStructure.parent.syl_out
                                  <
                                  3.6)
                                 ((0.859856 0.325406))
                                 ((1.25069 0.793935)))
                                ((R:segstate.parent.R:SylStructure.parent.syl_in
                                  <
                                  5.5)
                                 ((1.84132 1.34578))
                                 ((0.903678 0.801662))))))))))
                         ((p.name is pau_5)
                          ((R:segstate.parent.R:SylStructure.parent.position_type
                            is
                            initial)
                           ((1.13223 0.307875))
                           ((1.79254 1.18941)))
                          ((name is ao_3)
                           ((R:segstate.parent.n.name is r)
                            ((R:segstate.parent.R:SylStructure.parent.syl_in
                              <
                              7.6)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                               <
                               1.2)
                              ((0.666325 1.11145))
                              ((0.824581 0.739444)))
                             ((0.781289 0.452552)))
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              7)
                             ((0.594875 -0.236427))
                             ((0.723431 0.427022))))
                           ((R:segstate.parent.ph_vheight is 1)
                            ((R:segstate.parent.p.name is sh)
                             ((R:segstate.parent.R:SylStructure.parent.asyl_in
                               <
                               1.2)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                                <
                                0.3)
                               ((0.609292 -0.125406))
                               ((0.142372 -0.701889)))
                              ((0.838633 -0.0201058)))
                             ((R:segstate.parent.pp.ph_vc is 0)
                              ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                <
                                8.3)
                               ((0.431089 -0.27021))
                               ((0.2518 -0.442725)))
                              ((p.name is m_3)
                               ((R:segstate.parent.R:SylStructure.parent.last_accent
                                 <
                                 1.2)
                                ((0.195512 -0.55671))
                                ((0.710609 -0.182144)))
                               ((name is ih_1)
                                ((R:segstate.parent.lisp_coda_stop
                                  is
                                  0)
                                 ((R:segstate.parent.lisp_coda_fric
                                   is
                                   0)
                                  ((1.57837 1.15921))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                    <
                                    0.3)
                                   ((1.49873 0.333107))
                                   ((0.432571 -0.278979))))
                                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                                   <
                                   9)
                                  ((R:segstate.parent.pp.ph_vlng is s)
                                   ((0.229982 -0.188753))
                                   ((R:segstate.parent.R:SylStructure.parent.last_accent
                                     <
                                     1.4)
                                    ((0.148399 -0.381142))
                                    ((0.449757 -0.204996))))
                                  ((0.819244 0.100977))))
                                ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                  <
                                  2.2)
                                 ((R:segstate.parent.p.ph_vheight is 2)
                                  ((0.582638 -0.179865))
                                  ((R:segstate.parent.R:SylStructure.parent.position_type
                                    is
                                    mid)
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                     <
                                     0.3)
                                    ((0.491738 -0.228052))
                                    ((0.975652 0.128957)))
                                   ((R:segstate.parent.p.name is hh)
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                      <
                                      0.1)
                                     ((name is iy_1)
                                      ((1.15001 0.607782))
                                      ((1.00388 0.149378)))
                                     ((name is iy_1)
                                      ((0.6615 0.0156285))
                                      ((0.711674 -0.523144))))
                                    ((name is uw_3)
                                     ((0.738606 -0.206525))
                                     ((R:segstate.parent.lisp_onset_fric
                                       is
                                       0)
                                      ((R:segstate.parent.n.name is d)
                                       ((R:segstate.parent.p.name is g)
                                        ((1.31487 0.608591))
                                        ((0.995703 0.907955)))
                                       ((name is iy_2)
                                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                          <
                                          0.2)
                                         ((R:segstate.parent.pp.ph_ctype
                                           is
                                           0)
                                          ((1.06066 1.07123))
                                          ((0.824721 0.528867)))
                                         ((0.994467 0.140011)))
                                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                          <
                                          0.3)
                                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                           <
                                           2.4)
                                          ((R:segstate.parent.R:SylStructure.parent.last_accent
                                            <
                                            0.4)
                                           ((0.684507 0.113023))
                                           ((0.504103 -0.283369)))
                                          ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                            <
                                            2.5)
                                           ((0.784597 -0.0573794))
                                           ((1.2975 0.494531))))
                                         ((R:segstate.parent.nn.ph_cplace
                                           is
                                           0)
                                          ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                            <
                                            3.6)
                                           ((1.06728 1.06524))
                                           ((1.07096 0.480575)))
                                          ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                            <
                                            4.5)
                                           ((R:segstate.parent.p.name
                                             is
                                             t)
                                            ((1.47523 0.712898))
                                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                              <
                                              1.2)
                                             ((1.15814 0.457913))
                                             ((0.694716 -0.0985971))))
                                           ((0.672726 -0.115453)))))))
                                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                        <
                                        1.4)
                                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                                         <
                                         9)
                                        ((1.76182 1.39943))
                                        ((0.882154 0.889585)))
                                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                         is
                                         0)
                                        ((1.21561 1.03276))
                                        ((R:segstate.parent.R:SylStructure.parent.last_accent
                                          <
                                          1.2)
                                         ((1.10845 0.753379))
                                         ((1.04058 -0.0233348))))))))))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                   <
                                   1.2)
                                  ((1.26422 0.659506))
                                  ((1.36399 1.30267))))))))
                            ((name is eh_1)
                             ((R:segstate.parent.n.name is r)
                              ((p.name is dh_3)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                 is
                                 0)
                                ((0.635373 0.574169))
                                ((0.580398 0.276813)))
                               ((1.46328 1.97284)))
                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                <
                                4.6)
                               ((1.4143 0.553502))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                 is
                                 0)
                                ((0.420723 -0.520525))
                                ((0.439964 -0.152429)))))
                             ((R:segstate.parent.n.name is r)
                              ((name is ao_1)
                               ((R:segstate.parent.nn.ph_cplace is a)
                                ((0.919568 0.106765))
                                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                  <
                                  3.4)
                                 ((1.33493 1.17148))
                                 ((0.939371 0.517338))))
                               ((name is aa_1)
                                ((R:segstate.parent.R:SylStructure.parent.position_type
                                  is
                                  single)
                                 ((0.871824 0.0452411))
                                 ((0.3936 -0.410167)))
                                ((name is aa_2)
                                 ((R:segstate.parent.pp.ph_cplace is a)
                                  ((0.570098 -0.162044))
                                  ((R:segstate.parent.pp.ph_vrnd is -)
                                   ((0.383876 -0.439187))
                                   ((0.158705 -0.578428))))
                                 ((R:segstate.parent.p.name is dh)
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                    <
                                    0.3)
                                   ((0.0556558 -0.83989))
                                   ((0.191648 -0.711683)))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                    is
                                    0)
                                   ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                                     <
                                     0.1)
                                    ((0.0930372 -0.683759))
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                      is
                                      0)
                                     ((0.430518 -0.529177))
                                     ((0.147277 -0.6591))))
                                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                                     <
                                     6.1)
                                    ((0.068569 -0.736643))
                                    ((0.116456 -0.673898))))))))
                              ((name is ao_2)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                 <
                                 1.2)
                                ((0.431747 0.944634))
                                ((0.913235 1.29175)))
                               ((name is eh_2)
                                ((R:segstate.parent.R:SylStructure.parent.syl_out
                                  <
                                  4.6)
                                 ((0.949353 -0.0636839))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                   <
                                   1.3)
                                  ((1.00461 1.12692))
                                  ((0.878077 0.420048))))
                                ((name is aa_2)
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                   is
                                   0)
                                  ((1.75631 1.20719))
                                  ((0.803621 0.133157)))
                                 ((name is aa_1)
                                  ((1.10569 0.70084))
                                  ((R:segstate.parent.n.name is k)
                                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                     <
                                     1.8)
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                      <
                                      0.1)
                                     ((0.401695 -0.325681))
                                     ((0.630616 -0.503979)))
                                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                      <
                                      3.4)
                                     ((0.570778 0.0856737))
                                     ((0.352543 -0.373596))))
                                   ((R:segstate.parent.R:SylStructure.parent.position_type
                                     is
                                     mid)
                                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                      <
                                      0.9)
                                     ((1.28196 0.778107))
                                     ((0.745299 0.367783)))
                                    ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                                      <
                                      2.2)
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                       <
                                       0.3)
                                      ((name is ay_3)
                                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                         is
                                         0)
                                        ((0.992842 1.20417))
                                        ((1.20834 0.311591)))
                                       ((name is oy_3)
                                        ((1.22468 0.817321))
                                        ((name is ay_1)
                                         ((R:segstate.parent.nn.ph_cplace
                                           is
                                           0)
                                          ((1.2948 1.05664))
                                          ((0.644335 0.0693234)))
                                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                                           <
                                           7.9)
                                          ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                            <
                                            3.6)
                                           ((R:segstate.parent.R:SylStructure.parent.syl_in
                                             <
                                             1.6)
                                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                                              <
                                              6.4)
                                             ((2.04924 0.527872))
                                             ((0.872875 0.0294869)))
                                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                              <
                                              1.2)
                                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                                               <
                                               6.4)
                                              ((R:segstate.parent.pp.ph_ctype
                                                is
                                                0)
                                               ((0.509151 -0.157079))
                                               ((R:segstate.parent.pp.ph_cplace
                                                 is
                                                 a)
                                                ((0.747311 -0.00830306))
                                                ((0.726317 0.381785))))
                                              ((0.735041 -0.270136)))
                                             ((0.704203 -0.310185))))
                                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                                             is
                                             0)
                                            ((R:segstate.parent.pp.ph_cplace
                                              is
                                              0)
                                             ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                               <
                                               1.2)
                                              ((1.03986 0.472675))
                                              ((0.982221 0.0259844)))
                                             ((1.26697 0.863893)))
                                            ((0.924811 -0.0963551))))
                                          ((R:segstate.parent.ph_vheight
                                            is
                                            2)
                                           ((R:segstate.parent.lisp_coda_fric
                                             is
                                             0)
                                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                                              <
                                              9.4)
                                             ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                               <
                                               1.2)
                                              ((0.512678 -0.529201))
                                              ((0.846191 -0.137684)))
                                             ((R:segstate.parent.ph_vrnd
                                               is
                                               +)
                                              ((1.10964 0.269811))
                                              ((R:segstate.parent.n.ph_vc
                                                is
                                                +)
                                               ((0.755359 -0.155851))
                                               ((0.514512 0.000629912)))))
                                            ((0.938608 0.344566)))
                                           ((R:segstate.parent.lisp_onset_fric
                                             is
                                             0)
                                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                              is
                                              0)
                                             ((0.412706 -0.258422))
                                             ((0.872811 -0.104909)))
                                            ((0.436215 -0.440828))))))))
                                      ((R:segstate.parent.n.name
                                        is
                                        pau)
                                       ((name is ay_3)
                                        ((0.6197 -0.777098))
                                        ((R:segstate.parent.p.name
                                          is
                                          dh)
                                         ((0.429061 -0.617811))
                                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                           <
                                           2.7)
                                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                                            <
                                            0.3)
                                           ((0.938446 0.48101))
                                           ((0.805821 0.0626652)))
                                          ((R:segstate.parent.ph_vheight
                                            is
                                            2)
                                           ((0.772491 -0.126424))
                                           ((0.522449 -0.533861))))))
                                       ((name is ey_2)
                                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                          is
                                          0)
                                         ((1.30158 0.979275))
                                         ((1.09963 0.361246)))
                                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                          is
                                          0)
                                         ((R:segstate.parent.n.name
                                           is
                                           s)
                                          ((R:segstate.parent.R:SylStructure.parent.next_accent
                                            <
                                            1.4)
                                           ((0.576618 -0.362789))
                                           ((0.916733 0.0547392)))
                                          ((R:segstate.parent.lisp_coda_stop
                                            is
                                            0)
                                           ((R:segstate.parent.pp.ph_vlng
                                             is
                                             a)
                                            ((0.915866 0.429584))
                                            ((R:segstate.parent.ph_vheight
                                              is
                                              2)
                                             ((0.550039 -0.381569))
                                             ((0.550094 -0.0511234))))
                                           ((R:segstate.parent.ph_vheight
                                             is
                                             2)
                                            ((1.21738 0.778528))
                                            ((R:segstate.parent.pp.ph_vlng
                                              is
                                              a)
                                             ((0.477008 0.0045987))
                                             ((R:segstate.parent.nn.ph_cplace
                                               is
                                               a)
                                              ((1.29473 0.596115))
                                              ((0.710437 0.174202)))))))
                                         ((R:segstate.parent.n.name
                                           is
                                           d)
                                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                            is
                                            0)
                                           ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                             <
                                             1.2)
                                            ((0.89531 -0.191936))
                                            ((0.455693 -0.358188)))
                                           ((0.391046 -0.471792)))
                                          ((name is ae_1)
                                           ((0.378265 -0.330365))
                                           ((name is ah_1)
                                            ((0.814994 -0.330671))
                                            ((R:segstate.parent.ph_vrnd
                                              is
                                              +)
                                             ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                               <
                                               5.2)
                                              ((0.534144 -0.295415))
                                              ((0.71257 0.0355418)))
                                             ((name is ah_3)
                                              ((0.453514 -0.192051))
                                              ((R:segstate.parent.pp.ph_ctype
                                                is
                                                s)
                                               ((0.707029 -0.167397))
                                               ((R:segstate.parent.n.name
                                                 is
                                                 s)
                                                ((1.13972 0.438058))
                                                ((R:segstate.parent.R:SylStructure.parent.position_type
                                                  is
                                                  single)
                                                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                                                   <
                                                   1.2)
                                                  ((1.03876 0.0497972))
                                                  ((0.914368 0.508733)))
                                                 ((0.410014 -0.174098))))))))))))))
                                     ((R:segstate.parent.n.name is er)
                                      ((R:segstate.parent.pp.ph_vrnd
                                        is
                                        -)
                                       ((0.469689 -1.12729))
                                       ((0.759825 -0.668562)))
                                      ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                        <
                                        2.4)
                                       ((R:segstate.parent.p.name is t)
                                        ((0.320289 -0.385291))
                                        ((R:segstate.parent.R:SylStructure.parent.next_accent
                                          <
                                          3.2)
                                         ((R:segstate.parent.pp.ph_ctype
                                           is
                                           0)
                                          ((R:segstate.parent.R:SylStructure.parent.last_accent
                                            <
                                            2.7)
                                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                             is
                                             0)
                                            ((0.888648 -0.295848))
                                            ((0.680221 -0.058484)))
                                           ((0.956778 0.170406)))
                                          ((0.715541 -0.310542)))
                                         ((1.15509 0.252573))))
                                       ((0.924973 0.304889)))))))))))))))))))))))))
                ((name is ae_1)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 4)
                  ((R:segstate.parent.lisp_coda_stop is 0)
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     1.5)
                    ((R:segstate.parent.pp.ph_vc is +)
                     ((0.930962 1.39749))
                     ((0.99908 0.510894)))
                    ((1.1531 1.68512)))
                   ((0.602611 1.89004)))
                  ((1.09713 0.434275)))
                 ((name is iy_2)
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    3.6)
                   ((0.712785 1.5797))
                   ((0.927647 0.974462)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((name is ay_3)
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      4.8)
                     ((0.747945 -0.961869))
                     ((0.624533 -0.392371)))
                    ((R:segstate.parent.ph_vheight is 1)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                       <
                       2.4)
                      ((name is ih_2)
                       ((R:segstate.parent.nn.ph_cplace is a)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                          is
                          0)
                         ((1.08312 0.145393))
                         ((0.32871 -0.531596)))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                          <
                          0.3)
                         ((0.946671 -0.0471604))
                         ((0.962232 0.673766))))
                       ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                         <
                         2.2)
                        ((name is iy_1)
                         ((0.253677 -0.472807))
                         ((p.name is b_3)
                          ((0.111457 -0.422027))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                            is
                            0)
                           ((R:segstate.parent.n.name is m)
                            ((0.296227 -0.0339699))
                            ((name is ih_3)
                             ((0.214954 -0.53535))
                             ((0.672695 -0.192992))))
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                             <
                             3)
                            ((R:segstate.parent.n.name is m)
                             ((0.370429 -0.149687))
                             ((1.19583 0.387234)))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                              is
                              0)
                             ((0.67042 -0.029168))
                             ((0.351967 -0.34265)))))))
                        ((0.953208 0.2723))))
                      ((0.134212 -0.575002)))
                     ((name is ae_2)
                      ((R:segstate.parent.lisp_onset_stop is 0)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                         <
                         2.1)
                        ((0.638702 -0.181167))
                        ((0.418865 -0.367112)))
                       ((0.249513 -0.507383)))
                      ((R:segstate.parent.R:SylStructure.parent.position_type
                        is
                        single)
                       ((name is ey_3)
                        ((0.805692 -0.304913))
                        ((name is eh_1)
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           0.7)
                          ((1.11553 0.419495))
                          ((0.703882 -0.452749)))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                           <
                           0.4)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                            is
                            0)
                           ((0.871384 0.0765712))
                           ((0.617833 -0.308759)))
                          ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                            <
                            4.4)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                             is
                             0)
                            ((R:segstate.parent.R:SylStructure.parent.syl_in
                              <
                              4.2)
                             ((1.006 0.528039))
                             ((0.624328 0.0953186)))
                            ((R:segstate.parent.pp.ph_ctype is s)
                             ((0.855907 0.2248))
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               5.5)
                              ((R:segstate.parent.R:SylStructure.parent.syl_in
                                <
                                4.2)
                               ((R:segstate.parent.R:SylStructure.parent.syl_in
                                 <
                                 2.2)
                                ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                  <
                                  2.2)
                                 ((0.960887 0.378542))
                                 ((0.650097 0.728999)))
                                ((R:segstate.parent.R:SylStructure.parent.next_accent
                                  <
                                  2)
                                 ((1.19999 1.16381))
                                 ((0.974574 0.599023))))
                               ((0.916821 0.246457)))
                              ((1.09838 1.00682)))))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                             <
                             0.4)
                            ((0.758417 0.577856))
                            ((0.679125 -0.154312)))))))
                       ((R:segstate.parent.p.name is pau)
                        ((1.33498 0.718171))
                        ((name is aa_2)
                         ((0.817533 0.704717))
                         ((R:segstate.parent.p.name is n)
                          ((2.38471 0.904923))
                          ((R:segstate.parent.pp.ph_vlng is a)
                           ((R:segstate.parent.R:SylStructure.parent.position_type
                             is
                             initial)
                            ((R:segstate.parent.R:SylStructure.parent.syl_in
                              <
                              7.4)
                             ((0.765895 -0.0638259))
                             ((0.512379 -0.508995)))
                            ((R:segstate.parent.lisp_coda_stop is 0)
                             ((R:segstate.parent.R:SylStructure.parent.position_type
                               is
                               final)
                              ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                <
                                2.2)
                               ((1.44648 1.11658))
                               ((1.04126 0.627946)))
                              ((0.741984 0.0836629)))
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               4.6)
                              ((1.06157 0.0917662))
                              ((0.34852 -0.134111)))))
                           ((name is ae_3)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                              <
                              0.1)
                             ((0.979676 -0.177029))
                             ((2.3037 1.11133)))
                            ((name is ah_1)
                             ((0.982612 0.315617))
                             ((p.name is k_3)
                              ((R:segstate.parent.R:SylStructure.parent.next_accent
                                <
                                1.4)
                               ((0.422275 -0.354696))
                               ((0.318701 -0.491755)))
                              ((R:segstate.parent.nn.ph_cplace is p)
                               ((0.971918 0.312015))
                               ((name is eh_1)
                                ((0.485891 -0.386599))
                                ((R:segstate.parent.pp.ph_vlng is d)
                                 ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                                   <
                                   3.2)
                                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                                    <
                                    3.5)
                                   ((0.874898 0.0527201))
                                   ((0.617013 -0.139274)))
                                  ((0.254321 -0.448458)))
                                 ((name is ax_3)
                                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                                    <
                                    6.5)
                                   ((0.344035 -0.307857))
                                   ((0.485029 -0.0648047)))
                                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                                    <
                                    1.2)
                                   ((R:segstate.parent.p.name is k)
                                    ((0.441846 -0.346248))
                                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                      <
                                      5.5)
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                       is
                                       0)
                                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                                        <
                                        6)
                                       ((0.540602 0.0198863))
                                       ((0.893309 0.208304)))
                                      ((0.821155 -0.279974)))
                                     ((0.416309 -0.334586))))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                     <
                                     0.3)
                                    ((R:segstate.parent.lisp_onset_fric
                                      is
                                      0)
                                     ((1.53174 0.634468))
                                     ((0.586911 -0.0777308)))
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                      is
                                      0)
                                     ((0.417365 -0.29074))
                                     ((R:segstate.parent.pp.ph_cplace
                                       is
                                       a)
                                      ((1.2503 0.318914))
                                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                                        <
                                        5)
                                       ((0.475162 -0.37897))
                                       ((R:segstate.parent.pp.ph_vrnd
                                         is
                                         -)
                                        ((1.11417 0.350544))
                                        ((0.640901 -0.0578056)))))))))))))))))))))))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                     is
                     0)
                    ((name is ax_1)
                     ((0.365993 -0.433788))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       3.5)
                      ((R:segstate.parent.ph_vheight is 3)
                       ((0.931297 0.412857))
                       ((R:segstate.parent.R:SylStructure.parent.position_type
                         is
                         final)
                        ((R:segstate.parent.nn.ph_cplace is a)
                         ((0.443766 -0.290606))
                         ((0.72887 0.423385)))
                        ((R:segstate.parent.R:SylStructure.parent.position_type
                          is
                          initial)
                         ((0.685313 -0.0611))
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           1.2)
                          ((0.225637 -0.438778))
                          ((0.488899 -0.302313))))))
                      ((R:segstate.parent.ph_vheight is 2)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                         <
                         0.1)
                        ((0.887157 0.282045))
                        ((1.50376 0.729641)))
                       ((0.953108 -0.0242552)))))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      6)
                     ((R:segstate.parent.nn.ph_vlng is s)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.3)
                       ((0.322468 -0.396952))
                       ((0.214882 -0.539076)))
                      ((R:segstate.parent.R:SylStructure.parent.position_type
                        is
                        initial)
                       ((R:segstate.parent.p.name is hh)
                        ((0.240947 -0.544481))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                          <
                          0.3)
                         ((0.794152 -0.0447011))
                         ((R:segstate.parent.R:SylStructure.parent.next_accent
                           <
                           1.4)
                          ((0.272361 -0.433672))
                          ((0.475148 -0.286521)))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                         <
                         0.3)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          1.1)
                         ((R:segstate.parent.lisp_onset_fric is 0)
                          ((R:segstate.parent.R:SylStructure.parent.position_type
                            is
                            final)
                           ((1.11887 0.225359))
                           ((1.03163 -0.24813)))
                          ((0.478942 -0.355256)))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                           is
                           0)
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            8.6)
                           ((0.705425 -0.164913))
                           ((0.273223 -0.437816)))
                          ((0.165623 -0.478383))))
                        ((R:segstate.parent.pp.ph_vfront is 2)
                         ((0.303662 -0.39533))
                         ((R:segstate.parent.lisp_coda_fric is 0)
                          ((R:segstate.parent.R:SylStructure.parent.sub_phrases
                            <
                            0.1)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                             is
                             0)
                            ((R:segstate.parent.R:SylStructure.parent.asyl_out
                              <
                              2.2)
                             ((0.771552 -0.0879714))
                             ((1.12949 0.302523)))
                            ((R:segstate.parent.R:SylStructure.parent.position_type
                              is
                              single)
                             ((0.457047 -0.47424))
                             ((name is ax_1)
                              ((0.608157 -0.304302))
                              ((R:segstate.parent.nn.ph_cplace is a)
                               ((0.725664 -0.119626))
                               ((0.748525 0.114362))))))
                           ((0.406186 -0.350579)))
                          ((0.840471 0.243314)))))))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       2.8)
                      ((0.366312 -0.316617))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.1)
                       ((0.119269 -0.578419))
                       ((0.337389 -0.48752))))))))))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                 is
                 0)
                ((name is ah_1)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                   is
                   0)
                  ((0.619291 1.14608))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                    is
                    0)
                   ((0.378904 0.938188))
                   ((1.00695 0.506835))))
                 ((name is aa_1)
                  ((R:segstate.parent.lisp_onset_stop is 0)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                     is
                     0)
                    ((1.07994 0.89579))
                    ((1.07817 0.329806)))
                   ((0.756113 1.32424)))
                  ((name is ih_2)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                     is
                     0)
                    ((R:segstate.parent.n.name is r)
                     ((0.599144 -0.0471604))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                       is
                       0)
                      ((R:segstate.parent.nn.ph_vrnd is -)
                       ((0.934353 1.11371))
                       ((0.883754 0.391335)))
                      ((0.781529 0.0698183))))
                    ((R:segstate.parent.nn.ph_vlng is a)
                     ((1.19481 1.55999))
                     ((1.02989 0.440759))))
                   ((name is ae_2)
                    ((R:segstate.parent.n.name is n)
                     ((0.505666 -0.409146))
                     ((R:segstate.parent.nn.ph_vlng is a)
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        1.3)
                       ((0.643303 1.35132))
                       ((0.901627 0.730737)))
                      ((0.794998 0.346002))))
                    ((name is ae_1)
                     ((R:segstate.parent.n.name is n)
                      ((0.977188 1.60906))
                      ((R:segstate.parent.pos_in_syl is 1)
                       ((R:segstate.parent.R:SylStructure.parent.asyl_in
                         <
                         1.4)
                        ((0.490514 -0.24734))
                        ((1.03747 0.43925)))
                       ((1.05742 0.710714))))
                     ((name is ao_3)
                      ((1.53483 0.834906))
                      ((R:segstate.parent.nn.ph_cplace is a)
                       ((name is ih_3)
                        ((1.44428 2.17171))
                        ((name is ih_1)
                         ((0.282012 -0.277723))
                         ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                           <
                           2.4)
                          ((R:segstate.parent.R:SylStructure.parent.asyl_out
                            <
                            1.5)
                           ((0.697985 -0.000434954))
                           ((0.547236 -0.23423)))
                          ((R:segstate.parent.R:SylStructure.parent.asyl_in
                            <
                            1.2)
                           ((1.21833 0.607008))
                           ((0.702066 0.116968))))))
                       ((p.name is m_3)
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                          <
                          2.4)
                         ((0.421902 -0.596803))
                         ((0.679466 -0.179492)))
                        ((name is ey_1)
                         ((R:segstate.parent.lisp_onset_fric is 0)
                          ((R:segstate.parent.R:SylStructure.parent.syl_in
                            <
                            5.5)
                           ((0.671064 -0.427386))
                           ((0.503282 -0.80306)))
                          ((0.69242 -0.01394)))
                         ((name is uw_3)
                          ((0.221165 -0.483096))
                          ((p.name is p_3)
                           ((0.513248 -0.432691))
                           ((R:segstate.parent.R:SylStructure.parent.position_type
                             is
                             single)
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                              <
                              6)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                               is
                               0)
                              ((0.778843 0.212693))
                              ((R:segstate.parent.R:SylStructure.parent.syl_in
                                <
                                1.6)
                               ((0.610001 -0.181185))
                               ((0.67958 -0.21011))))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                               <
                               0.4)
                              ((0.575107 -0.317302))
                              ((0.500089 -0.606972))))
                            ((name is iy_2)
                             ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                               <
                               2.3)
                              ((R:segstate.parent.nn.ph_vlng is a)
                               ((0.944748 0.103811))
                               ((0.933812 0.558216)))
                              ((0.731362 0.88207)))
                             ((R:segstate.parent.R:SylStructure.parent.position_type
                               is
                               final)
                              ((1.71127 0.812687))
                              ((name is aa_3)
                               ((R:segstate.parent.R:SylStructure.parent.syl_out
                                 <
                                 3.4)
                                ((0.636804 -0.0968938))
                                ((0.358314 -0.500491)))
                               ((name is ay_1)
                                ((0.681658 -0.406108))
                                ((name is ih_3)
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                   <
                                   0.3)
                                  ((1.02366 0.132675))
                                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                    <
                                    5)
                                   ((R:segstate.parent.nn.ph_vlng is a)
                                    ((0.112261 -0.587339))
                                    ((0.249056 -0.462547)))
                                   ((0.939173 -0.0601851))))
                                 ((R:segstate.parent.p.name is n)
                                  ((R:segstate.parent.ph_vheight is 2)
                                   ((R:segstate.parent.n.name is t)
                                    ((1.2504 0.441892))
                                    ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                      <
                                      1.5)
                                     ((p.name is n_3)
                                      ((0.927158 0.369141))
                                      ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                                        <
                                        2.4)
                                       ((0.636639 -0.435973))
                                       ((0.786545 0.308824))))
                                     ((0.702935 -0.183741))))
                                   ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                                     <
                                     2.2)
                                    ((1.50652 1.68433))
                                    ((1.29275 0.339958))))
                                  ((R:segstate.parent.pp.ph_vlng is d)
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                     is
                                     0)
                                    ((R:segstate.parent.R:SylStructure.parent.position_type
                                      is
                                      initial)
                                     ((0.592739 -0.257611))
                                     ((0.147918 -0.556634)))
                                    ((0.714314 -0.0792383)))
                                   ((R:segstate.parent.n.name is r)
                                    ((name is eh_2)
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                       <
                                       0.3)
                                      ((0.0348301 -0.856418))
                                      ((0.333715 -0.685354)))
                                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                                       <
                                       3.8)
                                      ((1.06439 0.41937))
                                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                                        <
                                        7.3)
                                       ((0.640596 -0.274765))
                                       ((0.960789 0.333606)))))
                                    ((name is eh_2)
                                     ((R:segstate.parent.nn.ph_vlng
                                       is
                                       a)
                                      ((R:segstate.parent.lisp_onset_stop
                                        is
                                        0)
                                       ((0.658095 0.944596))
                                       ((0.510047 0.386576)))
                                      ((0.812007 0.0829474)))
                                     ((R:segstate.parent.pp.ph_ctype
                                       is
                                       r)
                                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                        <
                                        1.6)
                                       ((R:segstate.parent.ph_vheight
                                         is
                                         2)
                                        ((0.905114 0.269587))
                                        ((0.809042 -0.180457)))
                                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                                         <
                                         9)
                                        ((0.51165 -0.516904))
                                        ((0.539074 -0.238963))))
                                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                                        <
                                        6.7)
                                       ((R:segstate.parent.nn.ph_vlng
                                         is
                                         s)
                                        ((R:segstate.parent.ph_vheight
                                          is
                                          2)
                                         ((0.745338 -0.0666384))
                                         ((1.68747 0.905249)))
                                        ((name is ae_3)
                                         ((0.455771 -0.347314))
                                         ((R:segstate.parent.pp.ph_vfront
                                           is
                                           2)
                                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                            is
                                            0)
                                           ((0.622008 0.0129995))
                                           ((0.949138 0.524406)))
                                          ((R:segstate.parent.p.name
                                            is
                                            s)
                                           ((R:segstate.parent.pp.ph_cplace
                                             is
                                             a)
                                            ((0.259483 -0.358212))
                                            ((0.450913 -0.157376)))
                                           ((name is aa_2)
                                            ((0.470179 -0.283736))
                                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                              is
                                              0)
                                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                               is
                                               0)
                                              ((R:segstate.parent.ph_vheight
                                                is
                                                1)
                                               ((0.846766 -0.264431))
                                               ((R:segstate.parent.R:SylStructure.parent.syl_in
                                                 <
                                                 5.7)
                                                ((R:segstate.parent.R:SylStructure.parent.syl_in
                                                  <
                                                  4.5)
                                                 ((0.698901 0.00584185))
                                                 ((0.474846 -0.196201)))
                                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                                  <
                                                  1.2)
                                                 ((R:segstate.parent.pp.ph_vrnd
                                                   is
                                                   -)
                                                  ((0.652963 0.0845996))
                                                  ((0.571524 -0.158177)))
                                                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                                   <
                                                   2.4)
                                                  ((0.522508 0.0616774))
                                                  ((0.819384 0.280209))))))
                                              ((R:segstate.parent.ph_vheight
                                                is
                                                2)
                                               ((R:segstate.parent.R:SylStructure.parent.position_type
                                                 is
                                                 initial)
                                                ((0.485335 -0.327816))
                                                ((0.543967 -0.362664)))
                                               ((0.737456 0.0911276))))
                                             ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                               <
                                               0.2)
                                              ((0.570947 -0.0991812))
                                              ((R:segstate.parent.R:SylStructure.parent.position_type
                                                is
                                                initial)
                                               ((0.844735 0.171589))
                                               ((1.25686 0.401998))))))))))
                                       ((name is ow_3)
                                        ((0.644699 -0.450225))
                                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                                          <
                                          6)
                                         ((R:segstate.parent.n.name
                                           is
                                           n)
                                          ((1.60866 0.857279))
                                          ((R:segstate.parent.pp.ph_vfront
                                            is
                                            3)
                                           ((0.643905 -0.119776))
                                           ((R:segstate.parent.ph_vheight
                                             is
                                             1)
                                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                                              <
                                              0.3)
                                             ((0.956454 0.531374))
                                             ((1.35377 0.873021)))
                                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                              <
                                              0.3)
                                             ((R:segstate.parent.pp.ph_vc
                                               is
                                               +)
                                              ((0.672403 0.133268))
                                              ((0.585397 -0.111157)))
                                             ((R:segstate.parent.R:SylStructure.parent.last_accent
                                               <
                                               2.1)
                                              ((R:segstate.parent.R:SylStructure.parent.next_accent
                                                <
                                                1.4)
                                               ((1.12916 0.939835))
                                               ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                                                 <
                                                 2.3)
                                                ((0.738292 0.143048))
                                                ((1.07541 0.513515))))
                                              ((0.730287 0.101345)))))))
                                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                           <
                                           3.4)
                                          ((0.621621 -0.262452))
                                          ((R:segstate.parent.pp.ph_vc
                                            is
                                            +)
                                           ((R:segstate.parent.pp.ph_vlng
                                             is
                                             a)
                                            ((0.474723 -0.00716734))
                                            ((1.40458 0.653472)))
                                           ((0.572064 -0.0838579)))))))))))))))))))))))))))))
                ((p.name is b_3)
                 ((R:segstate.parent.n.name is g)
                  ((0.991645 1.69147))
                  ((1.2397 0.408844)))
                 ((name is ay_1)
                  ((R:segstate.parent.n.name is hh)
                   ((0.630225 -0.108929))
                   ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                     <
                     2.2)
                    ((R:segstate.parent.nn.ph_vlng is s)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       1.6)
                      ((0.415335 -0.764299))
                      ((0.433265 -0.551009)))
                     ((R:segstate.parent.pp.ph_vc is 0)
                      ((0.366481 -0.628502))
                      ((0.461361 -0.244515))))
                    ((0.282652 -0.863329))))
                  ((R:segstate.parent.pp.ph_vc is -)
                   ((name is iy_1)
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      2.6)
                     ((R:segstate.parent.n.name is hh)
                      ((0.967453 0.672498))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                        <
                        0.3)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                         <
                         0.1)
                        ((0.386625 -0.32049))
                        ((R:segstate.parent.nn.ph_vlng is l)
                         ((0.417209 -0.159105))
                         ((0.55657 0.188421))))
                       ((1.35419 0.427501))))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                       is
                       0)
                      ((0.292072 -0.465144))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                        <
                        3.1)
                       ((0.468191 -0.333091))
                       ((0.816597 0.0713187)))))
                    ((R:segstate.parent.p.name is hh)
                     ((R:segstate.parent.pp.ph_cplace is a)
                      ((R:segstate.parent.R:SylStructure.parent.next_accent
                        <
                        1.4)
                       ((0.745146 -0.0307551))
                       ((0.539071 -0.353726)))
                      ((R:segstate.parent.nn.ph_vrnd is +)
                       ((0.443168 -0.182834))
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         11.8)
                        ((R:segstate.parent.nn.ph_vlng is s)
                         ((0.359994 -0.755411))
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           7)
                          ((0.380815 -0.673234))
                          ((0.456191 -0.532881))))
                        ((0.501944 -0.417601)))))
                     ((R:segstate.parent.n.name is m)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        7.4)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                         <
                         0.1)
                        ((0.477508 -0.242157))
                        ((0.529354 -0.502628)))
                       ((0.440469 -0.611329)))
                      ((R:segstate.parent.n.name is d)
                       ((R:segstate.parent.ph_vheight is 2)
                        ((0.346935 -0.240577))
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          5.5)
                         ((0.639696 0.432023))
                         ((0.636313 0.0584007))))
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         15.2)
                        ((name is ax_3)
                         ((R:segstate.parent.R:SylStructure.parent.last_accent
                           <
                           0.7)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                            is
                            0)
                           ((0.555043 0.0781346))
                           ((1.27666 0.389806)))
                          ((0.50939 -0.209891)))
                         ((name is ow_1)
                          ((0.724737 0.128959))
                          ((R:segstate.parent.n.name is w)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                             is
                             0)
                            ((0.387069 -0.60311))
                            ((0.356291 -0.442967)))
                           ((name is iy_2)
                            ((0.635756 0.177378))
                            ((R:segstate.parent.nn.ph_vlng is s)
                             ((R:segstate.parent.pos_in_syl is 1)
                              ((R:segstate.parent.R:SylStructure.parent.position_type
                                is
                                single)
                               ((R:segstate.parent.ph_vrnd is +)
                                ((0.684677 0.0460137))
                                ((R:segstate.parent.n.name is hh)
                                 ((0.540988 -0.48531))
                                 ((0.63378 -0.223735))))
                               ((R:segstate.parent.R:SylStructure.parent.next_accent
                                 <
                                 1.2)
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                  is
                                  0)
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                   is
                                   0)
                                  ((0.343498 -0.730288))
                                  ((0.264979 -0.529099)))
                                 ((0.354692 -0.480129)))
                                ((0.32588 -0.333471))))
                              ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                <
                                3.7)
                               ((0.637044 -0.211244))
                               ((0.637181 0.0630264))))
                             ((R:segstate.parent.pp.ph_ctype is n)
                              ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                <
                                2)
                               ((1.08175 0.526146))
                               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                 <
                                 4.2)
                                ((0.623985 0.114535))
                                ((0.785691 -0.174858))))
                              ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                <
                                9)
                               ((name is ih_3)
                                ((1.00282 0.189891))
                                ((R:segstate.parent.ph_vheight is 1)
                                 ((R:segstate.parent.pp.ph_ctype is 0)
                                  ((0.636507 -0.221543))
                                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                    <
                                    2.5)
                                   ((0.507616 -0.350284))
                                   ((0.181752 -0.624872))))
                                 ((R:segstate.parent.p.name is dh)
                                  ((0.345854 -0.443182))
                                  ((R:segstate.parent.n.name is p)
                                   ((0.378369 -0.359156))
                                   ((R:segstate.parent.ph_vheight is 2)
                                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                      <
                                      1.6)
                                     ((0.685428 -0.266387))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                       is
                                       0)
                                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                        <
                                        0.1)
                                       ((1.14643 0.42224))
                                       ((0.77513 0.0424794)))
                                      ((1.142 -0.161857))))
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                      is
                                      0)
                                     ((0.592222 -0.0644514))
                                     ((0.586682 -0.398001))))))))
                               ((0.526267 -0.635336)))))))))
                        ((0.583194 0.216044)))))))
                   ((name is ih_2)
                    ((0.381779 -0.497907))
                    ((R:segstate.parent.lisp_onset_fric is 0)
                     ((name is ih_1)
                      ((0.150994 -0.386593))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        15.7)
                       ((R:segstate.parent.p.name is jh)
                        ((1.13072 -0.440769))
                        ((R:segstate.parent.p.name is r)
                         ((0.359414 -0.390861))
                         ((name is iy_1)
                          ((0.520082 -0.349092))
                          ((R:segstate.parent.n.name is m)
                           ((0.367839 -0.316298))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                             is
                             0)
                            ((R:segstate.parent.pp.ph_vlng is s)
                             ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                               <
                               4.8)
                              ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                <
                                0.1)
                               ((1.12138 0.318676))
                               ((0.665318 -0.338272)))
                              ((0.884072 0.568041)))
                             ((name is ax_2)
                              ((1.24131 0.521266))
                              ((name is ay_3)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                 is
                                 0)
                                ((1.02215 -0.451927))
                                ((0.672309 -0.215194)))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                 is
                                 0)
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                                  <
                                  0.3)
                                 ((0.64183 0.0825296))
                                 ((0.832971 0.345685)))
                                ((R:segstate.parent.ph_vrnd is +)
                                 ((0.562916 -0.351567))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                   is
                                   0)
                                  ((R:segstate.parent.R:SylStructure.parent.position_type
                                    is
                                    initial)
                                   ((0.968057 0.199382))
                                   ((0.432586 -0.154534)))
                                  ((0.49664 -0.253371))))))))
                            ((R:segstate.parent.n.name is t)
                             ((1.58679 0.767977))
                             ((name is iy_2)
                              ((0.598251 0.631083))
                              ((R:segstate.parent.p.name is t)
                               ((0.511557 -0.161908))
                               ((R:segstate.parent.pp.ph_vlng is d)
                                ((0.740202 -0.0796493))
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                  <
                                  0.3)
                                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                   <
                                   1.2)
                                  ((1.30694 0.602261))
                                  ((R:segstate.parent.nn.ph_vlng is l)
                                   ((0.843145 -0.00619659))
                                   ((0.788647 0.403068))))
                                 ((R:segstate.parent.R:SylStructure.parent.position_type
                                   is
                                   initial)
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                    <
                                    1.2)
                                   ((R:segstate.parent.pp.ph_vlng is s)
                                    ((0.910154 0.0916648))
                                    ((0.480339 -0.342853)))
                                   ((1.03626 0.285915)))
                                  ((R:segstate.parent.nn.ph_vlng is d)
                                   ((1.49249 0.494512))
                                   ((0.959432 0.130987))))))))))))))
                       ((1.09942 0.576623))))
                     ((R:segstate.parent.ph_vheight is 3)
                      ((0.777935 0.144978))
                      ((R:segstate.parent.R:SylStructure.parent.asyl_in
                        <
                        1.5)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                         is
                         0)
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                          <
                          1.2)
                         ((0.715917 0.0246587))
                         ((0.615789 -0.114048)))
                        ((0.717557 -0.313084)))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         2.2)
                        ((0.359885 -0.561619))
                        ((0.419963 -0.325628)))))))))))))))
           ((R:segstate.parent.n.name is 0)
            ((R:segstate.parent.p.name is ey)
             ((2.75887 2.58165))
             ((R:segstate.parent.p.name is s)
              ((R:segstate.parent.pp.ph_ctype is s)
               ((0.344965 -0.658005))
               ((R:segstate.parent.pp.ph_vfront is 2)
                ((0.215288 -0.571903))
                ((0.374027 -0.5366))))
              ((R:segstate.parent.p.name is t)
               ((R:segstate.parent.pp.ph_vlng is s)
                ((0.563339 -0.559096))
                ((R:segstate.parent.pp.ph_ctype is f)
                 ((0.551212 -0.50524))
                 ((name is pau_2)
                  ((0.543483 -0.363754))
                  ((R:segstate.parent.pp.ph_cplace is a)
                   ((0.41444 -0.20925))
                   ((0.792897 -0.259272))))))
               ((R:segstate.parent.p.name is z)
                ((R:segstate.parent.pp.ph_vlng is a)
                 ((0.300791 -0.582279))
                 ((R:segstate.parent.pp.ph_cplace is a)
                  ((0.452376 -0.418303))
                  ((0.220686 -0.506044))))
                ((R:segstate.parent.p.name is m)
                 ((R:segstate.parent.pp.ph_vlng is s)
                  ((0.677036 0.779838))
                  ((1.12531 1.55519)))
                 ((R:segstate.parent.p.name is r)
                  ((0.802972 1.24911))
                  ((R:segstate.parent.p.name is er)
                   ((R:segstate.parent.pp.ph_ctype is f)
                    ((1.01746 0.977077))
                    ((0.679198 0.962394)))
                   ((R:segstate.parent.p.name is f)
                    ((0.576902 -0.448635))
                    ((p.name is pau_1)
                     ((R:segstate.parent.p.name is k)
                      ((1.47284 0.874749))
                      ((R:segstate.parent.pp.ph_vlng is d)
                       ((name is pau_2)
                        ((0.792206 0.557786))
                        ((1.25544 0.742443)))
                       ((R:segstate.parent.p.ph_vc is +)
                        ((1.80904 0.806719))
                        ((R:segstate.parent.p.name is ng)
                         ((0.820329 0.583704))
                         ((name is pau_2)
                          ((R:segstate.parent.p.name is d)
                           ((R:segstate.parent.pp.ph_vrnd is -)
                            ((0.744922 0.405915))
                            ((0.982275 0.256378)))
                           ((0.547584 -0.168195)))
                          ((R:segstate.parent.pp.ph_vrnd is +)
                           ((0.95943 0.655535))
                           ((R:segstate.parent.pp.ph_vlng is l)
                            ((0.819598 -0.0755134))
                            ((R:segstate.parent.pp.ph_cplace is a)
                             ((0.765253 0.175632))
                             ((R:segstate.parent.p.name is d)
                              ((0.792265 0.547623))
                              ((R:segstate.parent.p.name is l)
                               ((0.734959 0.427716))
                               ((R:segstate.parent.pp.ph_vlng is a)
                                ((0.685476 0.254258))
                                ((1.01808 0.257237)))))))))))))
                     ((R:segstate.parent.pp.ph_vrnd is -)
                      ((R:segstate.parent.p.name is d)
                       ((0.619003 -0.0329954))
                       ((0.470578 -0.420114)))
                      ((1.17604 0.312934))))))))))))
            ((R:segstate.parent.ph_vheight is 3)
             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
               is
               in)
              ((name is aa_2)
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 2.1)
                ((0.529008 0.323566))
                ((1.37684 1.39938)))
               ((name is ao_2)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 4)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                   is
                   0)
                  ((0.0192685 -0.752138))
                  ((0.0391322 -0.731133)))
                 ((0.2619 -0.600297)))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 1)
                 ((R:segstate.parent.nn.ph_cplace is 0)
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    0.2)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                     <
                     0.2)
                    ((0.805641 0.619114))
                    ((0.713163 0.349291)))
                   ((0.737328 -0.239763)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((R:segstate.parent.n.name is t)
                    ((0.806213 0.0380974))
                    ((0.634526 0.291308)))
                   ((R:segstate.parent.p.name is f)
                    ((0.437071 -0.299609))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      0.3)
                     ((R:segstate.parent.nn.ph_cplace is d)
                      ((0.542115 -0.254636))
                      ((0.732749 -0.100526)))
                     ((0.705696 0.0481574))))))
                 ((name is ae_3)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                    is
                    0)
                   ((1.45067 0.639099))
                   ((R:segstate.parent.n.name is t)
                    ((R:segstate.parent.p.name is dh)
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       2.4)
                      ((0.347648 -0.324873))
                      ((0.7017 0.0209778)))
                     ((1.32309 0.553116)))
                    ((0.567473 -0.34377))))
                  ((name is aa_3)
                   ((1.71287 0.52393))
                   ((R:segstate.parent.R:SylStructure.parent.position_type
                     is
                     single)
                    ((name is ay_2)
                     ((0.693504 0.196612))
                     ((R:segstate.parent.n.name is n)
                      ((name is aa_1)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         4.6)
                        ((0.672086 -0.30732))
                        ((0.147385 -0.547655)))
                       ((0.664141 0.186587)))
                      ((R:segstate.parent.p.name is dh)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                         <
                         0.3)
                        ((0.81409 0.0116673))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                          <
                          3.1)
                         ((R:segstate.parent.pp.ph_ctype is 0)
                          ((0.109755 -0.667014))
                          ((0.396386 -0.481379)))
                         ((0.697366 -0.115014))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                         <
                         0.2)
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          4.2)
                         ((1.01532 -0.183039))
                         ((0.472028 -0.510813)))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                          is
                          0)
                         ((R:segstate.parent.p.name is b)
                          ((0.399919 -1.0724))
                          ((name is ae_2)
                           ((0.215117 -0.621673))
                           ((name is ao_1)
                            ((0.0371275 -0.701253))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                              is
                              0)
                             ((0.228239 -0.733851))
                             ((0.06382 -0.851933))))))
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           3.4)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                            <
                            0.1)
                           ((0.440945 -0.471322))
                           ((0.366889 -0.63902)))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                            is
                            0)
                           ((0.298934 -0.757891))
                           ((0.281625 -0.678794)))))))))
                    ((R:segstate.parent.p.name is f)
                     ((1.11124 0.808759))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       1.4)
                      ((0.707382 0.108838))
                      ((0.688485 -0.321588))))))))))
              ((name is ae_3)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                 <
                 1.2)
                ((R:segstate.parent.n.name is v)
                 ((0.675669 -0.14114))
                 ((R:segstate.parent.pp.ph_vlng is l)
                  ((0.439364 -0.414635))
                  ((0.184569 -0.676442))))
                ((R:segstate.parent.pp.ph_vrnd is -)
                 ((1.14409 0.640074))
                 ((R:segstate.parent.pp.ph_ctype is s)
                  ((1.4194 0.505431))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                    is
                    0)
                   ((0.793893 0.0271648))
                   ((0.647101 -0.356095))))))
               ((R:segstate.parent.n.name is er)
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  6.8)
                 ((0.284045 -1.23207))
                 ((0.871413 -0.691274)))
                ((R:segstate.parent.n.name is n)
                 ((name is ae_1)
                  ((0.157178 -0.796931))
                  ((0.167747 -0.649924)))
                 ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                   is
                   aux)
                  ((R:segstate.parent.nn.ph_cplace is 0)
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     6.4)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                       <
                       0.1)
                      ((0.493746 -0.387394))
                      ((0.797756 0.0265526)))
                     ((0.393152 -0.461409)))
                    ((0.225995 -0.609098)))
                   ((R:segstate.parent.pp.ph_ctype is f)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      7.4)
                     ((0.184628 -0.58638))
                     ((0.093044 -0.707478)))
                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                      <
                      3.3)
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       0.6)
                      ((R:segstate.parent.n.name is d)
                       ((name is ae_1)
                        ((0.401964 -0.311636))
                        ((0.264101 -0.559086)))
                       ((R:segstate.parent.pp.ph_vc is +)
                        ((0.345517 -0.634567))
                        ((0.509012 -0.462437))))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                        <
                        2.7)
                       ((0.0936307 -0.726532))
                       ((R:segstate.parent.R:SylStructure.parent.last_accent
                         <
                         2.5)
                        ((0.408911 -0.467909))
                        ((0.266303 -0.592667)))))
                     ((name is ae_2)
                      ((0.433026 -0.50576))
                      ((0.669836 -0.152683))))))
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    0.4)
                   ((0.833841 -0.0243887))
                   ((0.682447 -0.407225))))))))
             ((name is pau_3)
              ((R:segstate.parent.n.seg_onsetcoda is coda)
               ((R:segstate.parent.pp.ph_vc is +)
                ((1.0976 -0.472656))
                ((1.22422 -0.252257)))
               ((R:segstate.parent.nn.ph_vlng is d)
                ((R:segstate.parent.p.name is 0)
                 ((0.599407 -0.793806))
                 ((1.3109 0.0697123)))
                ((R:segstate.parent.nn.ph_vlng is s)
                 ((R:segstate.parent.n.name is w)
                  ((0.548087 -1.04701))
                  ((0.742563 -0.751761)))
                 ((R:segstate.parent.nn.ph_vlng is l)
                  ((0.858363 -0.662566))
                  ((0.764387 -0.7599))))))
              ((name is ah_1)
               ((R:segstate.parent.n.name is v)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                   <
                   0.3)
                  ((0.145434 -0.760541))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                    is
                    0)
                   ((0.326781 -0.671603))
                   ((0.64613 -0.511513))))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                   <
                   3.6)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                    <
                    0.4)
                   ((0.114967 -0.757926))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                     <
                     0.1)
                    ((0.0628888 -0.790187))
                    ((R:segstate.parent.pp.ph_cplace is a)
                     ((1.7708e-06 -0.80501))
                     ((1.55275e-06 -0.805011)))))
                  ((0.273912 -0.710513))))
                ((R:segstate.parent.pp.ph_vc is +)
                 ((0.920359 0.652216))
                 ((0.712621 0.0621408))))
               ((R:segstate.parent.p.seg_onsetcoda is coda)
                ((R:segstate.parent.ph_vheight is 2)
                 ((p.name is n_3)
                  ((1.8189 1.46632))
                  ((p.name is d_3)
                   ((1.52817 0.984644))
                   ((name is ax_2)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      0.4)
                     ((1.27164 2.31088))
                     ((R:segstate.parent.n.name is s)
                      ((1.1133 0.853973))
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        2.1)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         3.2)
                        ((1.19239 0.370034))
                        ((R:segstate.parent.pp.ph_ctype is 0)
                         ((R:segstate.parent.pp.ph_vlng is s)
                          ((0.608839 -0.0955099))
                          ((0.482892 -0.349129)))
                         ((0.659622 0.125517))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                         is
                         0)
                        ((1.00533 0.196639))
                        ((1.01942 0.602782))))))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      1.2)
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       2)
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        3)
                       ((name is ax_1)
                        ((0.336446 -0.40886))
                        ((R:segstate.parent.nn.ph_vrnd is -)
                         ((1.22137 0.0787252))
                         ((0.378614 -0.28706))))
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         5)
                        ((0.495043 -0.352094))
                        ((0.212397 -0.609197))))
                      ((1.47209 0.390337)))
                     ((R:segstate.parent.nn.ph_cplace is l)
                      ((1.6661 0.75551))
                      ((R:segstate.parent.p.name is r)
                       ((0.340859 -0.357472))
                       ((R:segstate.parent.p.name is l)
                        ((0.389719 -0.427579))
                        ((R:segstate.parent.p.name is s)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                           is
                           0)
                          ((0.514397 -0.153666))
                          ((0.445831 -0.334807)))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                           <
                           1.2)
                          ((R:segstate.parent.R:SylStructure.parent.last_accent
                            <
                            4.5)
                           ((R:segstate.parent.nn.ph_cplace is a)
                            ((R:segstate.parent.pp.ph_cplace is a)
                             ((0.842647 -0.00546139))
                             ((R:segstate.parent.R:SylStructure.parent.asyl_out
                               <
                               2.2)
                              ((1.36412 0.881607))
                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                <
                                7.4)
                               ((0.627869 -0.0507999))
                               ((1.03902 0.733898)))))
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                              <
                              6.3)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                               is
                               0)
                              ((R:segstate.parent.pp.ph_vlng is s)
                               ((R:segstate.parent.R:SylStructure.parent.syl_in
                                 <
                                 6.5)
                                ((1.39665 0.882051))
                                ((1.29643 0.456203)))
                               ((R:segstate.parent.nn.ph_cplace is 0)
                                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                  <
                                  4.6)
                                 ((0.407915 -0.288728))
                                 ((1.1558 0.0878383)))
                                ((1.43246 0.55505))))
                              ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                <
                                4.6)
                               ((R:segstate.parent.R:SylStructure.parent.syl_in
                                 <
                                 6)
                                ((R:segstate.parent.R:SylStructure.parent.syl_out
                                  <
                                  4.1)
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                   is
                                   0)
                                  ((0.656811 -0.0354237))
                                  ((0.892882 0.201639)))
                                 ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                                   is
                                   det)
                                  ((1.44595 0.854956))
                                  ((1.08064 0.263781))))
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                  <
                                  0.3)
                                 ((0.522482 -0.245593))
                                 ((0.759083 0.0553315))))
                               ((R:segstate.parent.R:SylStructure.parent.next_accent
                                 <
                                 1.1)
                                ((0.597773 -0.333296))
                                ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                                  is
                                  det)
                                 ((0.685706 -0.221079))
                                 ((0.765795 0.141174))))))
                             ((0.602336 -0.206686))))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                             <
                             0.3)
                            ((0.234278 -0.523987))
                            ((1.19708 0.0696873))))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                            is
                            0)
                           ((1.03867 0.223531))
                           ((R:segstate.parent.R:SylStructure.parent.syl_in
                             <
                             6.5)
                            ((0.973159 0.423355))
                            ((1.4632 1.11114)))))))))))))
                 ((R:segstate.parent.n.name is ae)
                  ((R:segstate.parent.pp.ph_vlng is a)
                   ((2.49378 1.36474))
                   ((R:segstate.parent.pp.ph_vfront is 1)
                    ((1.61926 0.610007))
                    ((R:segstate.parent.pp.ph_cplace is a)
                     ((0.923791 -0.054977))
                     ((R:segstate.parent.pp.ph_ctype is 0)
                      ((R:segstate.parent.pp.ph_vrnd is -)
                       ((0.84988 0.0995162))
                       ((1.44913 0.104981)))
                      ((1.28858 0.367801))))))
                  ((R:segstate.parent.n.name is w)
                   ((p.name is z_3)
                    ((0.64899 0.911866))
                    ((p.name is s_3)
                     ((0.729009 0.730828))
                     ((R:segstate.parent.p.ph_vc is +)
                      ((0.966039 0.466323))
                      ((p.name is t_3)
                       ((R:segstate.parent.nn.ph_vlng is l)
                        ((0.776967 0.277396))
                        ((0.975199 0.231099)))
                       ((R:segstate.parent.pp.ph_vfront is 1)
                        ((0.363836 -0.228212))
                        ((R:segstate.parent.nn.ph_vlng is l)
                         ((0.525402 -0.248349))
                         ((R:segstate.parent.pp.ph_vc is +)
                          ((0.775347 0.0700406))
                          ((0.595778 -0.019337)))))))))
                   ((R:segstate.parent.n.seg_onsetcoda is coda)
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      4.4)
                     ((R:segstate.parent.nn.ph_vlng is s)
                      ((R:segstate.parent.p.name is pau)
                       ((0.563408 0.016292))
                       ((1.66507 0.879915)))
                      ((R:segstate.parent.nn.ph_cplace is p)
                       ((R:segstate.parent.pp.ph_ctype is 0)
                        ((1.54215 0.82502))
                        ((1.35808 0.226324)))
                       ((R:segstate.parent.p.name is t)
                        ((name is ih_3)
                         ((1.33126 1.10984))
                         ((name is ih_2)
                          ((0.704777 0.477935))
                          ((R:segstate.parent.nn.ph_cplace is a)
                           ((1.56706 0.222581))
                           ((R:segstate.parent.pp.ph_vfront is 1)
                            ((0.198098 -0.274742))
                            ((0.346403 -0.366414))))))
                        ((name is pau_5)
                         ((R:segstate.parent.p.ph_vc is +)
                          ((1.65519 0.746146))
                          ((R:segstate.parent.pp.ph_vlng is s)
                           ((R:segstate.parent.nn.ph_cplace is a)
                            ((0.682786 -0.025459))
                            ((0.905604 0.300544)))
                           ((R:segstate.parent.nn.ph_cplace is a)
                            ((0.689999 -0.0242528))
                            ((0.461498 -0.341476)))))
                         ((R:segstate.parent.nn.ph_cplace is 0)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                            <
                            0.3)
                           ((R:segstate.parent.nn.ph_vc is +)
                            ((0.768681 -0.02981))
                            ((1.35219 0.709393)))
                           ((R:segstate.parent.nn.ph_vrnd is -)
                            ((0.794705 -0.0675668))
                            ((0.551865 -0.312885))))
                          ((p.name is pau_2)
                           ((1.19913 0.379664))
                           ((R:segstate.parent.p.name is d)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                              is
                              0)
                             ((1.25394 0.261966))
                             ((0.624418 -0.0404512)))
                            ((R:segstate.parent.p.ph_vc is +)
                             ((0.233182 -0.487734))
                             ((R:segstate.parent.n.name is ih)
                              ((R:segstate.parent.pp.ph_vc is +)
                               ((0.791896 -0.326188))
                               ((0.128339 -0.453914)))
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                <
                                0.3)
                               ((R:segstate.parent.nn.ph_cplace is b)
                                ((0.651542 -0.3184))
                                ((R:segstate.parent.pp.ph_vfront is 1)
                                 ((0.546034 -0.213227))
                                 ((R:segstate.parent.n.ph_vc is +)
                                  ((0.786136 0.134032))
                                  ((0.542366 -0.195568)))))
                               ((R:segstate.parent.R:SylStructure.parent.syl_in
                                 <
                                 2.4)
                                ((0.402481 -0.365994))
                                ((0.376221 -0.153805)))))))))))))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                       <
                       1.3)
                      ((R:segstate.parent.R:SylStructure.parent.last_accent
                        <
                        1.4)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                         is
                         0)
                        ((0.162718 -0.565094))
                        ((0.278442 -0.438285)))
                       ((0.597526 -0.165862)))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                        <
                        2.2)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         6.2)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                          is
                          0)
                         ((0.212136 -0.519759))
                         ((0.391333 -0.31023)))
                        ((R:segstate.parent.pp.ph_vlng is s)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                           is
                           0)
                          ((0.294711 -0.511259))
                          ((0.607806 -0.00884371)))
                         ((name is ih_2)
                          ((0.78913 0.358557))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                            is
                            0)
                           ((0.985217 0.178366))
                           ((R:segstate.parent.p.name is pau)
                            ((0.316781 -0.396322))
                            ((0.728158 0.0647671)))))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                         is
                         0)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                          is
                          0)
                         ((0.747348 -0.113593))
                         ((0.290575 -0.305011)))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                          is
                          0)
                         ((0.253676 -0.514491))
                         ((0.427322 -0.361487)))))))
                    ((p.name is dh_3)
                     ((1.25757 0.525186))
                     ((R:segstate.parent.n.name is d)
                      ((R:segstate.parent.pp.ph_vc is +)
                       ((1.31226 0.726776))
                       ((0.659113 -0.142413)))
                      ((R:segstate.parent.n.name is b)
                       ((name is pau_2)
                        ((0.210791 -0.455541))
                        ((R:segstate.parent.pp.ph_vrnd is -)
                         ((0.154312 -0.579611))
                         ((0.214276 -0.514271))))
                       ((R:segstate.parent.n.name is r)
                        ((R:segstate.parent.nn.ph_vlng is s)
                         ((0.840985 0.199308))
                         ((0.518799 0.0562699)))
                        ((R:segstate.parent.nn.ph_vc is +)
                         ((R:segstate.parent.p.name is z)
                          ((R:segstate.parent.n.name is m)
                           ((0.25962 -0.127128))
                           ((R:segstate.parent.pp.ph_vfront is 3)
                            ((0.237832 -0.536228))
                            ((R:segstate.parent.nn.ph_vlng is l)
                             ((0.317712 -0.42636))
                             ((R:segstate.parent.pp.ph_vlng is s)
                              ((0.481244 -0.372114))
                              ((0.590822 -0.239609))))))
                          ((R:segstate.parent.n.name is s)
                           ((name is pau_2)
                            ((0.41587 -0.220265))
                            ((0.202307 -0.538576)))
                           ((R:segstate.parent.p.name is er)
                            ((0.74324 0.116198))
                            ((R:segstate.parent.pp.ph_cplace is l)
                             ((0.269131 -0.444101))
                             ((R:segstate.parent.n.name is sh)
                              ((2.01474 0.453825))
                              ((name is pau_2)
                               ((R:segstate.parent.p.name is n)
                                ((1.24582 0.00964465))
                                ((R:segstate.parent.pp.ph_vrnd is -)
                                 ((R:segstate.parent.nn.ph_vlng is s)
                                  ((0.137674 -0.479922))
                                  ((R:segstate.parent.nn.ph_vlng is l)
                                   ((0.140599 -0.484413))
                                   ((0.649239 -0.194899))))
                                 ((R:segstate.parent.pp.ph_cplace is a)
                                  ((R:segstate.parent.n.name is hh)
                                   ((0.315556 -0.397839))
                                   ((0.364077 -0.356143)))
                                  ((R:segstate.parent.nn.ph_vlng is s)
                                   ((0.604091 -0.0520391))
                                   ((R:segstate.parent.n.name is dh)
                                    ((0.110176 -0.479204))
                                    ((R:segstate.parent.n.name is hh)
                                     ((0.558753 -0.136152))
                                     ((0.501557 -0.108114))))))))
                               ((R:segstate.parent.n.name is t)
                                ((R:segstate.parent.nn.ph_vlng is a)
                                 ((R:segstate.parent.pp.ph_vlng is s)
                                  ((0.537914 -0.243437))
                                  ((0.418775 -0.321563)))
                                 ((0.21631 -0.463345)))
                                ((R:segstate.parent.n.name is k)
                                 ((R:segstate.parent.pp.ph_vlng is s)
                                  ((0.452955 -0.236128))
                                  ((0.431353 -0.391971)))
                                 ((p.name is v_3)
                                  ((0.789168 0.214462))
                                  ((R:segstate.parent.pp.ph_vlng is s)
                                   ((0.525491 -0.196603))
                                   ((R:segstate.parent.pp.ph_vfront
                                     is
                                     2)
                                    ((0.550651 -0.15316))
                                    ((R:segstate.parent.n.name is m)
                                     ((0.501076 -0.160489))
                                     ((R:segstate.parent.pp.ph_vlng
                                       is
                                       l)
                                      ((0.878859 -0.0150727))
                                      ((R:segstate.parent.pp.ph_ctype
                                        is
                                        n)
                                       ((1.16924 -0.0524651))
                                       ((1.19691 0.387601))))))))))))))))
                         ((R:segstate.parent.nn.ph_cplace is a)
                          ((R:segstate.parent.pp.ph_vfront is 2)
                           ((0.254575 -0.522093))
                           ((R:segstate.parent.pp.ph_vc is -)
                            ((0.29186 -0.415295))
                            ((R:segstate.parent.pp.ph_vfront is 1)
                             ((0.370699 -0.368352))
                             ((0.617981 -0.155212)))))
                          ((0.18045 -0.528533))))))))))))
                ((name is ax_3)
                 ((R:segstate.parent.p.name is dh)
                  ((R:segstate.parent.n.name is w)
                   ((0.796176 1.02008))
                   ((R:segstate.parent.n.name is r)
                    ((0.647484 0.409495))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      4.4)
                     ((R:segstate.parent.n.name is b)
                      ((0.492797 0.0158017))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                        is
                        0)
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         9)
                        ((R:segstate.parent.pp.ph_cplace is a)
                         ((0.27257 -0.268766))
                         ((0.155262 -0.396705)))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                          is
                          0)
                         ((1.84678e-07 -0.451707))
                         ((0.116876 -0.422486))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                         is
                         0)
                        ((R:segstate.parent.pp.ph_ctype is s)
                         ((0.129447 -0.414306))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                           <
                           0.4)
                          ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                            <
                            6.3)
                           ((0.277521 -0.327038))
                           ((0.562156 -0.111701)))
                          ((R:segstate.parent.n.seg_onsetcoda is coda)
                           ((0.12071 -0.420539))
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                             <
                             4.5)
                            ((0.352016 -0.209294))
                            ((0.256345 -0.347816))))))
                        ((0.809748 0.0158013)))))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                       is
                       0)
                      ((0.578904 0.171636))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        11.1)
                       ((R:segstate.parent.R:SylStructure.parent.asyl_in
                         <
                         2.5)
                        ((0.335404 -0.231706))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                          <
                          1.3)
                         ((0.608698 0.0781338))
                         ((0.514157 -0.015367))))
                       ((0.269916 -0.334824)))))))
                  ((R:segstate.parent.n.ph_vc is +)
                   ((3.44666 4.81555))
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     6.1)
                    ((R:segstate.parent.nn.ph_vrnd is -)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                       <
                       0.3)
                      ((0.692769 0.0450201))
                      ((R:segstate.parent.R:SylStructure.parent.last_accent
                        <
                        0.9)
                       ((2.02186 1.23539))
                       ((1.28032 0.48331))))
                     ((0.528801 -0.0667005)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                      is
                      0)
                     ((0.371764 -0.259204))
                     ((0.651959 0.0391771))))))
                 ((name is ih_3)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    2.2)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                     <
                     0.3)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                      is
                      0)
                     ((0.35996 -0.413764))
                     ((0.599522 -0.187406)))
                    ((1.14163 0.325537)))
                   ((R:segstate.parent.p.name is dh)
                    ((2.21637 1.47627))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      4.2)
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       7.2)
                      ((1.005 0.994123))
                      ((0.678358 0.467611)))
                     ((0.711446 0.0683891)))))
                  ((name is uh_3)
                   ((1.04781 1.09111))
                   ((R:segstate.parent.p.name is n)
                    ((R:segstate.parent.nn.ph_vlng is s)
                     ((0.610498 -0.254251))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       0.7)
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        3.4)
                       ((1.32075 0.799484))
                       ((0.997913 0.165025)))
                      ((name is ow_3)
                       ((0.682294 -0.291918))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                         <
                         0.3)
                        ((0.849329 0.489261))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          2.4)
                         ((0.629796 -0.0113414))
                         ((0.885216 0.325922)))))))
                    ((R:segstate.parent.n.name is y)
                     ((1.13584 0.524386))
                     ((R:segstate.parent.n.name is hh)
                      ((R:segstate.parent.nn.ph_vlng is s)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                         <
                         1.6)
                        ((name is pau_2)
                         ((0.826658 0.842059))
                         ((1.53013 0.595137)))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          2.2)
                         ((0.482072 -0.255989))
                         ((0.78163 -0.00194276))))
                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                         <
                         2.4)
                        ((R:segstate.parent.nn.ph_vlng is l)
                         ((0.49637 -0.190448))
                         ((0.345965 -0.220536)))
                        ((1.02951 0.22675))))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        4.6)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                         <
                         0.4)
                        ((R:segstate.parent.n.name is f)
                         ((0.767733 0.27784))
                         ((R:segstate.parent.n.name is b)
                          ((0.106655 -0.505503))
                          ((R:segstate.parent.n.name is ae)
                           ((0.559485 -0.0484048))
                           ((R:segstate.parent.p.name is hh)
                            ((R:segstate.parent.R:SylStructure.parent.syl_in
                              <
                              2.4)
                             ((0.778091 0.0427399))
                             ((0.627874 -0.276849)))
                            ((R:segstate.parent.n.name is ih)
                             ((name is pau_2)
                              ((0.451483 -0.103441))
                              ((0.276029 -0.475725)))
                             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                               is
                               det)
                              ((R:segstate.parent.R:SylStructure.parent.last_accent
                                <
                                0.3)
                               ((R:segstate.parent.R:SylStructure.parent.syl_out
                                 <
                                 13.6)
                                ((R:segstate.parent.nn.ph_vc is +)
                                 ((0.801881 0.241492))
                                 ((0.397516 -0.166257)))
                                ((0.496762 -0.280608)))
                               ((R:segstate.parent.R:SylStructure.parent.syl_out
                                 <
                                 7)
                                ((0.503845 -0.216085))
                                ((0.29847 -0.44614))))
                              ((R:segstate.parent.n.ph_vc is +)
                               ((R:segstate.parent.n.name is ax)
                                ((0.163215 -0.480682))
                                ((R:segstate.parent.nn.ph_cplace is 0)
                                 ((0.338534 -0.28449))
                                 ((R:segstate.parent.n.name is ay)
                                  ((R:segstate.parent.nn.ph_cplace
                                    is
                                    a)
                                   ((0.283397 -0.401238))
                                   ((0.236626 -0.414454)))
                                  ((0.241742 -0.381366)))))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                 <
                                 0.1)
                                ((R:segstate.parent.n.name is s)
                                 ((0.58141 -0.0960508))
                                 ((R:segstate.parent.n.name is d)
                                  ((0.298797 -0.423968))
                                  ((R:segstate.parent.n.name is pau)
                                   ((0.295549 -0.231748))
                                   ((R:segstate.parent.nn.ph_vrnd is -)
                                    ((R:segstate.parent.nn.ph_vlng
                                      is
                                      a)
                                     ((0.553404 -0.353557))
                                     ((R:segstate.parent.n.name is sh)
                                      ((0.321724 -0.353446))
                                      ((R:segstate.parent.n.name is dh)
                                       ((R:segstate.parent.nn.ph_vlng
                                         is
                                         d)
                                        ((0.502676 -0.328412))
                                        ((0.549985 -0.29408)))
                                       ((R:segstate.parent.n.name is w)
                                        ((0.40466 -0.272685))
                                        ((0.588188 -0.149792))))))
                                    ((0.273505 -0.383301))))))
                                ((R:segstate.parent.n.seg_onsetcoda
                                  is
                                  coda)
                                 ((0.317778 -0.494199))
                                 ((0.326888 -0.319305)))))))))))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          5.8)
                         ((R:segstate.parent.nn.ph_vlng is s)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                            <
                            0.1)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                             is
                             0)
                            ((0.367182 -0.375136))
                            ((0.762135 0.0788042)))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                             <
                             1.2)
                            ((0.933114 0.347951))
                            ((0.498196 -0.150677))))
                          ((R:segstate.parent.pp.ph_ctype is s)
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                             <
                             3.2)
                            ((0.68258 -0.0653487))
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              7.9)
                             ((0.33696 -0.346175))
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               2.2)
                              ((0.172715 -0.56644))
                              ((0.285013 -0.452286)))))
                           ((R:segstate.parent.R:SylStructure.parent.asyl_out
                             <
                             2.2)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                              <
                              1.2)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                               <
                               0.1)
                              ((0.268999 -0.565218))
                              ((0.447155 -0.396153)))
                             ((R:segstate.parent.R:SylStructure.parent.asyl_out
                               <
                               1.1)
                              ((0.430959 -0.396277))
                              ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                <
                                2.4)
                               ((0.571545 -0.344231))
                               ((0.718455 0.147882)))))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                              <
                              0.1)
                             ((name is ax_1)
                              ((0.213042 -0.474843))
                              ((R:segstate.parent.pp.ph_ctype is 0)
                               ((R:segstate.parent.lisp_coda_fric is 0)
                                ((0.530644 -0.203397))
                                ((0.407624 -0.282606)))
                               ((0.958028 0.0180595))))
                             ((R:segstate.parent.nn.ph_cplace is a)
                              ((0.393412 -0.265245))
                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                <
                                9.6)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                 is
                                 0)
                                ((R:segstate.parent.R:SylStructure.parent.syl_out
                                  <
                                  7.5)
                                 ((0.930107 0.306024))
                                 ((0.898731 0.185062)))
                                ((0.529112 -0.0779409)))
                               ((0.702642 -0.172178))))))))
                         ((name is ax_2)
                          ((0.484156 -0.234399))
                          ((R:segstate.parent.nn.ph_vc is +)
                           ((0.830357 0.143365))
                           ((1.37736 0.480938))))))
                       ((R:segstate.parent.n.name is g)
                        ((0.659064 0.14987))
                        ((name is iy_2)
                         ((0.863279 0.0358284))
                         ((R:segstate.parent.ph_vheight is 1)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                            <
                            0.3)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                             <
                             0.3)
                            ((0.381445 -0.414147))
                            ((1.48673 0.163288)))
                           ((R:segstate.parent.nn.ph_cplace is a)
                            ((0.473894 -0.247888))
                            ((name is ih_2)
                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                               <
                               5.5)
                              ((R:segstate.parent.R:SylStructure.parent.syl_in
                                <
                                10)
                               ((0.241457 -0.590845))
                               ((0.1259 -0.664902)))
                              ((0.504866 -0.455794)))
                             ((R:segstate.parent.p.name is t)
                              ((0.20205 -0.59266))
                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                <
                                4)
                               ((name is ih_1)
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                  <
                                  0.3)
                                 ((4.26636e-06 -0.481082))
                                 ((0.091432 -0.446438)))
                                ((0.831587 -0.120744)))
                               ((name is ih_1)
                                ((0.356376 -0.351159))
                                ((R:segstate.parent.pp.ph_ctype is 0)
                                 ((0.118437 -0.653139))
                                 ((0.19014 -0.507322)))))))))
                          ((name is eh_2)
                           ((0.275702 -0.663813))
                           ((R:segstate.parent.n.name is m)
                            ((name is ax_2)
                             ((0.224089 -0.398573))
                             ((0.206971 -0.527397)))
                            ((name is ax_2)
                             ((R:segstate.parent.n.name is f)
                              ((0.452365 -0.138312))
                              ((R:segstate.parent.pp.ph_ctype is n)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                 is
                                 0)
                                ((0.354522 -0.349742))
                                ((0.513715 -0.119968)))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                 is
                                 0)
                                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                  <
                                  8)
                                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                                   <
                                   7)
                                  ((R:segstate.parent.pp.ph_ctype is s)
                                   ((0.255033 -0.378797))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                     is
                                     0)
                                    ((0.321382 -0.340457))
                                    ((0.537023 -0.196682))))
                                  ((0.240247 -0.406814)))
                                 ((0.195509 -0.437943)))
                                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                  <
                                  1.6)
                                 ((0.324229 -0.355206))
                                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                                   <
                                   1.2)
                                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                    <
                                    4.4)
                                   ((0.0956977 -0.511879))
                                   ((4.70074e-06 -0.546899)))
                                  ((0.201387 -0.441837)))))))
                             ((R:segstate.parent.nn.ph_vrnd is +)
                              ((0.305581 -0.41201))
                              ((R:segstate.parent.n.name is k)
                               ((0.574508 0.0527637))
                               ((name is ax_1)
                                ((R:segstate.parent.pp.ph_ctype is f)
                                 ((0.248726 -0.418351))
                                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                                   <
                                   12.2)
                                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                    <
                                    1.8)
                                   ((p.name is dh_3)
                                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                                      <
                                      7.1)
                                     ((0.346972 -0.354933))
                                     ((0.240709 -0.496159)))
                                    ((0.35075 -0.266302)))
                                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                     <
                                     1.2)
                                    ((0.731923 -0.0299551))
                                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                                      <
                                      9.2)
                                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                                       <
                                       6.2)
                                      ((0.435549 -0.219033))
                                      ((0.202506 -0.471137)))
                                     ((0.498837 -0.104593)))))
                                  ((0.683496 -0.0119464))))
                                ((R:segstate.parent.R:SylStructure.parent.last_accent
                                  <
                                  2)
                                 ((0.636807 -0.237724))
                                 ((0.733826 0.133338))))))))))))))))))))))))))
         ((p.name is n_3)
          ((name is s_1)
           ((R:segstate.parent.R:SylStructure.parent.syl_codasize
             <
             2.2)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
              is
              0)
             ((1.02301 0.758069))
             ((0.652454 -0.13882)))
            ((0.708022 -0.211252)))
           ((R:segstate.parent.ph_ctype is a)
            ((0.311409 -1.14423))
            ((name is t_1)
             ((R:segstate.parent.syl_final is 0)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                <
                0.3)
               ((R:segstate.parent.R:SylStructure.parent.position_type
                 is
                 final)
                ((0.172131 -0.844667))
                ((0.392045 -0.603539)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                 <
                 0.2)
                ((0.217473 -0.733704))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  2.4)
                 ((0.223947 -0.854204))
                 ((3.69032e-06 -0.940587)))))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 5.4)
               ((0.663172 -0.35442))
               ((0.333945 -0.753013))))
             ((name is dh_1)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                <
                0.3)
               ((0.278813 -0.594378))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                 is
                 0)
                ((2.33936e-06 -0.779602))
                ((0.14522 -0.741607))))
              ((R:segstate.parent.ph_ctype is s)
               ((name is k_1)
                ((0.495081 -0.804541))
                ((R:segstate.parent.R:SylStructure.parent.last_accent
                  <
                  1.8)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   4.5)
                  ((R:segstate.parent.n.seg_onsetcoda is coda)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                     <
                     0.3)
                    ((0.377998 -0.423338))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      4.5)
                     ((0.203926 -0.620473))
                     ((0.293827 -0.517598))))
                   ((0.11546 -0.648281)))
                  ((0.515971 -0.356002)))
                 ((R:segstate.parent.R:SylStructure.parent.position_type
                   is
                   final)
                  ((0.212897 -0.557269))
                  ((0.585376 -0.141281)))))
               ((R:segstate.parent.n.ph_vc is +)
                ((R:segstate.parent.lisp_coda_nasal is 0)
                 ((R:segstate.parent.lisp_onset_nasal is 0)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                    <
                    0.2)
                   ((0.847565 0.540003))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                     <
                     0.3)
                    ((0.590659 -0.326506))
                    ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                      <
                      1.2)
                     ((0.905355 0.297451))
                     ((0.505564 -0.176667)))))
                  ((0.533751 -0.33629)))
                 ((0.435393 -0.441133)))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                  <
                  0.3)
                 ((0.591321 -0.510079))
                 ((0.228505 -0.752435)))))))))
          ((p.name is d_3)
           ((R:segstate.parent.n.ph_vc is +)
            ((R:segstate.parent.pp.ph_ctype is l)
             ((1.00158 0.160362))
             ((R:segstate.parent.lisp_onset_fric is 0)
              ((R:segstate.parent.pp.ph_vfront is 2)
               ((0.755857 -0.118918))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                 <
                 0.3)
                ((R:segstate.parent.ph_cplace is a)
                 ((0.338234 -0.549286))
                 ((0.790536 -0.20239)))
                ((R:segstate.parent.lisp_coda_nasal is 0)
                 ((R:segstate.parent.pp.ph_vlng is s)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    3.4)
                   ((0.490571 -0.334861))
                   ((0.441171 -0.615944)))
                  ((R:segstate.parent.ph_ctype is n)
                   ((0.345329 -0.55318))
                   ((R:segstate.parent.nn.ph_cplace is a)
                    ((0.527106 -0.599789))
                    ((0.172292 -0.811436)))))
                 ((0.269176 -0.965416)))))
              ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                is
                content)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                  <
                  0.1)
                 ((0.498033 -0.502982))
                 ((0.847131 -0.197849)))
                ((1.1745 0.194744)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                 <
                 0.3)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  2.2)
                 ((0.268573 -0.534847))
                 ((0.665235 -0.306399)))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                  is
                  0)
                 ((0.464103 -0.438811))
                 ((0.148544 -0.67941)))))))
            ((R:segstate.parent.pp.ph_ctype is n)
             ((0.134219 -0.834508))
             ((0.15249 -0.752658))))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
             <
             0.3)
            ((name is hh_1)
             ((R:segstate.parent.n.name is iy)
              ((R:segstate.parent.nn.ph_cplace is l)
               ((0.74876 1.79347))
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 4.6)
                ((0.483545 1.41668))
                ((0.842769 0.99886))))
              ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                <
                1.2)
               ((0.322087 -0.381469))
               ((0.960677 0.0684546))))
             ((p.name is pau_2)
              ((R:segstate.parent.n.name is iy)
               ((1.99329 1.30224))
               ((name is s_1)
                ((1.17211 0.376705))
                ((R:segstate.parent.ph_ctype is s)
                 ((name is d_1)
                  ((0.227894 -0.527516))
                  ((name is t_1)
                   ((0.172752 -0.8468))
                   ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                     <
                     1.3)
                    ((0.0453313 -1.12078))
                    ((0.185861 -1.03654)))))
                 ((R:segstate.parent.R:SylStructure.parent.position_type
                   is
                   initial)
                  ((R:segstate.parent.n.name is ih)
                   ((0.827083 0.0536215))
                   ((0.784872 -0.411723)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                    <
                    0.2)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     11.5)
                    ((0.502315 -0.370487))
                    ((0.298223 -0.562118)))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                     <
                     0.1)
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      7.5)
                     ((0.0869098 -0.745833))
                     ((0.19097 -0.683615)))
                    ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                      is
                      content)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                       <
                       0.3)
                      ((0.240989 -0.78023))
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        3.4)
                       ((0.292325 -0.681934))
                       ((0.412239 -0.55962))))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       10)
                      ((0.315189 -0.622848))
                      ((0.57355 -0.424089))))))))))
              ((p.name is ng_3)
               ((0.261874 -0.960992))
               ((R:segstate.parent.ph_cplace is g)
                ((R:segstate.parent.n.name is iy)
                 ((R:segstate.parent.nn.ph_cplace is 0)
                  ((0.27932 -0.43736))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                    <
                    0.1)
                   ((R:segstate.parent.nn.ph_cplace is l)
                    ((0.113355 -0.551468))
                    ((0.0356303 -0.593194)))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     7.6)
                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                      <
                      1.2)
                     ((R:segstate.parent.nn.ph_cplace is a)
                      ((0.114958 -0.536409))
                      ((0.0352409 -0.593194)))
                     ((0.179828 -0.501914)))
                    ((0.257495 -0.467482)))))
                 ((R:segstate.parent.n.name is ih)
                  ((name is hh_2)
                   ((0.531927 -0.245397))
                   ((0.161883 -0.530332)))
                  ((name is hh_2)
                   ((0.374927 -0.438773))
                   ((0.852065 0.280266)))))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                  is
                  0)
                 ((R:segstate.parent.lisp_onset_stop is 0)
                  ((name is er_2)
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     3.2)
                    ((0.833848 -0.0459161))
                    ((0.906513 0.68358)))
                   ((R:segstate.parent.n.name is ow)
                    ((R:segstate.parent.ph_ctype is n)
                     ((1.08681 0.653585))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                       <
                       0.1)
                      ((0.77581 0.282629))
                      ((0.774219 0.0964208))))
                    ((R:segstate.parent.p.name is er)
                     ((name is s_1)
                      ((0.154334 -0.403937))
                      ((R:segstate.parent.ph_cplace is b)
                       ((1.55094 0.633316))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                         <
                         0.3)
                        ((1.00003 -0.0667042))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                          is
                          0)
                         ((1.11422 0.388616))
                         ((0.857132 0.118219))))))
                     ((name is dh_2)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                        <
                        0.3)
                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                         <
                         5.6)
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                          <
                          6.5)
                         ((0.689161 0.219463))
                         ((0.577258 0.399233)))
                        ((0.553548 0.0996167)))
                       ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                         is
                         content)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                          <
                          0.2)
                         ((0.577258 -0.0801534))
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           3.4)
                          ((0.750392 0.31752))
                          ((0.549981 0.0787738))))
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          11.2)
                         ((0.55837 -0.264717))
                         ((0.600943 0.0996167)))))
                      ((name is t_1)
                       ((R:segstate.parent.n.seg_onsetcoda is coda)
                        ((0.640954 -0.384814))
                        ((1.29955 0.935146)))
                       ((R:segstate.parent.n.name is jh)
                        ((1.08384 0.452755))
                        ((R:segstate.parent.ph_ctype is l)
                         ((R:segstate.parent.n.name is f)
                          ((R:segstate.parent.R:SylStructure.parent.next_accent
                            <
                            1.4)
                           ((0.342273 -0.561602))
                           ((0.317792 -0.72089)))
                          ((R:segstate.parent.p.ph_vheight is 2)
                           ((0.588842 -0.176184))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                             is
                             0)
                            ((0.306776 -0.659744))
                            ((0.505948 -0.357325)))))
                         ((R:segstate.parent.p.ph_vheight is 2)
                          ((R:segstate.parent.ph_ctype is f)
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                             <
                             3)
                            ((0.808455 -0.0977893))
                            ((0.59482 -0.653044)))
                           ((name is r_1)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                              is
                              0)
                             ((0.0966024 -0.643165))
                             ((1.40198 -0.265129)))
                            ((R:segstate.parent.n.name is w)
                             ((name is r_2)
                              ((0.635229 -0.201612))
                              ((0.313343 -0.592309)))
                             ((R:segstate.parent.lisp_coda_stop is 0)
                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                <
                                7.8)
                               ((R:segstate.parent.ph_ctype is r)
                                ((1.52262 0.686446))
                                ((R:segstate.parent.lisp_onset_fric
                                  is
                                  0)
                                 ((R:segstate.parent.ph_cplace is a)
                                  ((0.591903 -0.0429468))
                                  ((R:segstate.parent.R:SylStructure.parent.position_type
                                    is
                                    mid)
                                   ((0.806036 0.0684851))
                                   ((1.44737 0.347312))))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                   <
                                   0.1)
                                  ((1.62702 0.463213))
                                  ((0.782301 0.239354)))))
                               ((R:segstate.parent.R:SylStructure.parent.next_accent
                                 <
                                 1.4)
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                  is
                                  0)
                                 ((0.715198 -0.187175))
                                 ((R:segstate.parent.nn.ph_vrnd is -)
                                  ((0.860278 0.354771))
                                  ((0.725398 -0.00162297))))
                                ((0.680843 -0.168803))))
                              ((p.name is eh_3)
                               ((0.798516 0.300988))
                               ((R:segstate.parent.p.ph_vlng is d)
                                ((0.655931 -0.109528))
                                ((R:segstate.parent.pp.ph_ctype is f)
                                 ((0.918325 -0.397052))
                                 ((0.554674 -0.733904)))))))))
                          ((R:segstate.parent.p.name is ay)
                           ((R:segstate.parent.R:SylStructure.parent.position_type
                             is
                             final)
                            ((R:segstate.parent.pp.ph_ctype is f)
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               5.4)
                              ((0.804771 0.147488))
                              ((0.670934 -0.181353)))
                             ((0.562848 -0.409442)))
                            ((R:segstate.parent.ph_ctype is n)
                             ((1.20755 0.149405))
                             ((1.13019 0.656937))))
                           ((name is z_3)
                            ((1.19749 0.335731))
                            ((name is z_2)
                             ((R:segstate.parent.lisp_coda_glide is 0)
                              ((0.960201 0.284349))
                              ((0.945304 0.0963956)))
                             ((name is f_3)
                              ((R:segstate.parent.p.name is l)
                               ((0.658794 -0.120217))
                               ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                 <
                                 1.2)
                                ((0.448424 -0.0153518))
                                ((0.759612 0.330088))))
                              ((R:segstate.parent.n.seg_onsetcoda
                                is
                                coda)
                               ((R:segstate.parent.nn.ph_vrnd is -)
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                  <
                                  0.1)
                                 ((R:segstate.parent.ph_ctype is f)
                                  ((1.7563 0.915239))
                                  ((0.442089 -0.171703)))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                   <
                                   0.3)
                                  ((0.625256 -0.571679))
                                  ((0.775263 -0.179371))))
                                ((R:segstate.parent.ph_vc is +)
                                 ((1.15694 0.321683))
                                 ((R:segstate.parent.n.name is ih)
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                    <
                                    1.2)
                                   ((R:segstate.parent.ph_ctype is s)
                                    ((0.259542 -0.574935))
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                      is
                                      0)
                                     ((0.390315 -0.561754))
                                     ((0.735371 -0.419532))))
                                   ((0.420863 -0.686078)))
                                  ((R:segstate.parent.pp.ph_vlng is a)
                                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                     <
                                     2.7)
                                    ((1.54877 0.387047))
                                    ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                      <
                                      2.2)
                                     ((0.716242 -0.345678))
                                     ((R:segstate.parent.p.name is n)
                                      ((0.660741 0.00740191))
                                      ((0.691559 -0.176732)))))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                     <
                                     0.1)
                                    ((R:segstate.parent.R:SylStructure.parent.last_accent
                                      <
                                      2.1)
                                     ((name is sh_3)
                                      ((0.67895 -0.759038))
                                      ((R:segstate.parent.p.name is t)
                                       ((0.493148 -0.695678))
                                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                         is
                                         0)
                                        ((R:segstate.parent.ph_cplace
                                          is
                                          l)
                                         ((0.472708 -0.423354))
                                         ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                           <
                                           1.2)
                                          ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                            <
                                            3.4)
                                           ((0.70666 -0.0638436))
                                           ((0.761063 -0.344821)))
                                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                            is
                                            0)
                                           ((0.521004 -0.301573))
                                           ((0.983874 0.237811)))))
                                        ((R:segstate.parent.nn.ph_cplace
                                          is
                                          v)
                                         ((0.371407 -0.724437))
                                         ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                                           <
                                           0.1)
                                          ((R:segstate.parent.ph_ctype
                                            is
                                            f)
                                           ((1.02239 -0.0499136))
                                           ((0.978054 -0.189665)))
                                          ((R:segstate.parent.lisp_coda_glide
                                            is
                                            0)
                                           ((p.name is pau_3)
                                            ((0.211996 -0.509544))
                                            ((R:segstate.parent.nn.ph_cplace
                                              is
                                              0)
                                             ((0.500882 -0.432204))
                                             ((R:segstate.parent.lisp_onset_fric
                                               is
                                               0)
                                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                                <
                                                10)
                                               ((0.942721 0.0326954))
                                               ((0.556839 -0.375642)))
                                              ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                                                is
                                                det)
                                               ((R:segstate.parent.R:SylStructure.parent.syl_out
                                                 <
                                                 9.4)
                                                ((0.559057 -0.280937))
                                                ((0.612707 -0.0773392)))
                                               ((R:segstate.parent.R:SylStructure.parent.syl_out
                                                 <
                                                 8)
                                                ((0.439886 -0.30694))
                                                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                                  <
                                                  7)
                                                 ((0.487524 -0.698228))
                                                 ((0.320235 -0.320869))))))))
                                           ((R:segstate.parent.p.name
                                             is
                                             pau)
                                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                                              <
                                              11.5)
                                             ((0.412732 -0.569451))
                                             ((0.310366 -0.644526)))
                                            ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                              <
                                              5.2)
                                             ((0.564869 -0.525725))
                                             ((0.700126 -0.175338))))))))))
                                     ((0.344023 -0.716095)))
                                    ((name is s_1)
                                     ((1.1047 0.197841))
                                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                       <
                                       2.4)
                                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                        is
                                        0)
                                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                         <
                                         3.5)
                                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                          <
                                          1.2)
                                         ((0.584354 -0.301505))
                                         ((0.837852 0.0988191)))
                                        ((0.443793 -0.563361)))
                                       ((R:segstate.parent.syl_final
                                         is
                                         0)
                                        ((1.10766 0.376604))
                                        ((0.521987 -0.144494))))
                                      ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                        <
                                        0.1)
                                       ((0.255675 -0.51822))
                                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                         is
                                         0)
                                        ((0.729375 -0.1692))
                                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                          is
                                          0)
                                         ((R:segstate.parent.R:SylStructure.parent.position_type
                                           is
                                           final)
                                          ((0.455112 -0.552009))
                                          ((0.749449 -0.38605)))
                                         ((0.771282 -0.227619))))))))))))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                 is
                                 0)
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                  <
                                  1.2)
                                 ((R:segstate.parent.pos_in_syl is 1)
                                  ((0.758166 -0.0364036))
                                  ((R:segstate.parent.ph_ctype is r)
                                   ((0.388733 -0.531322))
                                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                                     <
                                     3)
                                    ((0.79112 -0.0417727))
                                    ((R:segstate.parent.pp.ph_vc is +)
                                     ((0.539268 -0.196589))
                                     ((0.446346 -0.424418))))))
                                 ((0.303702 -0.558312)))
                                ((R:segstate.parent.n.name is s)
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                   <
                                   0.2)
                                  ((0.522149 -0.50097))
                                  ((0.220853 -0.83499)))
                                 ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                                   is
                                   in)
                                  ((R:segstate.parent.n.name is dh)
                                   ((0.226792 -0.713437))
                                   ((0.223991 -0.579173)))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                    <
                                    0.2)
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                     is
                                     0)
                                    ((0.77308 -0.236719))
                                    ((0.888748 -0.0428132)))
                                   ((R:segstate.parent.pp.ph_vlng is l)
                                    ((0.54885 -0.234481))
                                    ((R:segstate.parent.nn.ph_vlng
                                      is
                                      a)
                                     ((0.535062 -0.39999))
                                     ((0.472112 -0.618206)))))))))))))))))))))
                  ((name is t_3)
                   ((R:segstate.parent.pos_in_syl is 0)
                    ((R:segstate.parent.R:SylStructure.parent.position_type
                      is
                      final)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       3.2)
                      ((0.719626 0.887091))
                      ((0.563792 0.480384)))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       8.6)
                      ((0.536156 1.19944))
                      ((0.627097 1.49467))))
                    ((R:segstate.parent.lisp_coda_nasal is 0)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                       is
                       0)
                      ((0.359995 -0.238038))
                      ((0.451073 -0.448554)))
                     ((1.05101 0.269145))))
                   ((R:segstate.parent.n.name is iy)
                    ((R:segstate.parent.ph_cplace is a)
                     ((name is t_2)
                      ((1.22578 0.136519))
                      ((R:segstate.parent.pp.ph_vc is +)
                       ((1.07468 0.475825))
                       ((1.01937 1.16538))))
                     ((0.915674 0.134271)))
                    ((name is d_1)
                     ((1.19985 1.10099))
                     ((R:segstate.parent.p.name is m)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        6.4)
                       ((0.690424 -0.818421))
                       ((1.04646 -0.452035)))
                      ((name is er_1)
                       ((1.0788 0.574965))
                       ((p.name is eh_3)
                        ((1.37768 0.45395))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                          <
                          1.2)
                         ((R:segstate.parent.p.name is ay)
                          ((0.889384 0.426814))
                          ((R:segstate.parent.nn.ph_cplace is p)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                             <
                             0.1)
                            ((1.37569 0.667354))
                            ((R:segstate.parent.R:SylStructure.parent.syl_in
                              <
                              4)
                             ((0.458542 -0.278927))
                             ((0.896105 0.068154))))
                           ((R:segstate.parent.pp.ph_cplace is a)
                            ((R:segstate.parent.R:SylStructure.parent.last_accent
                              <
                              1.4)
                             ((R:segstate.parent.R:SylStructure.parent.asyl_in
                               <
                               2.5)
                              ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                <
                                4)
                               ((0.76198 0.225224))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                 is
                                 0)
                                ((0.498926 -0.217728))
                                ((0.731499 0.0615639))))
                              ((1.68923 0.660198)))
                             ((R:segstate.parent.nn.ph_vlng is s)
                              ((0.787158 0.0454125))
                              ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                <
                                4.8)
                               ((R:segstate.parent.p.ph_vlng is s)
                                ((0.724895 -0.159566))
                                ((0.795947 -0.00756686)))
                               ((0.484983 -0.445451)))))
                            ((R:segstate.parent.n.name is eh)
                             ((1.17708 0.254159))
                             ((R:segstate.parent.R:SylStructure.parent.last_accent
                               <
                               4.8)
                              ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                                <
                                0.1)
                               ((R:segstate.parent.n.name is ax)
                                ((0.354186 -0.612162))
                                ((R:segstate.parent.R:SylStructure.parent.next_accent
                                  <
                                  3.5)
                                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                                   <
                                   11.2)
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                    <
                                    0.3)
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                     is
                                     0)
                                    ((0.675675 -0.321998))
                                    ((0.374086 -0.440227)))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                     <
                                     0.3)
                                    ((0.815146 -0.042452))
                                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                                      <
                                      4.6)
                                     ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                       <
                                       1.1)
                                      ((0.379425 -0.489451))
                                      ((0.777685 -0.141802)))
                                     ((0.610923 -0.0932652)))))
                                  ((0.794607 -0.022666)))
                                 ((0.441025 -0.563171))))
                               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                 <
                                 3.3)
                                ((R:segstate.parent.R:SylStructure.parent.syl_out
                                  <
                                  5.8)
                                 ((R:segstate.parent.ph_cplace is a)
                                  ((R:segstate.parent.n.name is hh)
                                   ((0.477231 -0.43602))
                                   ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                     <
                                     1.1)
                                    ((R:segstate.parent.n.seg_onsetcoda
                                      is
                                      coda)
                                     ((R:segstate.parent.pp.ph_vlng
                                       is
                                       s)
                                      ((0.931158 0.0949845))
                                      ((0.564429 -0.338869)))
                                     ((0.96711 0.304647)))
                                    ((0.638516 -0.363477))))
                                  ((0.661292 -0.45645)))
                                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                                   <
                                   3.9)
                                  ((R:segstate.parent.ph_ctype is s)
                                   ((0.973608 0.296236))
                                   ((0.575591 0.0554893)))
                                  ((R:segstate.parent.nn.ph_vc is +)
                                   ((0.792111 -0.200003))
                                   ((0.698295 0.0347922)))))
                                ((R:segstate.parent.lisp_coda_stop
                                  is
                                  0)
                                 ((R:segstate.parent.nn.ph_cplace is a)
                                  ((0.912395 0.0546565))
                                  ((R:segstate.parent.nn.ph_cplace
                                    is
                                    0)
                                   ((0.725445 -0.19598))
                                   ((0.427342 -0.374191))))
                                 ((R:segstate.parent.nn.ph_vc is +)
                                  ((0.491689 -0.548635))
                                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                                    <
                                    3)
                                   ((0.4739 -0.368074))
                                   ((0.379037 -0.175875)))))))
                              ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                <
                                2.2)
                               ((0.973726 0.212222))
                               ((0.650854 -0.102387))))))))
                         ((R:segstate.parent.pp.ph_vfront is 1)
                          ((0.404066 -0.401472))
                          ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                            <
                            2.2)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                             is
                             0)
                            ((2.58069 0.773869))
                            ((0.753924 0.36466)))
                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                             <
                             8.9)
                            ((0.855593 -0.122185))
                            ((0.95228 0.190997)))))))))))))
                 ((name is dh_3)
                  ((0.714917 0.856072))
                  ((R:segstate.parent.ph_ctype is n)
                   ((p.name is ae_3)
                    ((1.56814 0.43164))
                    ((p.name is eh_3)
                     ((0.969601 0.0996302))
                     ((R:segstate.parent.nn.ph_cplace is l)
                      ((0.301599 -0.902369))
                      ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                        <
                        1.3)
                       ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                         <
                         3.2)
                        ((name is n_3)
                         ((0.194475 -0.682034))
                         ((R:segstate.parent.R:SylStructure.parent.syl_in
                           <
                           9)
                          ((0.510431 -0.534762))
                          ((0.711386 -0.229476))))
                        ((0.355512 -0.771654)))
                       ((R:segstate.parent.lisp_onset_stop is 0)
                        ((R:segstate.parent.ph_cplace is a)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                           <
                           1.2)
                          ((R:segstate.parent.p.ph_vlng is d)
                           ((0.347331 -0.399111))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                             is
                             0)
                            ((0.281382 -0.720055))
                            ((0.393115 -0.517881))))
                          ((0.599467 -0.274822)))
                         ((R:segstate.parent.n.name is ax)
                          ((name is m_1)
                           ((0.390154 -0.624972))
                           ((R:segstate.parent.R:SylStructure.parent.asyl_out
                             <
                             3.6)
                            ((0.469151 -0.466498))
                            ((0.741054 -0.0215363))))
                          ((R:segstate.parent.R:SylStructure.parent.syl_in
                            <
                            8.4)
                           ((0.774788 -0.303837))
                           ((1.22669 0.0667923)))))
                        ((0.482087 0.00342284)))))))
                   ((R:segstate.parent.ph_ctype is s)
                    ((R:segstate.parent.p.name is f)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       3.2)
                      ((0.732749 0.0784997))
                      ((1.5478 0.694652)))
                     ((name is t_2)
                      ((R:segstate.parent.pp.ph_vrnd is -)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         2.4)
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          1.2)
                         ((0.6712 -0.0759057))
                         ((1.7536 0.8682)))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                          is
                          0)
                         ((R:segstate.parent.R:SylStructure.parent.next_accent
                           <
                           2.4)
                          ((0.641394 -0.139453))
                          ((0.98729 0.265711)))
                         ((0.389209 -0.234613))))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         5.4)
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          1.5)
                         ((0.518435 -0.139451))
                         ((R:segstate.parent.p.ph_vheight is 2)
                          ((1.07574e-05 -0.429945))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                            <
                            1.2)
                           ((0.322474 -0.311935))
                           ((0.529274 -0.241131)))))
                        ((1.10441 0.116644))))
                      ((name is d_1)
                       ((R:segstate.parent.pp.ph_vrnd is -)
                        ((0.586905 -0.339079))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                          is
                          0)
                         ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                           <
                           1.2)
                          ((0.650413 0.037799))
                          ((1.06217 0.632865)))
                         ((0.804432 -0.126988))))
                       ((R:segstate.parent.pos_in_syl is 0)
                        ((R:segstate.parent.p.name is n)
                         ((name is t_3)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                            is
                            0)
                           ((0.660141 0.382406))
                           ((0.577053 0.813249)))
                          ((name is d_2)
                           ((R:segstate.parent.nn.ph_cplace is a)
                            ((0.263631 -0.561448))
                            ((0.0751216 -0.703099)))
                           ((R:segstate.parent.R:SylStructure.parent.syl_in
                             <
                             4.8)
                            ((0.277445 -0.422518))
                            ((0.404103 -0.0946238)))))
                         ((R:segstate.parent.ph_cplace is a)
                          ((R:segstate.parent.p.name is l)
                           ((0.667525 -0.00394319))
                           ((R:segstate.parent.pp.ph_vlng is s)
                            ((0.674999 -0.180364))
                            ((name is d_3)
                             ((R:segstate.parent.lisp_coda_nasal is 0)
                              ((R:segstate.parent.p.ph_vheight is 2)
                               ((0.137114 -0.518205))
                               ((0.401593 -0.337006)))
                              ((5.42751e-06 -0.583112)))
                             ((R:segstate.parent.R:SylStructure.parent.last_accent
                               <
                               4)
                              ((name is t_3)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                 <
                                 0.2)
                                ((0.17222 -0.722961))
                                ((R:segstate.parent.R:SylStructure.parent.syl_out
                                  <
                                  4)
                                 ((0.107945 -0.78353))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                   is
                                   0)
                                  ((0.0457316 -0.841185))
                                  ((0.0940016 -0.806432)))))
                               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                 <
                                 2.1)
                                ((R:segstate.parent.p.ph_vlng is d)
                                 ((0.377331 -0.451289))
                                 ((R:segstate.parent.nn.ph_cplace is a)
                                  ((0.359032 -0.562472))
                                  ((0.171623 -0.765736))))
                                ((R:segstate.parent.R:SylStructure.parent.syl_in
                                  <
                                  4.3)
                                 ((0.16962 -0.789714))
                                 ((0.29442 -0.690035)))))
                              ((0.451832 -0.531799))))))
                          ((R:segstate.parent.p.name is m)
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                             <
                             4.2)
                            ((0.379125 -0.73681))
                            ((0.61171 -0.51828)))
                           ((name is g_2)
                            ((0.468871 -0.563892))
                            ((name is p_3)
                             ((0.377425 -0.529319))
                             ((name is b_2)
                              ((0.299062 -0.479488))
                              ((R:segstate.parent.pp.ph_vfront is 1)
                               ((0.425375 -0.377306))
                               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                 <
                                 7.8)
                                ((R:segstate.parent.p.ph_vlng is d)
                                 ((R:segstate.parent.nn.ph_cplace is v)
                                  ((0.504762 -0.108677))
                                  ((0.74197 -0.29565)))
                                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                   <
                                   7)
                                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                    <
                                    2.4)
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                     <
                                     1.1)
                                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                      <
                                      2.4)
                                     ((0.906929 -0.191145))
                                     ((0.657841 0.0305569)))
                                    ((0.950279 0.449223)))
                                   ((0.635865 0.570119)))
                                  ((0.681066 -0.193093))))
                                ((0.638172 -0.339432))))))))))
                        ((R:segstate.parent.pos_in_syl is 3)
                         ((R:segstate.parent.lisp_onset_fric is 0)
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            7.8)
                           ((R:segstate.parent.p.name is s)
                            ((0.840581 -0.166174))
                            ((0.394612 -0.48887)))
                           ((0.710733 0.0308256)))
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            3.2)
                           ((0.504624 -0.46037))
                           ((0.235677 -0.613142))))
                         ((name is d_2)
                          ((1.23196 0.479062))
                          ((R:segstate.parent.p.name is er)
                           ((0.47771 -0.409392))
                           ((R:segstate.parent.R:SylStructure.parent.next_accent
                             <
                             1.4)
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                              <
                              3.6)
                             ((0.450818 -0.0899598))
                             ((0.514494 -0.326608)))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                              is
                              0)
                             ((0.586591 -0.167577))
                             ((0.685643 0.389092)))))))))))
                    ((R:segstate.parent.n.ph_vc is +)
                     ((name is f_1)
                      ((0.189692 -0.713263))
                      ((name is er_1)
                       ((R:segstate.parent.lisp_onset_fric is 0)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          7)
                         ((0.982546 0.804888))
                         ((1.09582 0.399106)))
                        ((1.01432 0.0598579)))
                       ((name is v_2)
                        ((R:segstate.parent.p.name is ow)
                         ((0.324469 -0.957367))
                         ((R:segstate.parent.pp.ph_cplace is a)
                          ((0.709763 -0.429064))
                          ((1.01327 0.120265))))
                        ((name is s_2)
                         ((R:segstate.parent.pp.ph_vrnd is +)
                          ((0.464885 0.379315))
                          ((R:segstate.parent.p.ph_vc is +)
                           ((0.706675 -0.708709))
                           ((R:segstate.parent.R:SylStructure.parent.next_accent
                             <
                             1.8)
                            ((0.54294 -0.589146))
                            ((0.707408 0.0312561)))))
                         ((R:segstate.parent.R:SylStructure.parent.asyl_in
                           <
                           1.2)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                            is
                            0)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                             <
                             1.1)
                            ((R:segstate.parent.nn.ph_cplace is 0)
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               4.6)
                              ((1.33325 0.374211))
                              ((0.65781 -0.0739071)))
                             ((name is er_3)
                              ((0.375878 -0.483933))
                              ((R:segstate.parent.p.ph_vc is +)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                 is
                                 0)
                                ((R:segstate.parent.R:SylStructure.parent.syl_in
                                  <
                                  4.6)
                                 ((R:segstate.parent.p.ph_vheight is 2)
                                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                                    <
                                    3.6)
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                     <
                                     0.1)
                                    ((0.863183 -0.165701))
                                    ((0.734106 0.0783397)))
                                   ((0.493144 -0.2034)))
                                  ((0.871057 0.230796)))
                                 ((0.633422 -0.22759)))
                                ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                  <
                                  1.2)
                                 ((0.429341 -0.484097))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                   is
                                   0)
                                  ((0.448812 -0.317327))
                                  ((0.728648 -0.0897347)))))
                               ((1.04937 0.307053)))))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                              is
                              0)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                               is
                               0)
                              ((0.398236 -0.504691))
                              ((0.766366 -0.239572)))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                               <
                               0.1)
                              ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                                <
                                2.2)
                               ((0.331859 -0.361465))
                               ((0.695885 -0.271987)))
                              ((0.855386 -0.0495944)))))
                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                             <
                             12.2)
                            ((R:segstate.parent.nn.ph_cplace is 0)
                             ((0.629933 -0.192446))
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               6.6)
                              ((R:segstate.parent.lisp_coda_nasal is 0)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                 <
                                 0.3)
                                ((1.09116 0.0956908))
                                ((1.44468 0.478813)))
                               ((R:segstate.parent.p.ph_vlng is d)
                                ((0.520551 -0.00379145))
                                ((0.549543 -0.157784))))
                              ((0.605549 -0.214303))))
                            ((1.0237 0.482894))))
                          ((R:segstate.parent.R:SylStructure.parent.syl_in
                            <
                            6)
                           ((R:segstate.parent.p.ph_vlng is d)
                            ((0.616803 -0.0398475))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                              <
                              0.3)
                             ((1.13364 0.725141))
                             ((R:segstate.parent.n.name is ax)
                              ((1.15482 0.0241406))
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                <
                                1.1)
                               ((1.42109 0.704655))
                               ((1.28404 0.155542))))))
                           ((p.name is ey_3)
                            ((0.456776 -0.417052))
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              8.2)
                             ((R:segstate.parent.p.seg_onsetcoda
                               is
                               coda)
                              ((R:segstate.parent.R:SylStructure.parent.last_accent
                                <
                                2.1)
                               ((name is v_1)
                                ((0.568101 -0.229871))
                                ((p.name is eh_3)
                                 ((0.75202 0.491252))
                                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                   <
                                   9)
                                  ((R:segstate.parent.pp.ph_cplace
                                    is
                                    a)
                                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                                     <
                                     9.3)
                                    ((0.822682 0.421373))
                                    ((0.905668 -0.000583136)))
                                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                                     <
                                     2.4)
                                    ((R:segstate.parent.ph_cplace is b)
                                     ((0.829956 0.559494))
                                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                                       <
                                       6.6)
                                      ((R:segstate.parent.ph_cplace
                                        is
                                        a)
                                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                         is
                                         0)
                                        ((0.24257 -0.452574))
                                        ((0.352187 -0.350837)))
                                       ((R:segstate.parent.p.ph_vheight
                                         is
                                         2)
                                        ((0.604334 -0.175852))
                                        ((1.07043 0.0705926))))
                                      ((1.44184 0.338289))))
                                    ((0.784005 -0.474545))))
                                  ((0.989426 0.360423)))))
                               ((1.18719 0.458566)))
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                is
                                0)
                               ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                 <
                                 3.2)
                                ((0.808355 -0.384815))
                                ((0.530227 -0.204455)))
                               ((1.08539 0.140896))))
                             ((0.625154 -0.311852))))))))))
                     ((name is z_3)
                      ((R:segstate.parent.pos_in_syl is 3)
                       ((0.735394 -0.0441603))
                       ((1.5686 1.25986)))
                      ((name is er_3)
                       ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                         <
                         1.2)
                        ((R:segstate.parent.p.name is v)
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           5.8)
                          ((0.218123 -0.613357))
                          ((0.234978 -0.458445)))
                         ((R:segstate.parent.p.name is aw)
                          ((0.157232 -0.660203))
                          ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                            <
                            1.3)
                           ((0.418836 -0.451928))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                             is
                             0)
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                              <
                              3.1)
                             ((1.22232 0.772606))
                             ((0.882612 0.159941)))
                            ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                              <
                              2.2)
                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                               <
                               6.2)
                              ((0.95018 0.116763))
                              ((0.843369 -0.078216)))
                             ((0.398986 -0.33819)))))))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                          <
                          3.1)
                         ((1.29329 1.40794))
                         ((1.14983 0.92918))))
                       ((p.name is aw_3)
                        ((1.23346 0.423191))
                        ((R:segstate.parent.nn.ph_cplace is 0)
                         ((name is er_1)
                          ((p.name is v_3)
                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                             <
                             4.2)
                            ((0.630647 -0.0249535))
                            ((0.53084 0.0554711)))
                           ((R:segstate.parent.pp.ph_cplace is a)
                            ((0.536357 -0.475566))
                            ((R:segstate.parent.lisp_onset_fric is 0)
                             ((p.name is t_3)
                              ((0.0679017 -0.780768))
                              ((0.426827 -0.598637)))
                             ((0.0824618 -0.791431)))))
                          ((R:segstate.parent.pp.ph_vlng is l)
                           ((1.02653 0.318669))
                           ((R:segstate.parent.pp.ph_vlng is d)
                            ((0.950592 0.125892))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                              <
                              0.3)
                             ((R:segstate.parent.p.seg_onsetcoda
                               is
                               coda)
                              ((R:segstate.parent.n.name is t)
                               ((0.602287 -0.464206))
                               ((0.391587 -0.786827)))
                              ((0.616803 -0.327862)))
                             ((R:segstate.parent.nn.ph_vlng is d)
                              ((0.551836 -0.536682))
                              ((R:segstate.parent.pp.ph_vlng is s)
                               ((0.900281 0.0985496))
                               ((R:segstate.parent.pp.ph_ctype is 0)
                                ((0.501749 -0.521336))
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                  is
                                  0)
                                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                   <
                                   1.2)
                                  ((0.693861 -0.212182))
                                  ((0.418187 -0.53867)))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                   is
                                   0)
                                  ((0.600667 -0.381482))
                                  ((R:segstate.parent.syl_final is 0)
                                   ((0.560866 -0.295475))
                                   ((R:segstate.parent.ph_ctype is r)
                                    ((0.714337 0.0112811))
                                    ((1.0635 0.259234)))))))))))))
                         ((R:segstate.parent.pp.ph_cplace is a)
                          ((R:segstate.parent.R:SylStructure.parent.next_accent
                            <
                            1.5)
                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                             <
                             6.5)
                            ((0.192853 -0.847999))
                            ((0.228412 -0.767232)))
                           ((0.368064 -0.580292)))
                          ((R:segstate.parent.p.name is dh)
                           ((0.196395 -0.76547))
                           ((R:segstate.parent.p.ph_vheight is 2)
                            ((0.783106 -0.643646))
                            ((name is er_1)
                             ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                               <
                               2.6)
                              ((0.511835 -0.3759))
                              ((0.292439 -0.725126)))
                             ((R:segstate.parent.pp.ph_vc is +)
                              ((R:segstate.parent.R:SylStructure.parent.next_accent
                                <
                                1.5)
                               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                 <
                                 3.7)
                                ((0.239175 -0.667663))
                                ((0.637562 -0.470169)))
                               ((0.681487 -0.18089)))
                              ((1.24892 0.310455))))))))))))))))))))
            ((R:segstate.parent.p.name is ao)
             ((R:segstate.parent.n.seg_onsetcoda is coda)
              ((R:segstate.parent.n.ph_vc is +)
               ((name is r_1)
                ((0.898874 0.427824))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  3.3)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                   is
                   0)
                  ((0.730552 -0.0867754))
                  ((0.783748 0.28425)))
                 ((0.793109 -0.357454))))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  2.5)
                 ((0.728807 0.161345))
                 ((0.586991 -0.109588)))
                ((name is r_2)
                 ((0.270728 -0.570988))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                   is
                   0)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((0.853701 -0.0485006))
                   ((0.400809 -0.210578)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((0.42413 -0.272989))
                   ((R:segstate.parent.ph_ctype is r)
                    ((0.315846 -0.406905))
                    ((0.515805 -0.571612))))))))
              ((R:segstate.parent.n.name is r)
               ((0.46677 -0.799564))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                 <
                 1.3)
                ((R:segstate.parent.pp.ph_cplace is b)
                 ((0.365813 -0.523935))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                   is
                   0)
                  ((0.632597 -0.3869))
                  ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                    <
                    0.1)
                   ((1.05427 0.280415))
                   ((0.605728 -0.217603)))))
                ((R:segstate.parent.nn.ph_vlng is d)
                 ((R:segstate.parent.pp.ph_ctype is f)
                  ((0.468712 -0.54933))
                  ((0.244937 -0.803856)))
                 ((R:segstate.parent.n.name is dh)
                  ((0.30795 -0.617895))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     2.5)
                    ((0.703257 -0.270539))
                    ((name is r_3)
                     ((0.403555 -0.31148))
                     ((R:segstate.parent.R:SylStructure.parent.position_type
                       is
                       initial)
                      ((0.424754 -0.496501))
                      ((0.219517 -0.727158)))))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                     is
                     0)
                    ((0.371472 -0.444416))
                    ((0.95409 -0.0812092)))))))))
             ((R:segstate.parent.lisp_onset_stop is 0)
              ((name is t_3)
               ((R:segstate.parent.n.name is hh)
                ((0.602087 -0.150592))
                ((R:segstate.parent.nn.ph_vrnd is -)
                 ((R:segstate.parent.lisp_coda_fric is 0)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                     is
                     content)
                    ((0.144374 -0.762709))
                    ((0.229732 -0.655831)))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                     is
                     0)
                    ((0.0602088 -0.834609))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                      is
                      0)
                     ((0.210994 -0.727423))
                     ((0.119974 -0.81129)))))
                  ((0.44652 -0.558671)))
                 ((R:segstate.parent.nn.ph_cplace is 0)
                  ((1.11391 -0.0401343))
                  ((R:segstate.parent.pos_in_syl is 3)
                   ((0.516459 -0.430418))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                     is
                     0)
                    ((0.417799 -0.597534))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                      is
                      0)
                     ((0.24814 -0.712985))
                     ((0.0976711 -0.801062))))))))
               ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                 is
                 pps)
                ((R:segstate.parent.p.name is t)
                 ((R:segstate.parent.n.ph_vc is +)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    3.1)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                     is
                     0)
                    ((0.339811 -0.511672))
                    ((0.0337312 -0.621569)))
                   ((0.38894 -0.332775)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                    is
                    0)
                   ((0.284022 -0.90748))
                   ((0.541499 -0.515165))))
                 ((R:segstate.parent.ph_cplace is g)
                  ((R:segstate.parent.p.name is n)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                     <
                     1.2)
                    ((0.749088 0.128595))
                    ((0.285606 -0.466688)))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                     is
                     0)
                    ((0.509327 -0.200963))
                    ((R:segstate.parent.nn.ph_cplace is a)
                     ((name is hh_3)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                        <
                        0.3)
                       ((2.97189e-06 -0.627692))
                       ((0.117634 -0.588421)))
                      ((R:segstate.parent.pp.ph_vfront is 2)
                       ((0.378598 -0.301525))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                         <
                         0.3)
                        ((0.0673012 -0.583849))
                        ((0.467595 -0.386029)))))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       1.4)
                      ((0.81555 -0.163102))
                      ((0.372879 -0.328562))))))
                  ((name is r_1)
                   ((0.107555 -0.65653))
                   ((name is er_3)
                    ((0.508784 -0.367121))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                      is
                      0)
                     ((R:segstate.parent.pp.ph_vrnd is -)
                      ((0.510537 -0.499464))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                        is
                        0)
                       ((0.609267 -0.224895))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                         <
                         0.3)
                        ((0.848206 0.107291))
                        ((0.76586 0.214243)))))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                       <
                       0.1)
                      ((1.01958 -0.0140113))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                        is
                        0)
                       ((1.00319 0.145012))
                       ((1.16164 0.542008)))))))))
                ((name is er_1)
                 ((R:segstate.parent.n.ph_vc is +)
                  ((0.862553 1.48119))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    1.5)
                   ((0.930962 -0.0359209))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                     is
                     0)
                    ((0.990138 0.785021))
                    ((1.1005 0.151982)))))
                 ((R:segstate.parent.nn.ph_vc is +)
                  ((name is dh_3)
                   ((R:segstate.parent.nn.ph_vlng is s)
                    ((1.90064 2.55354))
                    ((1.45821 1.74622)))
                   ((name is d_2)
                    ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                      <
                      2.2)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                       is
                       0)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        7.2)
                       ((1.16502 0.919987))
                       ((1.05246 0.179095)))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                        is
                        0)
                       ((1.13346 1.38878))
                       ((0.77945 0.915263))))
                     ((0.564425 -0.5273)))
                    ((p.name is ae_3)
                     ((R:segstate.parent.n.name is dh)
                      ((1.40289 1.34157))
                      ((R:segstate.parent.n.name is t)
                       ((0.372867 -0.501596))
                       ((R:segstate.parent.nn.ph_vrnd is +)
                        ((1.11805 0.948221))
                        ((R:segstate.parent.n.name is s)
                         ((0.362969 -0.359922))
                         ((R:segstate.parent.pp.ph_cplace is 0)
                          ((1.25866 1.04338))
                          ((name is d_1)
                           ((R:segstate.parent.R:SylStructure.parent.asyl_out
                             <
                             2.4)
                            ((1.17042 0.623711))
                            ((0.482809 0.180617)))
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                             <
                             4)
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                              <
                              1.2)
                             ((0.526614 -0.0964956))
                             ((1.50499 0.53586)))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                              is
                              0)
                             ((0.456021 -0.320589))
                             ((0.975298 0.0276096))))))))))
                     ((name is v_1)
                      ((R:segstate.parent.n.name is dh)
                       ((R:segstate.parent.pp.ph_vc is +)
                        ((0.669464 0.0861521))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                          is
                          0)
                         ((1.15632 0.340591))
                         ((1.0198 1.21987))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                         is
                         0)
                        ((0.721182 -0.445959))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                          is
                          0)
                         ((1.35598 0.418386))
                         ((0.604789 -0.106113)))))
                      ((name is m_3)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                         <
                         0.1)
                        ((0.755887 -0.137474))
                        ((1.19868 0.770415)))
                       ((R:segstate.parent.seg_onsetcoda is coda)
                        ((name is z_2)
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           4.6)
                          ((0.859621 0.833521))
                          ((0.691083 0.157204)))
                         ((name is t_1)
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            4.9)
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                             <
                             3.6)
                            ((1.34457 1.21651))
                            ((0.939819 0.169222)))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                             <
                             1.2)
                            ((0.693776 -0.290475))
                            ((0.979161 0.175474))))
                          ((R:segstate.parent.R:SylStructure.parent.asyl_out
                            <
                            1.6)
                           ((name is v_2)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                              <
                              1.2)
                             ((0.938202 0.166408))
                             ((1.29425 0.861702)))
                            ((p.name is eh_3)
                             ((1.29033 0.518295))
                             ((R:segstate.parent.pp.ph_ctype is s)
                              ((R:segstate.parent.ph_ctype is f)
                               ((0.608634 -0.219652))
                               ((1.10484 0.544575)))
                              ((R:segstate.parent.pp.ph_vfront is 1)
                               ((0.977276 0.27226))
                               ((R:segstate.parent.lisp_coda_glide
                                 is
                                 0)
                                ((R:segstate.parent.R:SylStructure.parent.next_accent
                                  <
                                  4)
                                 ((R:segstate.parent.pp.ph_ctype is n)
                                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                                    <
                                    1.6)
                                   ((0.54397 -0.327955))
                                   ((0.372399 -0.530911)))
                                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                                    <
                                    2.7)
                                   ((R:segstate.parent.p.name is aa)
                                    ((0.41434 -0.339552))
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                      is
                                      0)
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                       is
                                       0)
                                      ((0.907234 -0.0921378))
                                      ((R:segstate.parent.ph_cplace
                                        is
                                        a)
                                       ((0.573915 -0.215166))
                                       ((0.403287 -0.485906))))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                       <
                                       1.3)
                                      ((0.419318 -0.29829))
                                      ((R:segstate.parent.p.ph_vheight
                                        is
                                        2)
                                       ((1.08912 0.143777))
                                       ((0.648075 -0.154596))))))
                                   ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                     <
                                     0.1)
                                    ((0.496936 -0.584584))
                                    ((0.612386 -0.235511)))))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                   <
                                   1.2)
                                  ((1.18138 0.339046))
                                  ((0.870016 -0.037549))))
                                ((R:segstate.parent.R:SylStructure.parent.syl_in
                                  <
                                  5.8)
                                 ((0.53609 -0.299871))
                                 ((1.19808 0.437675))))))))
                           ((name is r_2)
                            ((R:segstate.parent.pp.ph_ctype is f)
                             ((0.807146 -0.111093))
                             ((1.22975 0.71623)))
                            ((R:segstate.parent.pp.ph_vfront is 1)
                             ((R:segstate.parent.R:SylStructure.parent.asyl_out
                               <
                               3.5)
                              ((R:segstate.parent.p.ph_vheight is 3)
                               ((1.02623 0.0331608))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                 is
                                 0)
                                ((R:segstate.parent.R:SylStructure.parent.syl_out
                                  <
                                  5.4)
                                 ((0.518881 -0.307426))
                                 ((0.885305 -0.131719)))
                                ((0.649683 -0.541267))))
                              ((R:segstate.parent.R:SylStructure.parent.position_type
                                is
                                initial)
                               ((0.410683 -0.887858))
                               ((R:segstate.parent.lisp_coda_stop is 0)
                                ((0.347037 -0.589572))
                                ((0.465628 -0.322553)))))
                             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                               is
                               in)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                is
                                0)
                               ((R:segstate.parent.pp.ph_ctype is n)
                                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                  <
                                  5.5)
                                 ((0.666785 -0.623234))
                                 ((0.931658 -0.122466)))
                                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                  <
                                  0.4)
                                 ((0.658551 -0.409531))
                                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                   <
                                   4.2)
                                  ((R:segstate.parent.p.name is ah)
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                     is
                                     0)
                                    ((0.589996 0.112919))
                                    ((1.13038 -0.0934094)))
                                   ((0.830807 -0.375896)))
                                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                    <
                                    5.4)
                                   ((0.953601 0.309501))
                                   ((0.760016 -0.0076324))))))
                               ((R:segstate.parent.p.name is ae)
                                ((0.355085 -0.284141))
                                ((R:segstate.parent.R:SylStructure.parent.syl_out
                                  <
                                  7.6)
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                   is
                                   0)
                                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                    <
                                    3)
                                   ((1.16078 0.654861))
                                   ((1.27624 0.400642)))
                                  ((0.95637 0.17736)))
                                 ((0.690351 -0.280104)))))
                              ((name is l_2)
                               ((0.908322 0.222579))
                               ((R:segstate.parent.n.name is t)
                                ((R:segstate.parent.p.name is ae)
                                 ((1.60582 0.722648))
                                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                                   <
                                   2)
                                  ((0.821094 -0.292848))
                                  ((0.702883 -0.0590444))))
                                ((p.name is aa_3)
                                 ((1.0423 0.240377))
                                 ((R:segstate.parent.n.name is l)
                                  ((R:segstate.parent.pp.ph_ctype is 0)
                                   ((0.333946 -0.880402))
                                   ((0.837582 -0.345765)))
                                  ((name is n_2)
                                   ((R:segstate.parent.p.name is ae)
                                    ((0.68693 -0.458555))
                                    ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                      <
                                      0.1)
                                     ((0.921764 0.629809))
                                     ((0.841039 0.232705))))
                                   ((name is er_2)
                                    ((1.04686 0.0991708))
                                    ((p.name is eh_3)
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                       is
                                       0)
                                      ((0.847318 0.18478))
                                      ((0.60175 -0.311319)))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                       is
                                       0)
                                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                        <
                                        3.2)
                                       ((R:segstate.parent.lisp_coda_glide
                                         is
                                         0)
                                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                          is
                                          0)
                                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                           <
                                           0.1)
                                          ((0.415354 -0.296495))
                                          ((0.43022 -0.477127)))
                                         ((0.647844 -0.145607)))
                                        ((0.350587 -0.490902)))
                                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                         <
                                         0.1)
                                        ((0.240827 -0.683133))
                                        ((0.30093 -0.506395))))
                                      ((R:segstate.parent.n.name is b)
                                       ((R:segstate.parent.lisp_coda_fric
                                         is
                                         0)
                                        ((0.347271 -0.337656))
                                        ((0.265189 -0.745637)))
                                       ((R:segstate.parent.pp.ph_ctype
                                         is
                                         r)
                                        ((0.450283 -0.563117))
                                        ((R:segstate.parent.R:SylStructure.parent.last_accent
                                          <
                                          1.4)
                                         ((R:segstate.parent.ph_ctype
                                           is
                                           s)
                                          ((R:segstate.parent.nn.ph_vlng
                                            is
                                            d)
                                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                             is
                                             0)
                                            ((0.797168 -0.292586))
                                            ((0.482319 -0.652541)))
                                           ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                             <
                                             1.5)
                                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                                              <
                                              6.8)
                                             ((0.810997 0.0441394))
                                             ((0.516282 -0.221816)))
                                            ((0.491884 -0.3469))))
                                          ((R:segstate.parent.pp.ph_cplace
                                            is
                                            d)
                                           ((0.521902 -0.385095))
                                           ((R:segstate.parent.p.ph_vheight
                                             is
                                             2)
                                            ((1.1049 0.251693))
                                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                              <
                                              0.1)
                                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                                               <
                                               7.2)
                                              ((0.555868 -0.701593))
                                              ((0.525318 -0.00643125)))
                                             ((1.01319 0.00617071))))))
                                         ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                           <
                                           2.6)
                                          ((0.392507 -0.575797))
                                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                            is
                                            0)
                                           ((0.748505 -0.128578))
                                           ((R:segstate.parent.lisp_coda_stop
                                             is
                                             0)
                                            ((0.724962 -0.308663))
                                            ((0.139518 -0.475744))))))))))))))))))))))
                        ((p.name is pau_2)
                         ((0.900546 -0.36509))
                         ((name is n_3)
                          ((0.575399 -0.315687))
                          ((R:segstate.parent.n.name is aw)
                           ((1.30726 0.692161))
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                             <
                             6.6)
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                              <
                              0.6)
                             ((1.00673 0.518653))
                             ((name is dh_1)
                              ((0.887023 0.396708))
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                is
                                0)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                 is
                                 0)
                                ((0.910365 -0.0623606))
                                ((0.546725 -0.442203)))
                               ((R:segstate.parent.pp.ph_vfront is 1)
                                ((1.02959 0.35781))
                                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                  <
                                  4.5)
                                 ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                                   is
                                   det)
                                  ((1.03356 0.343329))
                                  ((R:segstate.parent.ph_cplace is g)
                                   ((0.933698 0.239167))
                                   ((R:segstate.parent.n.name is iy)
                                    ((0.93213 -0.370614))
                                    ((R:segstate.parent.pp.ph_ctype
                                      is
                                      n)
                                     ((0.891889 0.161171))
                                     ((R:segstate.parent.pp.ph_cplace
                                       is
                                       0)
                                      ((0.711897 0.0355691))
                                      ((0.51447 -0.184535)))))))
                                 ((0.618674 -0.282077)))))))
                            ((1.17976 0.500672))))))))))))
                  ((name is k_3)
                   ((0.403438 -0.947156))
                   ((p.name is ng_3)
                    ((R:segstate.parent.ph_ctype is f)
                     ((0.501555 -0.519476))
                     ((0.208473 -0.819945)))
                    ((name is dh_1)
                     ((p.name is t_3)
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        2.4)
                       ((1.10251 -0.0482073))
                       ((0.206748 -0.593083)))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                        is
                        0)
                       ((1.48015 0.898236))
                       ((R:segstate.parent.p.name is pau)
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          4.6)
                         ((p.name is pau_2)
                          ((1.22724 0.618596))
                          ((0.768195 0.0752747)))
                         ((p.name is pau_5)
                          ((0.633779 -0.195436))
                          ((0.277171 -0.665618))))
                        ((R:segstate.parent.pp.ph_vfront is 2)
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           3.6)
                          ((0.996511 0.401683))
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            2.6)
                           ((0.947007 0.00341576))
                           ((0.593565 -0.363897))))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                           is
                           0)
                          ((1.04571 0.404073))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                            is
                            0)
                           ((1.02766 1.06813))
                           ((0.689487 0.675044))))))))
                     ((R:segstate.parent.p.name is r)
                      ((R:segstate.parent.n.name is ih)
                       ((1.64225 0.705413))
                       ((R:segstate.parent.n.name is ae)
                        ((1.44313 0.50372))
                        ((R:segstate.parent.R:SylStructure.parent.last_accent
                          <
                          3)
                         ((p.name is r_3)
                          ((R:segstate.parent.pos_in_syl is 0)
                           ((1.10223 -0.125052))
                           ((1.25624 0.754483)))
                          ((R:segstate.parent.pos_in_syl is 0)
                           ((R:segstate.parent.ph_cplace is a)
                            ((0.97405 0.294258))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                              is
                              0)
                             ((0.750177 -0.206395))
                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                               <
                               5)
                              ((0.895533 0.268217))
                              ((0.606356 -0.0131846)))))
                           ((0.594983 -0.528564))))
                         ((R:segstate.parent.pos_in_syl is 0)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                            is
                            0)
                           ((0.833372 0.247139))
                           ((0.967956 0.420419)))
                          ((0.860732 -0.0631656))))))
                      ((R:segstate.parent.p.ph_vc is +)
                       ((name is hh_2)
                        ((R:segstate.parent.p.name is ay)
                         ((1.62215 1.37805))
                         ((1.03973 0.311288)))
                        ((name is m_2)
                         ((R:segstate.parent.p.ph_vlng is d)
                          ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                            <
                            5)
                           ((1.04431 0.996119))
                           ((1.15612 0.575828)))
                          ((R:segstate.parent.syl_final is 0)
                           ((1.09618 -0.180697))
                           ((1.03398 0.309644))))
                         ((name is r_2)
                          ((R:segstate.parent.R:SylStructure.parent.syl_in
                            <
                            3.8)
                           ((0.570429 0.201342))
                           ((1.29064 0.644274)))
                          ((name is d_1)
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                             <
                             4.6)
                            ((1.641 0.947903))
                            ((0.601382 0.00804474)))
                           ((name is l_3)
                            ((0.314342 -0.560784))
                            ((name is t_1)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                               <
                               0.3)
                              ((R:segstate.parent.pp.ph_cplace is a)
                               ((0.286706 -0.643595))
                               ((0.423773 -0.502915)))
                              ((R:segstate.parent.R:SylStructure.parent.syl_in
                                <
                                3.2)
                               ((0.782003 0.12233))
                               ((0.483771 -0.612333))))
                             ((p.name is aa_3)
                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                <
                                2.6)
                               ((0.662367 0.00387032))
                               ((1.32926 0.685188)))
                              ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                                is
                                content)
                               ((name is hh_3)
                                ((1.2165 0.838445))
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                  <
                                  1.2)
                                 ((name is f_2)
                                  ((1.01879 0.493464))
                                  ((name is n_2)
                                   ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                     <
                                     2.2)
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                      is
                                      0)
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                       is
                                       0)
                                      ((0.768908 0.585686))
                                      ((0.845359 -0.147242)))
                                     ((1.08409 0.857779)))
                                    ((0.790239 -0.350348)))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                     <
                                     0.1)
                                    ((R:segstate.parent.lisp_coda_fric
                                      is
                                      0)
                                     ((R:segstate.parent.lisp_coda_glide
                                       is
                                       0)
                                      ((R:segstate.parent.pp.ph_cplace
                                        is
                                        a)
                                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                         <
                                         4.4)
                                        ((0.949342 0.0134155))
                                        ((0.412105 -0.416036)))
                                       ((R:segstate.parent.n.name
                                         is
                                         pau)
                                        ((1.33094 0.593224))
                                        ((R:segstate.parent.lisp_coda_nasal
                                          is
                                          0)
                                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                           <
                                           0.1)
                                          ((1.09184 0.351547))
                                          ((1.11137 -0.00472653)))
                                         ((0.618084 -0.121481)))))
                                      ((1.26988 0.661411)))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                       is
                                       0)
                                      ((0.928586 -0.154137))
                                      ((0.414922 -0.562942))))
                                    ((R:segstate.parent.pp.ph_ctype
                                      is
                                      r)
                                     ((0.537066 -0.478048))
                                     ((R:segstate.parent.pp.ph_cplace
                                       is
                                       g)
                                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                        <
                                        1.5)
                                       ((0.28472 -0.548437))
                                       ((R:segstate.parent.lisp_coda_fric
                                         is
                                         0)
                                        ((R:segstate.parent.R:SylStructure.parent.next_accent
                                          <
                                          1.4)
                                         ((0.38115 -0.493077))
                                         ((0.740208 -0.181932)))
                                        ((0.644502 -0.0766448))))
                                      ((R:segstate.parent.ph_ctype
                                        is
                                        r)
                                       ((0.500951 -0.436274))
                                       ((R:segstate.parent.lisp_onset_nasal
                                         is
                                         0)
                                        ((p.name is ay_3)
                                         ((1.13777 0.46001))
                                         ((R:segstate.parent.R:SylStructure.parent.syl_in
                                           <
                                           1.4)
                                          ((R:segstate.parent.lisp_coda_fric
                                            is
                                            0)
                                           ((0.420134 -0.474021))
                                           ((0.591848 -0.0880958)))
                                          ((R:segstate.parent.nn.ph_cplace
                                            is
                                            b)
                                           ((0.874756 0.427512))
                                           ((p.name is er_3)
                                            ((0.457453 -0.32849))
                                            ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                              <
                                              1.3)
                                             ((0.82825 0.257921))
                                             ((R:segstate.parent.ph_ctype
                                               is
                                               f)
                                              ((R:segstate.parent.lisp_onset_fric
                                                is
                                                0)
                                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                                 <
                                                 0.1)
                                                ((0.629094 -0.319907))
                                                ((0.381159 -0.432954)))
                                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                                 is
                                                 0)
                                                ((0.880048 0.207807))
                                                ((0.677602 -0.231284))))
                                              ((R:segstate.parent.n.name
                                                is
                                                d)
                                               ((0.575259 -0.445373))
                                               ((R:segstate.parent.n.ph_vc
                                                 is
                                                 +)
                                                ((0.855254 -0.232869))
                                                ((R:segstate.parent.R:SylStructure.parent.syl_out
                                                  <
                                                  8)
                                                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                                   <
                                                   3.4)
                                                  ((1.19924 0.864943))
                                                  ((1.02686 0.258176)))
                                                 ((0.627689 -0.0443329)))))))))))
                                        ((R:segstate.parent.p.ph_vlng
                                          is
                                          d)
                                         ((R:segstate.parent.pp.ph_cplace
                                           is
                                           l)
                                          ((0.574516 -0.233545))
                                          ((0.34331 -0.545264)))
                                         ((R:segstate.parent.syl_final
                                           is
                                           0)
                                          ((0.943431 0.214529))
                                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                            is
                                            0)
                                           ((R:segstate.parent.p.ph_vheight
                                             is
                                             2)
                                            ((0.581076 -0.208569))
                                            ((0.315543 -0.424798)))
                                           ((0.534588 0.00498417))))))))))))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                   <
                                   1.1)
                                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                    <
                                    5)
                                   ((0.969404 0.0470934))
                                   ((1.20221 0.274939)))
                                  ((1.38494 0.59854)))))
                               ((R:segstate.parent.p.ph_vlng is s)
                                ((name is z_1)
                                 ((0.814158 0.332541))
                                 ((R:segstate.parent.ph_cplace is b)
                                  ((R:segstate.parent.n.seg_onsetcoda
                                    is
                                    coda)
                                   ((R:segstate.parent.R:SylStructure.parent.last_accent
                                     <
                                     1.8)
                                    ((R:segstate.parent.nn.ph_cplace
                                      is
                                      l)
                                     ((0.573975 -0.303561))
                                     ((p.name is ah_3)
                                      ((0.723551 0.256321))
                                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                                        <
                                        6.2)
                                       ((name is v_2)
                                        ((0.728168 -0.137785))
                                        ((0.582604 -0.293723)))
                                       ((0.662688 0.0668043)))))
                                    ((p.name is ah_3)
                                     ((0.687978 -0.148841))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                       <
                                       2)
                                      ((name is v_3)
                                       ((1.18968 0.28041))
                                       ((0.8116 -0.0539345)))
                                      ((0.830489 0.499843)))))
                                   ((0.616335 -0.346905)))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                    is
                                    0)
                                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                     <
                                     4.5)
                                    ((R:segstate.parent.R:SylStructure.parent.sub_phrases
                                      <
                                      0.1)
                                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                                       <
                                       7.5)
                                      ((R:segstate.parent.R:SylStructure.parent.next_accent
                                        <
                                        3.6)
                                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                         <
                                         5.2)
                                        ((0.692521 -0.109031))
                                        ((0.444615 0.0294222)))
                                       ((0.428932 -0.349396)))
                                      ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                        <
                                        0.1)
                                       ((0.754424 -0.214908))
                                       ((0.391079 -0.470374))))
                                     ((0.487462 -0.496804)))
                                    ((0.429507 -0.511415)))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                     is
                                     0)
                                    ((0.588196 -0.280472))
                                    ((R:segstate.parent.ph_ctype is s)
                                     ((1.03488 0.261259))
                                     ((0.669236 -0.0930502)))))))
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                  <
                                  0.2)
                                 ((0.398041 -0.788556))
                                 ((name is hh_1)
                                  ((2.11029e-06 -0.646882))
                                  ((R:segstate.parent.ph_cplace is d)
                                   ((0.536167 -0.0885474))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                     is
                                     0)
                                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                      <
                                      4.2)
                                     ((0.637547 -0.0565366))
                                     ((0.741287 -0.244256)))
                                    ((0.3719 -0.539484)))))))))))))))
                       ((name is s_1)
                        ((R:segstate.parent.n.name is iy)
                         ((1.0954 1.17762))
                         ((R:segstate.parent.nn.ph_cplace is a)
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            4.3)
                           ((1.22191 0.846224))
                           ((1.27316 0.160578)))
                          ((R:segstate.parent.R:SylStructure.parent.position_type
                            is
                            initial)
                           ((1.15581 0.200574))
                           ((0.686209 -0.528184)))))
                        ((R:segstate.parent.pp.ph_vlng is a)
                         ((R:segstate.parent.R:SylStructure.parent.asyl_in
                           <
                           3.5)
                          ((R:segstate.parent.n.name is ih)
                           ((0.539992 -0.398492))
                           ((R:segstate.parent.pos_in_syl is 1)
                            ((0.471368 -0.221064))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                              <
                              1.2)
                             ((R:segstate.parent.R:SylStructure.parent.asyl_in
                               <
                               0.3)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                is
                                0)
                               ((0.481911 -0.186928))
                               ((0.675243 -0.014974)))
                              ((R:segstate.parent.ph_cplace is d)
                               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                 <
                                 3.5)
                                ((0.510123 0.012278))
                                ((0.560054 -0.204039)))
                               ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                 <
                                 1.2)
                                ((R:segstate.parent.R:SylStructure.parent.next_accent
                                  <
                                  1.5)
                                 ((1.13324 0.276553))
                                 ((1.11266 0.614325)))
                                ((R:segstate.parent.pp.ph_ctype is 0)
                                 ((1.3016 0.241702))
                                 ((0.729352 -0.1802))))))
                             ((1.30782 0.481131)))))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                            is
                            0)
                           ((0.911037 0.208323))
                           ((2.16069 1.10993))))
                         ((name is sh_2)
                          ((R:segstate.parent.pp.ph_vrnd is -)
                           ((0.876799 0.648672))
                           ((1.14984 -0.0358843)))
                          ((name is f_1)
                           ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                             is
                             content)
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                              <
                              2.2)
                             ((0.993936 0.0779331))
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               8.5)
                              ((1.29263 0.912541))
                              ((0.95912 0.361334))))
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              4.2)
                             ((0.639179 -0.117096))
                             ((0.601739 -0.370633))))
                           ((R:segstate.parent.lisp_coda_fric is 0)
                            ((R:segstate.parent.p.name is v)
                             ((R:segstate.parent.R:SylStructure.parent.position_type
                               is
                               initial)
                              ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                <
                                3)
                               ((0.593094 -0.425829))
                               ((0.933469 0.18968)))
                              ((name is dh_3)
                               ((R:segstate.parent.R:SylStructure.parent.syl_in
                                 <
                                 10)
                                ((0.37788 -0.244548))
                                ((0.84186 0.104392)))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                 is
                                 0)
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                  <
                                  0.3)
                                 ((0.912946 0.173396))
                                 ((0.934712 0.544042)))
                                ((0.875501 0.0253392)))))
                             ((R:segstate.parent.ph_cplace is g)
                              ((R:segstate.parent.p.name is n)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                 is
                                 0)
                                ((1.43546 0.8786))
                                ((1.026 0.19618)))
                               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                 <
                                 1.1)
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                  is
                                  0)
                                 ((1.18018 0.579529))
                                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                                   <
                                   6.2)
                                  ((1.28722 0.291385))
                                  ((0.310916 -0.336952))))
                                ((R:segstate.parent.pp.ph_ctype is f)
                                 ((name is hh_1)
                                  ((0.0644981 -0.63023))
                                  ((R:segstate.parent.nn.ph_cplace
                                    is
                                    a)
                                   ((0.48973 -0.376719))
                                   ((0.217069 -0.523651))))
                                 ((R:segstate.parent.p.name is s)
                                  ((0.118126 -0.544026))
                                  ((R:segstate.parent.p.name is z)
                                   ((R:segstate.parent.nn.ph_cplace
                                     is
                                     a)
                                    ((0.419943 -0.240264))
                                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                      <
                                      3.4)
                                     ((0.13798 -0.536679))
                                     ((0.292527 -0.41616))))
                                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                                     <
                                     6.5)
                                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                                      <
                                      3.6)
                                     ((R:segstate.parent.pp.ph_vc is +)
                                      ((R:segstate.parent.n.name is iy)
                                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                                         <
                                         10)
                                        ((1.28701 0.00630067))
                                        ((0.412031 -0.343265)))
                                       ((name is hh_3)
                                        ((1.22016 0.471092))
                                        ((1.0088 0.0698957))))
                                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                        is
                                        0)
                                       ((0.587513 -0.274957))
                                       ((0.362614 -0.377878))))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                       is
                                       0)
                                      ((R:segstate.parent.n.name is iy)
                                       ((0.695837 -0.253536))
                                       ((R:segstate.parent.n.name
                                         is
                                         ih)
                                        ((0.337665 -0.461465))
                                        ((0.236266 -0.506885))))
                                      ((0.863214 0.0184428))))
                                    ((R:segstate.parent.nn.ph_cplace
                                      is
                                      l)
                                     ((0.632193 -0.108594))
                                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                                       <
                                       7.6)
                                      ((1.42748 0.435168))
                                      ((R:segstate.parent.R:SylStructure.parent.next_accent
                                        <
                                        1.2)
                                       ((0.640357 -0.112945))
                                       ((1.23326 0.335336)))))))))))
                              ((R:segstate.parent.p.name is n)
                               ((name is dh_2)
                                ((R:segstate.parent.nn.ph_cplace is a)
                                 ((0.337868 -0.646096))
                                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                   <
                                   2.2)
                                  ((0.163741 -0.799232))
                                  ((2.94494e-06 -0.859156))))
                                ((name is m_2)
                                 ((0.309666 -0.755096))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                   is
                                   0)
                                  ((R:segstate.parent.ph_ctype is s)
                                   ((0.262626 -0.506733))
                                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                     <
                                     2.1)
                                    ((R:segstate.parent.R:SylStructure.parent.last_accent
                                      <
                                      2.4)
                                     ((0.844238 0.105404))
                                     ((0.572069 -0.336296)))
                                    ((0.342743 -0.370931))))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                    <
                                    0.3)
                                   ((0.601782 -0.294827))
                                   ((R:segstate.parent.nn.ph_cplace
                                     is
                                     a)
                                    ((0.696217 -0.393319))
                                    ((0.446193 -0.722635)))))))
                               ((name is dh_2)
                                ((R:segstate.parent.p.name is m)
                                 ((0.198484 -0.763279))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                   <
                                   1.2)
                                  ((R:segstate.parent.pp.ph_vfront
                                    is
                                    2)
                                   ((0.393129 -0.531154))
                                   ((R:segstate.parent.p.name is z)
                                    ((0.630382 0.369273))
                                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                      <
                                      4.8)
                                     ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                       <
                                       1.2)
                                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                        is
                                        0)
                                       ((R:segstate.parent.pp.ph_cplace
                                         is
                                         a)
                                        ((0.832325 -0.219975))
                                        ((0.674606 0.165738)))
                                       ((0.627664 -0.379769)))
                                      ((R:segstate.parent.nn.ph_cplace
                                        is
                                        a)
                                       ((0.879057 0.489118))
                                       ((0.682923 0.0150189))))
                                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                       <
                                       2.2)
                                      ((0.731449 -0.213028))
                                      ((0.508281 -0.486302))))))
                                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                    <
                                    3.7)
                                   ((0.696399 0.0432196))
                                   ((1.58857 0.834674)))))
                                ((name is jh_3)
                                 ((0.657664 0.187711))
                                 ((name is ch_3)
                                  ((0.756715 0.192244))
                                  ((R:segstate.parent.n.name is aa)
                                   ((R:segstate.parent.nn.ph_cplace
                                     is
                                     v)
                                    ((0.979279 0.195663))
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                                      is
                                      0)
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                       is
                                       0)
                                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                        <
                                        2.5)
                                       ((name is n_3)
                                        ((0.602573 -0.535748))
                                        ((0.607111 -0.316778)))
                                       ((0.442496 -0.565053)))
                                      ((0.361419 -0.772249)))
                                     ((R:segstate.parent.ph_cplace
                                       is
                                       a)
                                      ((0.509576 -0.430952))
                                      ((0.768843 -0.141242)))))
                                   ((name is s_3)
                                    ((R:segstate.parent.nn.ph_cplace
                                      is
                                      l)
                                     ((0.2089 -0.508515))
                                     ((R:segstate.parent.R:SylStructure.parent.position_type
                                       is
                                       initial)
                                      ((0.268799 -0.51386))
                                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                        <
                                        2.4)
                                       ((0.341268 -0.443876))
                                       ((0.642988 -0.0498243)))))
                                    ((R:segstate.parent.pp.ph_ctype
                                      is
                                      r)
                                     ((1.22519 0.321725))
                                     ((R:segstate.parent.n.name is ow)
                                      ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                        <
                                        1.5)
                                       ((R:segstate.parent.nn.ph_cplace
                                         is
                                         a)
                                        ((0.600768 -0.372684))
                                        ((R:segstate.parent.pp.ph_cplace
                                          is
                                          a)
                                         ((0.429423 -0.314048))
                                         ((0.742332 0.104789))))
                                       ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                         <
                                         2.3)
                                        ((0.855457 0.386994))
                                        ((1.27802 0.163719))))
                                      ((R:segstate.parent.nn.ph_cplace
                                        is
                                        a)
                                       ((name is s_2)
                                        ((1.0159 -0.623906))
                                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                                          <
                                          1.2)
                                         ((R:segstate.parent.ph_ctype
                                           is
                                           a)
                                          ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                            <
                                            1.2)
                                           ((0.613037 -0.128544))
                                           ((0.915066 0.308566)))
                                          ((R:segstate.parent.ph_vc
                                            is
                                            +)
                                           ((0.528249 -0.486282))
                                           ((R:segstate.parent.n.name
                                             is
                                             iy)
                                            ((0.90834 -0.456992))
                                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                              is
                                              0)
                                             ((name is m_3)
                                              ((0.1521 -0.482747))
                                              ((R:segstate.parent.n.name
                                                is
                                                ae)
                                               ((R:segstate.parent.lisp_coda_stop
                                                 is
                                                 0)
                                                ((1.21209 0.288402))
                                                ((0.555205 -0.228674)))
                                               ((R:segstate.parent.pp.ph_vc
                                                 is
                                                 +)
                                                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                                  <
                                                  1.2)
                                                 ((0.440332 -0.541079))
                                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                                   is
                                                   0)
                                                  ((0.524326 -0.45634))
                                                  ((0.747821 -0.166861))))
                                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                                  <
                                                  0.3)
                                                 ((0.593629 -0.389052))
                                                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                                   <
                                                   2.4)
                                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                                    is
                                                    0)
                                                   ((1.03524 0.155622))
                                                   ((0.639405
                                                     -0.105152)))
                                                  ((0.737068 -0.374205)))))))
                                             ((R:segstate.parent.lisp_onset_fric
                                               is
                                               0)
                                              ((R:segstate.parent.ph_cplace
                                                is
                                                a)
                                               ((2.1831 0.584386))
                                               ((R:segstate.parent.pp.ph_ctype
                                                 is
                                                 n)
                                                ((0.461208 -0.544451))
                                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                                  <
                                                  0.1)
                                                 ((0.703163 -0.204745))
                                                 ((name is m_1)
                                                  ((0.64777 -0.225886))
                                                  ((R:segstate.parent.pp.ph_vc
                                                    is
                                                    +)
                                                   ((1.07186 0.258048))
                                                   ((1.04124
                                                     -0.0018407)))))))
                                              ((R:segstate.parent.p.name
                                                is
                                                d)
                                               ((0.79496 0.0449729))
                                               ((R:segstate.parent.n.name
                                                 is
                                                 ih)
                                                ((0.661666 -0.458348))
                                                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                                  <
                                                  2.4)
                                                 ((R:segstate.parent.pos_in_syl
                                                   is
                                                   0)
                                                  ((R:segstate.parent.pp.ph_cplace
                                                    is
                                                    a)
                                                   ((0.702288 0.18684))
                                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                                     is
                                                     0)
                                                    ((0.604897
                                                      -0.312792))
                                                    ((0.798627
                                                      0.0500371))))
                                                  ((0.653454 -0.330372)))
                                                 ((name is f_2)
                                                  ((0.485487 -0.513753))
                                                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                                    <
                                                    1.5)
                                                   ((0.426354 -0.39036))
                                                   ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                                                     is
                                                     content)
                                                    ((0.783095
                                                      -0.030028))
                                                    ((0.527892
                                                      -0.239846)))))))))))))
                                         ((0.378344 -0.537566))))
                                       ((name is n_2)
                                        ((1.08079 0.100335))
                                        ((R:segstate.parent.n.name
                                          is
                                          eh)
                                         ((0.389779 -0.551956))
                                         ((R:segstate.parent.pp.ph_ctype
                                           is
                                           s)
                                          ((R:segstate.parent.ph_cplace
                                            is
                                            d)
                                           ((0.45165 -0.292966))
                                           ((R:segstate.parent.ph_cplace
                                             is
                                             l)
                                            ((0.46151 -0.301303))
                                            ((0.492204 -0.725282))))
                                          ((R:segstate.parent.n.name
                                            is
                                            er)
                                           ((1.21688 0.130519))
                                           ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                                             <
                                             2.2)
                                            ((R:segstate.parent.R:SylStructure.parent.next_accent
                                              <
                                              2.4)
                                             ((name is dh_3)
                                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                                <
                                                0.3)
                                               ((0.152846 -0.454805))
                                               ((R:segstate.parent.pp.ph_vlng
                                                 is
                                                 s)
                                                ((0.127882 -0.426402))
                                                ((0.420488 -0.268039))))
                                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                                <
                                                0.1)
                                               ((R:segstate.parent.R:SylStructure.parent.syl_in
                                                 <
                                                 1.7)
                                                ((0.459833 -0.594183))
                                                ((R:segstate.parent.lisp_coda_stop
                                                  is
                                                  0)
                                                 ((0.748268 -0.122964))
                                                 ((0.493494 -0.369021))))
                                               ((R:segstate.parent.R:SylStructure.parent.syl_in
                                                 <
                                                 7.5)
                                                ((R:segstate.parent.lisp_onset_nasal
                                                  is
                                                  0)
                                                 ((R:segstate.parent.nn.ph_cplace
                                                   is
                                                   v)
                                                  ((1.00992 -0.109433))
                                                  ((1.28275 0.523056)))
                                                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                                                   <
                                                   4.5)
                                                  ((0.430216 -0.295327))
                                                  ((0.89841 0.00111864))))
                                                ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                                  <
                                                  1.2)
                                                 ((0.6392 -0.216039))
                                                 ((0.606687 -0.401397))))))
                                             ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                               <
                                               1.2)
                                              ((0.390676 -0.626825))
                                              ((0.65559 -0.282372))))
                                            ((0.541337 -0.624281))))))))))))))))))
                            ((name is s_2)
                             ((0.481749 -0.695545))
                             ((R:segstate.parent.pp.ph_ctype is f)
                              ((R:segstate.parent.ph_ctype is f)
                               ((0.460614 -0.518096))
                               ((0.698184 -0.379127)))
                              ((name is dh_3)
                               ((1.29496 0.496716))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                 <
                                 1.2)
                                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                  <
                                  3.6)
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                   <
                                   0.3)
                                  ((R:segstate.parent.syl_final is 0)
                                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                     <
                                     0.4)
                                    ((0.816195 -0.0833046))
                                    ((1.07116 0.303202)))
                                   ((1.6366 0.82573)))
                                  ((R:segstate.parent.ph_cplace is p)
                                   ((0.661601 -0.37791))
                                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                                     <
                                     7.5)
                                    ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                      <
                                      2.2)
                                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                                       <
                                       3.4)
                                      ((1.61719 0.528657))
                                      ((0.857273 0.135321)))
                                     ((R:segstate.parent.lisp_coda_stop
                                       is
                                       0)
                                      ((0.928916 -0.334194))
                                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                                        <
                                        4.6)
                                       ((0.575698 -0.16349))
                                       ((0.923771 0.272797)))))
                                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                                      <
                                      9.2)
                                     ((0.800789 -0.0296037))
                                     ((0.359496 -0.449044))))))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                   is
                                   0)
                                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                    <
                                    4.2)
                                   ((R:segstate.parent.pp.ph_vrnd is -)
                                    ((0.493202 -0.352563))
                                    ((0.929968 -0.0590089)))
                                   ((1.15736 0.229786)))
                                  ((0.401997 -0.437481))))
                                ((1.17651 0.345043))))))))))))))))))))
              ((R:segstate.parent.pos_in_syl is 0)
               ((name is t_3)
                ((R:segstate.parent.n.name is ax)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                   is
                   0)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    1.6)
                   ((0.610866 0.767582))
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     6.2)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      3.2)
                     ((0.524887 0.144777))
                     ((0.57119 0.315783)))
                    ((0.607084 -0.150593))))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                     is
                     0)
                    ((0.481559 0.658704))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      2.1)
                     ((0.710966 0.242911))
                     ((0.430577 0.517877))))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     4.9)
                    ((0.896511 1.03089))
                    ((0.696594 0.719973)))))
                 ((R:segstate.parent.nn.ph_cplace is v)
                  ((0.637634 0.833975))
                  ((R:segstate.parent.pp.ph_ctype is f)
                   ((1.07526 1.00077))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     1.2)
                    ((0.751971 1.58625))
                    ((0.689196 1.98696))))))
                ((name is d_3)
                 ((R:segstate.parent.pp.ph_vc is +)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    2.1)
                   ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                     <
                     1.2)
                    ((1.56017 2.41985))
                    ((1.76313 1.38573)))
                   ((1.2871 0.609555)))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    2.7)
                   ((1.44573 0.779937))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                     is
                     0)
                    ((0.416941 -0.224413))
                    ((0.96979 0.475044)))))
                 ((name is k_3)
                  ((R:segstate.parent.n.name is ax)
                   ((0.549683 -0.00129687))
                   ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                     is
                     content)
                    ((R:segstate.parent.nn.ph_cplace is a)
                     ((R:segstate.parent.p.name is pau)
                      ((0.461853 0.878275))
                      ((0.503032 1.16288)))
                     ((R:segstate.parent.pp.ph_ctype is 0)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        6.1)
                       ((0.513031 0.709908))
                       ((0.574216 0.94597)))
                      ((0.473755 0.604374))))
                    ((0.591583 -0.123252))))
                  ((p.name is pau_5)
                   ((R:segstate.parent.ph_cplace is a)
                    ((R:segstate.parent.pp.ph_ctype is s)
                     ((1.52262 0.436957))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                       is
                       0)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                        <
                        0.3)
                       ((1.01914 0.106479))
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         4.6)
                        ((0.545745 -0.460115))
                        ((0.575141 -0.215445))))
                      ((0.352898 -0.637288))))
                    ((R:segstate.parent.pp.ph_ctype is 0)
                     ((0.678236 -0.00530557))
                     ((name is k_1)
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        3.4)
                       ((0.589662 -0.782194))
                       ((0.861783 -0.268191)))
                      ((R:segstate.parent.R:SylStructure.parent.next_accent
                        <
                        1.4)
                       ((R:segstate.parent.pp.ph_ctype is f)
                        ((0.14059 -1.09254))
                        ((0.224812 -0.997593)))
                       ((0.511839 -0.813624))))))
                   ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                     is
                     in)
                    ((name is b_3)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       3.2)
                      ((1.40604 0.990862))
                      ((1.64793 2.01755)))
                     ((name is b_1)
                      ((0.675938 -0.543783))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                        is
                        0)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         6.5)
                        ((0.629451 -0.144556))
                        ((0.917705 0.349245)))
                       ((1.07162 0.773885)))))
                    ((p.name is r_3)
                     ((1.01135 0.883908))
                     ((p.name is er_3)
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        3.4)
                       ((0.663867 1.02902))
                       ((0.867517 0.391076)))
                      ((p.name is pau_2)
                       ((R:segstate.parent.lisp_coda_stop is 0)
                        ((R:segstate.parent.nn.ph_cplace is a)
                         ((0.976866 -0.192296))
                         ((R:segstate.parent.n.name is ax)
                          ((0.645163 -0.471653))
                          ((0.577331 -0.611468))))
                        ((0.613304 -0.800716)))
                       ((name is p_3)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                          <
                          2)
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           2)
                          ((0.673866 0.293093))
                          ((R:segstate.parent.R:SylStructure.parent.next_accent
                            <
                            1.4)
                           ((0.701824 0.401509))
                           ((0.803641 0.884916))))
                         ((0.739341 0.0851918)))
                        ((name is t_1)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                           is
                           0)
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            5.6)
                           ((0.632046 -0.205923))
                           ((1.04122 0.162786)))
                          ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                            <
                            2.7)
                           ((2.29615 1.44546))
                           ((0.955169 0.217092))))
                         ((p.name is s_3)
                          ((0.454213 -0.899595))
                          ((p.name is z_3)
                           ((0.7651 -0.679811))
                           ((name is g_2)
                            ((R:segstate.parent.R:SylStructure.parent.asyl_out
                              <
                              2.4)
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               5.5)
                              ((1.00425 0.439872))
                              ((0.918868 0.937674)))
                             ((0.790816 0.0256556)))
                            ((R:segstate.parent.pp.ph_cplace is d)
                             ((1.30321 0.521448))
                             ((R:segstate.parent.n.name is uh)
                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                <
                                5.2)
                               ((1.29107 0.801611))
                               ((0.796954 0.0580305)))
                              ((R:segstate.parent.n.name is t)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                 is
                                 0)
                                ((1.56939 0.515232))
                                ((name is s_2)
                                 ((0.808878 0.329425))
                                 ((0.759453 -0.0857153))))
                               ((R:segstate.parent.p.name is ay)
                                ((R:segstate.parent.ph_cplace is a)
                                 ((0.769109 0.584131))
                                 ((0.592557 0.0734506)))
                                ((R:segstate.parent.p.name is d)
                                 ((R:segstate.parent.n.name is ih)
                                  ((name is b_3)
                                   ((0.180841 -0.68353))
                                   ((0.303982 -0.502356)))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                    <
                                    0.3)
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                     is
                                     0)
                                    ((0.569801 -0.302894))
                                    ((0.172884 -0.466311)))
                                   ((R:segstate.parent.pp.ph_ctype
                                     is
                                     n)
                                    ((0.47721 -0.301143))
                                    ((1.12062 0.250083)))))
                                 ((name is b_2)
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                    <
                                    2.2)
                                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                                     <
                                     6)
                                    ((R:segstate.parent.pp.ph_vfront
                                      is
                                      1)
                                     ((0.811643 0.123262))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                       is
                                       0)
                                      ((0.113767 -0.528462))
                                      ((0.560781 -0.204705))))
                                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                                      <
                                      8.7)
                                     ((1.04474 0.334225))
                                     ((1.11217 0.579093))))
                                   ((0.822383 1.00789)))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                    <
                                    2.2)
                                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                     <
                                     3.2)
                                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                                      <
                                      7)
                                     ((R:segstate.parent.p.name is v)
                                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                                        <
                                        9.5)
                                       ((0.76785 0.0290544))
                                       ((0.961583 0.336594)))
                                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                        is
                                        0)
                                       ((R:segstate.parent.pp.ph_cplace
                                         is
                                         a)
                                        ((1.47808 0.445275))
                                        ((R:segstate.parent.lisp_coda_stop
                                          is
                                          0)
                                         ((R:segstate.parent.nn.ph_vlng
                                           is
                                           s)
                                          ((0.533027 -0.311755))
                                          ((R:segstate.parent.p.name
                                            is
                                            pau)
                                           ((0.786716 -0.25701))
                                           ((R:segstate.parent.R:SylStructure.parent.next_accent
                                             <
                                             1.2)
                                            ((0.822752 -0.0841285))
                                            ((1.26954 0.394355)))))
                                         ((0.449603 -0.45711))))
                                       ((R:segstate.parent.pp.ph_vfront
                                         is
                                         1)
                                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                          <
                                          1.2)
                                         ((0.882135 -0.147205))
                                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                           <
                                           2.7)
                                          ((0.9391 0.114465))
                                          ((1.08246 0.287232))))
                                        ((R:segstate.parent.p.ph_vheight
                                          is
                                          2)
                                         ((0.940205 0.0503022))
                                         ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                                           <
                                           2.2)
                                          ((R:segstate.parent.nn.ph_cplace
                                            is
                                            a)
                                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                             is
                                             0)
                                            ((0.427857 -0.65675))
                                            ((0.373456 -0.391405)))
                                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                                             <
                                             2.5)
                                            ((0.244615 -0.498386))
                                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                                              <
                                              4.2)
                                             ((0.762975 -0.0473322))
                                             ((0.438807 -0.315931)))))
                                          ((0.528594 -0.0178188)))))))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                       is
                                       0)
                                      ((R:segstate.parent.pp.ph_vfront
                                        is
                                        2)
                                       ((0.353148 -0.512772))
                                       ((R:segstate.parent.R:SylStructure.parent.next_accent
                                         <
                                         2.2)
                                        ((0.978033 0.0240821))
                                        ((0.506785 -0.361283))))
                                      ((0.409818 -0.498102))))
                                    ((R:segstate.parent.nn.ph_cplace
                                      is
                                      l)
                                     ((0.471239 -0.436482))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                       is
                                       0)
                                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                        <
                                        0.8)
                                       ((0.738158 -0.37562))
                                       ((R:segstate.parent.n.name
                                         is
                                         ax)
                                        ((0.891349 0.329416))
                                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                          is
                                          0)
                                         ((R:segstate.parent.ph_cplace
                                           is
                                           l)
                                          ((0.821346 0.0687319))
                                          ((0.498273 -0.283495)))
                                         ((0.839759 0.139882)))))
                                      ((R:segstate.parent.ph_cplace
                                        is
                                        a)
                                       ((1.02208 0.0577688))
                                       ((1.80425 0.745731))))))
                                   ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                                     is
                                     to)
                                    ((1.02267 -0.0145399))
                                    ((R:segstate.parent.ph_cplace is l)
                                     ((R:segstate.parent.p.name is t)
                                      ((0.595144 -0.48536))
                                      ((1.13389 0.0841038)))
                                     ((R:segstate.parent.pp.ph_ctype
                                       is
                                       f)
                                      ((0.208862 -0.677906))
                                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                        is
                                        0)
                                       ((0.283754 -0.39756))
                                       ((0.306597 -0.583457))))))))))))))))))))))))))
               ((R:segstate.parent.ph_ctype is r)
                ((name is er_3)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 2)
                  ((0.560528 -0.208203))
                  ((0.282094 -0.549583)))
                 ((p.name is aa_3)
                  ((0.958994 0.80927))
                  ((name is r_2)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     2.4)
                    ((0.945507 0.998859))
                    ((0.742673 0.228996)))
                   ((R:segstate.parent.n.seg_onsetcoda is coda)
                    ((R:segstate.parent.p.seg_onsetcoda is coda)
                     ((0.869501 0.100229))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                       is
                       0)
                      ((0.768408 0.232086))
                      ((name is er_1)
                       ((1.03104 1.02423))
                       ((1.15827 0.339425)))))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                      is
                      0)
                     ((0.641661 0.0567167))
                     ((R:segstate.parent.pp.ph_ctype is 0)
                      ((0.571974 -0.139799))
                      ((0.335625 -0.536368))))))))
                ((name is p_3)
                 ((R:segstate.parent.p.name is s)
                  ((0.177516 -0.896293))
                  ((0.415398 -0.768659)))
                 ((name is m_3)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     5.8)
                    ((1.08446 0.21719))
                    ((1.24502 1.19847)))
                   ((0.85813 -0.0325919)))
                  ((name is k_2)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                     is
                     0)
                    ((0.833991 0.667561))
                    ((1.04853 0.0429173)))
                   ((name is k_3)
                    ((0.435637 -0.695058))
                    ((name is t_3)
                     ((R:segstate.parent.p.ph_vc is +)
                      ((0.543573 -0.634905))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                        is
                        0)
                       ((0.606569 -0.0631462))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                         <
                         0.3)
                        ((0.432776 -0.150593))
                        ((R:segstate.parent.p.name is s)
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           4.9)
                          ((0.240834 -0.399325))
                          ((0.273363 -0.273322)))
                         ((0.307847 -0.663605))))))
                     ((p.name is s_3)
                      ((name is t_1)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         5.8)
                        ((0.677305 -0.291294))
                        ((0.664191 0.0513873)))
                       ((0.540033 -0.809622)))
                      ((name is m_1)
                       ((R:segstate.parent.p.ph_vlng is d)
                        ((0.132713 -0.746642))
                        ((0.88537 0.0187419)))
                       ((R:segstate.parent.n.name is w)
                        ((1.06176 0.403898))
                        ((p.name is eh_3)
                         ((0.908193 0.430113))
                         ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                           <
                           1.3)
                          ((1.29542 0.491957))
                          ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                            <
                            4.8)
                           ((R:segstate.parent.nn.ph_vlng is d)
                            ((1.44131 0.513057))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                              is
                              0)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                               is
                               0)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                is
                                0)
                               ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                 <
                                 5.2)
                                ((0.671841 -0.32611))
                                ((0.821115 0.00851538)))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                 <
                                 0.2)
                                ((R:segstate.parent.pp.ph_cplace is 0)
                                 ((0.446293 -0.432446))
                                 ((0.629872 -0.12378)))
                                ((R:segstate.parent.p.ph_vheight is 3)
                                 ((0.395313 -0.697619))
                                 ((0.404239 -0.377386)))))
                              ((R:segstate.parent.pp.ph_ctype is 0)
                               ((2.06122 0.505679))
                               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                 <
                                 2.2)
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                  <
                                  1.2)
                                 ((0.611252 -0.369971))
                                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                                   <
                                   7.5)
                                  ((0.536022 -0.337648))
                                  ((0.988393 -0.0579151))))
                                ((0.957107 0.0210562)))))
                             ((R:segstate.parent.pp.ph_vfront is 1)
                              ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                <
                                2.4)
                               ((0.447052 -0.569353))
                               ((0.600749 -0.202195)))
                              ((name is n_1)
                               ((0.241867 -0.451325))
                               ((R:segstate.parent.ph_ctype is f)
                                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                  <
                                  1.5)
                                 ((R:segstate.parent.pos_in_syl is 2)
                                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                                    <
                                    4.6)
                                   ((0.925411 -0.148769))
                                   ((1.2117 0.290987)))
                                  ((0.667796 -0.218055)))
                                 ((R:segstate.parent.n.seg_onsetcoda
                                   is
                                   coda)
                                  ((0.737272 -0.217912))
                                  ((0.426188 -0.455874))))
                                ((R:segstate.parent.p.name is ey)
                                 ((1.65133 0.653891))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                   is
                                   0)
                                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                    <
                                    1.2)
                                   ((R:segstate.parent.lisp_coda_nasal
                                     is
                                     0)
                                    ((0.468372 -0.383053))
                                    ((0.639434 -0.0777219)))
                                   ((1.0338 0.147025)))
                                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                    <
                                    3.2)
                                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                     <
                                     0.3)
                                    ((0.983542 -0.0441808))
                                    ((R:segstate.parent.pp.ph_cplace
                                      is
                                      0)
                                     ((1.79303 1.14018))
                                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                       <
                                       4.6)
                                      ((0.76682 -0.0501232))
                                      ((1.05839 0.521385)))))
                                   ((0.611797 -0.343958))))))))))
                           ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                             <
                             1.1)
                            ((R:segstate.parent.p.ph_vheight is 2)
                             ((R:segstate.parent.pp.ph_cplace is a)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                is
                                0)
                               ((0.758116 0.247564))
                               ((0.692508 -0.119412)))
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                is
                                0)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                 <
                                 0.2)
                                ((0.74297 -0.348957))
                                ((0.661537 -0.222766)))
                               ((R:segstate.parent.R:SylStructure.parent.next_accent
                                 <
                                 1.8)
                                ((0.882948 0.0897308))
                                ((0.682792 -0.248984)))))
                             ((R:segstate.parent.R:SylStructure.parent.next_accent
                               <
                               3)
                              ((R:segstate.parent.R:SylStructure.parent.position_type
                                is
                                initial)
                               ((0.55225 -0.593696))
                               ((R:segstate.parent.R:SylStructure.parent.syl_in
                                 <
                                 3.4)
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                  is
                                  0)
                                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                                   <
                                   8.4)
                                  ((0.757629 -0.184208))
                                  ((0.272985 -0.483164)))
                                 ((0.572107 -0.029356)))
                                ((0.506478 -0.477268))))
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                                is
                                0)
                               ((R:segstate.parent.lisp_coda_fric is 0)
                                ((1.02201 0.366966))
                                ((0.888279 -0.166714)))
                               ((0.464153 -0.398435)))))
                            ((R:segstate.parent.pp.ph_ctype is 0)
                             ((0.557971 -0.278788))
                             ((0.529909 -0.471241))))))))))))))))))))))))
       ((R:segstate.parent.pos_in_syl is 0)
        ((name is t_3)
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
           <
           0.1)
          ((1.31181 1.32626))
          ((0.738455 2.22792)))
         ((R:segstate.parent.R:SylStructure.parent.parent.gpos
           is
           content)
          ((name is s_3)
           ((R:segstate.parent.nn.ph_vrnd is -)
            ((2.80798 2.94106))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
              <
              0.3)
             ((0.46521 -0.156866))
             ((1.88104 1.03625))))
           ((name is l_2)
            ((R:segstate.parent.R:SylStructure.parent.position_type
              is
              final)
             ((R:segstate.parent.p.ph_vheight is 2)
              ((0.797112 -0.101593))
              ((R:segstate.parent.p.name is n)
               ((0.0579252 -1.14096))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                 <
                 0.3)
                ((0.701905 -0.355877))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                  is
                  0)
                 ((0.467744 -0.692627))
                 ((0.348746 -0.893496))))))
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 8.8)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                is
                0)
               ((0.898342 0.269671))
               ((R:segstate.parent.lisp_coda_stop is 0)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 3.2)
                 ((0.928883 0.412879))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   6.6)
                  ((0.57859 -0.393097))
                  ((0.709223 0.0232678))))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  2.4)
                 ((0.564038 -0.490419))
                 ((0.714724 -0.113122)))))
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 2.6)
               ((0.745906 -0.516667))
               ((0.504009 -0.723888)))))
            ((R:segstate.parent.p.ph_vc is +)
             ((name is r_2)
              ((R:segstate.parent.p.ph_vlng is s)
               ((R:segstate.parent.pp.ph_ctype is f)
                ((0.685188 1.97711))
                ((0.69352 2.48316)))
               ((R:segstate.parent.p.ph_vlng is l)
                ((0.465754 -0.313544))
                ((1.60326 0.28949))))
              ((p.name is aa_3)
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 8)
                ((1.21122 0.809952))
                ((1.20717 1.2905)))
               ((R:segstate.parent.n.name is r)
                ((R:segstate.parent.ph_cplace is a)
                 ((1.85704 1.36712))
                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                   <
                   6.4)
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    2.5)
                   ((0.678198 0.200476))
                   ((R:segstate.parent.ph_cplace is l)
                    ((0.869836 0.779032))
                    ((0.875462 0.323267))))
                  ((0.807285 0.0265622))))
                ((R:segstate.parent.p.name is eh)
                 ((name is r_1)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                    is
                    0)
                   ((8.52088e-07 -0.704261))
                   ((0.137427 -0.653347)))
                  ((p.name is eh_3)
                   ((0.998003 0.507119))
                   ((R:segstate.parent.n.name is iy)
                    ((0.303744 0.36524))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_in
                      <
                      1.2)
                     ((1.53019 -0.0448496))
                     ((0.453033 -0.387431))))))
                 ((name is r_3)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    1.5)
                   ((0.444051 -0.389978))
                   ((0.487698 0.00542046)))
                  ((R:segstate.parent.pp.ph_vrnd is -)
                   ((2.03457 1.01023))
                   ((R:segstate.parent.nn.ph_cplace is v)
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      3.7)
                     ((0.735903 -0.0980601))
                     ((0.67428 -0.453683)))
                    ((p.name is ay_3)
                     ((0.55062 -0.256855))
                     ((R:segstate.parent.R:SylStructure.parent.position_type
                       is
                       initial)
                      ((1.21453 0.731672))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        15)
                       ((R:segstate.parent.lisp_coda_nasal is 0)
                        ((R:segstate.parent.pp.ph_cplace is b)
                         ((0.711163 -0.114997))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                           is
                           0)
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            8.8)
                           ((R:segstate.parent.R:SylStructure.parent.position_type
                             is
                             final)
                            ((1.01727 0.52711))
                            ((R:segstate.parent.R:SylStructure.parent.asyl_in
                              <
                              1.5)
                             ((1.0617 -0.126778))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                               <
                               0.3)
                              ((0.642129 0.0937889))
                              ((0.932838 0.432923)))))
                           ((0.820713 -0.166)))
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            3.3)
                           ((0.790117 0.310135))
                           ((0.915948 0.651383)))))
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          9.5)
                         ((1.06577 0.738612))
                         ((0.846219 0.198558))))
                       ((0.922268 -0.168849))))))))))))
             ((name is r_1)
              ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                <
                1.2)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  2.1)
                 ((0.734341 1.23774))
                 ((0.532566 0.430391)))
                ((R:segstate.parent.pp.ph_ctype is 0)
                 ((0.826312 0.191824))
                 ((0.476576 -0.380808))))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                 is
                 0)
                ((0.773417 1.36225))
                ((0.526512 0.975897))))
              ((name is k_3)
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 6)
                ((0.842488 1.29639))
                ((0.627254 0.785288)))
               ((name is l_1)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 1.8)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   3.4)
                  ((1.76646 0.403416))
                  ((0.197019 -0.592794)))
                 ((R:segstate.parent.R:SylStructure.parent.next_accent
                   <
                   3.2)
                  ((R:segstate.parent.pp.ph_vfront is 1)
                   ((0.320715 -0.40483))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                     is
                     0)
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      6.8)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       4)
                      ((0.0912719 -0.661055))
                      ((0.0388256 -0.714344)))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                       is
                       0)
                      ((0.275322 -0.614096))
                      ((0.300116 -0.517609))))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      2.2)
                     ((0.283036 -0.513849))
                     ((0.237531 -0.563973)))))
                  ((1.10908 -0.183032))))
                ((name is p_3)
                 ((R:segstate.parent.nn.ph_vlng is l)
                  ((0.448946 1.03032))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    2.7)
                   ((0.648519 0.721336))
                   ((0.67098 0.388117))))
                 ((name is b_2)
                  ((R:segstate.parent.pp.ph_ctype is 0)
                   ((1.50431 0.373404))
                   ((1.09025 1.37096)))
                  ((name is g_2)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                     is
                     0)
                    ((1.25292 0.0195315))
                    ((1.4876 1.42887)))
                   ((R:segstate.parent.lisp_onset_stop is 0)
                    ((R:segstate.parent.pp.ph_vc is +)
                     ((R:segstate.parent.ph_cplace is l)
                      ((R:segstate.parent.n.name is iy)
                       ((name is w_1)
                        ((0.781909 0.399349))
                        ((0.337093 -0.45964)))
                       ((R:segstate.parent.p.name is r)
                        ((1.1233 -0.0979868))
                        ((R:segstate.parent.n.name is ih)
                         ((R:segstate.parent.nn.ph_cplace is p)
                          ((0.359968 -0.106965))
                          ((0.590001 0.206277)))
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           11.2)
                          ((name is w_3)
                           ((R:segstate.parent.pp.ph_vfront is 1)
                            ((1.62303 1.53807))
                            ((0.839609 0.753224)))
                           ((R:segstate.parent.R:SylStructure.parent.asyl_in
                             <
                             1.5)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                              is
                              0)
                             ((0.797104 0.666599))
                             ((0.904041 0.190927)))
                            ((R:segstate.parent.pp.ph_vfront is 1)
                             ((1.00368 0.481018))
                             ((2.30366 1.48524)))))
                          ((1.22935 0.0452843))))))
                      ((R:segstate.parent.ph_ctype is r)
                       ((name is y_3)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          4.6)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                           is
                           0)
                          ((1.09325 -0.11937))
                          ((0.49487 -0.460428)))
                         ((1.33546 0.61929)))
                        ((R:segstate.parent.n.name is uw)
                         ((R:segstate.parent.R:SylStructure.parent.syl_in
                           <
                           2.4)
                          ((1.0487 0.146397))
                          ((0.750118 -0.228442)))
                         ((name is y_2)
                          ((0.453669 -0.785207))
                          ((R:segstate.parent.R:SylStructure.parent.next_accent
                            <
                            2)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                             is
                             0)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                              <
                              0.3)
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               9.8)
                              ((0.852273 0.0405066))
                              ((0.287812 -0.285434)))
                             ((R:segstate.parent.R:SylStructure.parent.asyl_out
                               <
                               1.5)
                              ((0.258492 -0.547151))
                              ((0.487713 -0.287671))))
                            ((0.457111 -0.486601)))
                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                             <
                             5.6)
                            ((0.524612 0.0962891))
                            ((0.448986 -0.244699)))))))
                       ((R:segstate.parent.nn.ph_cplace is v)
                        ((0.790077 -0.299918))
                        ((R:segstate.parent.lisp_coda_fric is 0)
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           2.4)
                          ((1.87441 1.07156))
                          ((R:segstate.parent.R:SylStructure.parent.asyl_in
                            <
                            0.7)
                           ((1.55119 0.788545))
                           ((R:segstate.parent.n.name is iy)
                            ((0.99902 0.640231))
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              5.7)
                             ((R:segstate.parent.R:SylStructure.parent.asyl_in
                               <
                               1.6)
                              ((0.799467 -0.261399))
                              ((0.938811 0.218003)))
                             ((R:segstate.parent.pp.ph_vlng is s)
                              ((1.43068 0.538066))
                              ((1.24266 0.178094)))))))
                         ((R:segstate.parent.ph_cplace is a)
                          ((0.550831 -0.489796))
                          ((1.16519 0.160307)))))))
                     ((R:segstate.parent.R:SylStructure.parent.position_type
                       is
                       final)
                      ((1.07374 0.661837))
                      ((name is y_1)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                         <
                         0.3)
                        ((0.866206 0.697634))
                        ((0.930187 -0.135275)))
                       ((R:segstate.parent.n.name is ah)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                          is
                          0)
                         ((0.658417 0.0989965))
                         ((0.929177 0.516954)))
                        ((R:segstate.parent.n.name is ey)
                         ((0.850109 0.34839))
                         ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                           <
                           1.1)
                          ((R:segstate.parent.n.name is ih)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                             is
                             0)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                              is
                              0)
                             ((0.691441 0.267926))
                             ((0.78236 -0.11019)))
                            ((0.529597 -0.296967)))
                           ((R:segstate.parent.nn.ph_cplace is v)
                            ((R:segstate.parent.n.name is ay)
                             ((0.247695 -0.617454))
                             ((0.446146 -0.373124)))
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              2.6)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                               <
                               0.3)
                              ((0.274359 -0.667734))
                              ((0.719485 -0.35572)))
                             ((R:segstate.parent.n.name is ay)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                is
                                0)
                               ((0.535662 -0.171668))
                               ((0.618975 0.128479)))
                              ((name is l_3)
                               ((0.854379 0.06627))
                               ((R:segstate.parent.n.name is aa)
                                ((0.625854 0.0428456))
                                ((R:segstate.parent.pp.ph_cplace is a)
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                   is
                                   0)
                                  ((0.682011 0.0937277))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                    <
                                    2.1)
                                   ((0.495005 -0.143851))
                                   ((0.562519 -0.513705))))
                                 ((name is w_1)
                                  ((0.443896 -0.148758))
                                  ((R:segstate.parent.n.name is iy)
                                   ((0.24085 -0.614086))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                     is
                                     0)
                                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                      <
                                      2.5)
                                     ((0.353104 -0.386928))
                                     ((0.330953 -0.583921)))
                                    ((name is y_2)
                                     ((0.557624 -0.467273))
                                     ((0.674111 -0.211126)))))))))))))
                          ((R:segstate.parent.R:SylStructure.parent.asyl_in
                            <
                            1.5)
                           ((0.814026 -0.153496))
                           ((1.30976 0.353312)))))))))
                    ((name is k_2)
                     ((R:segstate.parent.n.name is r)
                      ((0.615117 -0.189947))
                      ((2.31133 0.908339)))
                     ((name is d_3)
                      ((0.991582 0.408196))
                      ((name is s_2)
                       ((0.822724 0.168786))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                         <
                         0.3)
                        ((R:segstate.parent.ph_cplace is l)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                           <
                           0.1)
                          ((0.299037 -1.013))
                          ((0.708656 -0.564726)))
                         ((R:segstate.parent.pp.ph_vfront is 3)
                          ((0.570854 -0.0528153))
                          ((R:segstate.parent.n.name is r)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                             is
                             0)
                            ((0.751925 -0.104111))
                            ((0.309985 -0.511757)))
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                             <
                             3.4)
                            ((0.334051 -0.743664))
                            ((0.568975 -0.585927))))))
                        ((name is p_2)
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           3.6)
                          ((0.823721 -0.224393))
                          ((1.28659 0.564847)))
                         ((R:segstate.parent.ph_cplace is a)
                          ((R:segstate.parent.n.name is r)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                             is
                             0)
                            ((1.44624 0.61205))
                            ((0.72753 -0.175372)))
                           ((0.579809 -0.486289)))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                            <
                            1.3)
                           ((0.848811 0.105951))
                           ((name is b_3)
                            ((0.758882 -0.0789017))
                            ((R:segstate.parent.pp.ph_ctype is f)
                             ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                               <
                               1.2)
                              ((0.554508 -0.596051))
                              ((0.209587 -1.00732)))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                               is
                               0)
                              ((R:segstate.parent.nn.ph_vlng is s)
                               ((0.772301 -0.516612))
                               ((0.371399 -0.862371)))
                              ((R:segstate.parent.pp.ph_vfront is 1)
                               ((0.489279 -0.734817))
                               ((R:segstate.parent.lisp_coda_stop is 0)
                                ((0.922658 -0.118021))
                                ((0.668236 -0.467667))))))))))))))))))))))))
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
            <
            1.5)
           ((p.name is pau_5)
            ((0.309378 -0.759008))
            ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 2.4)
             ((name is w_3)
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 0.7)
               ((1.00511 0.137705))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                 is
                 0)
                ((0.493473 -0.248425))
                ((0.359185 -0.704464))))
              ((R:segstate.parent.p.ph_vlng is d)
               ((1.24595 0.426886))
               ((name is w_1)
                ((0.69229 0.121342))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 4)
                 ((0.456633 -0.407558))
                 ((R:segstate.parent.pp.ph_vc is 0)
                  ((0.742726 0.0367986))
                  ((0.633289 -0.136285)))))))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
               is
               0)
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 6.6)
               ((0.338816 -0.191535))
               ((1.09553 0.307601)))
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 2.2)
               ((1.31365 0.695165))
               ((1.25932 0.421532))))))
           ((R:segstate.parent.pp.ph_ctype is f)
            ((R:segstate.parent.n.name is er)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 2.4)
              ((0.166648 -0.857501))
              ((0.415311 -0.650354)))
             ((name is w_1)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                is
                0)
               ((0.237162 -0.853655))
               ((0.670717 -0.606612)))
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 8)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                 <
                 0.3)
                ((0.828846 -0.0948683))
                ((R:segstate.parent.lisp_coda_nasal is 0)
                 ((0.534508 -0.371295))
                 ((0.282312 -0.574338))))
               ((0.282464 -0.680105)))))
            ((name is w_1)
             ((p.name is t_3)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                <
                0.3)
               ((0.676625 0.24124))
               ((0.86489 0.0910384)))
              ((R:segstate.parent.lisp_coda_fric is 0)
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 4.8)
                ((0.808001 0.0554639))
                ((0.505829 -0.536277)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  3.5)
                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                   <
                   2.1)
                  ((0.364687 -0.763622))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((0.375738 -0.668255))
                   ((0.587344 -0.399095))))
                 ((0.742087 -0.280515)))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                  is
                  0)
                 ((0.108143 -0.933751))
                 ((0.518552 -0.745351))))))
             ((name is f_3)
              ((0.921784 0.48276))
              ((R:segstate.parent.lisp_coda_fric is 0)
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 6.4)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  2.2)
                 ((R:segstate.parent.n.name is r)
                  ((0.834889 -0.167314))
                  ((R:segstate.parent.pp.ph_vlng is s)
                   ((0.479638 -0.486846))
                   ((0.449139 -0.618859))))
                 ((0.363708 -0.715871)))
                ((R:segstate.parent.pp.ph_cplace is a)
                 ((0.815394 -0.266506))
                 ((0.924283 0.145146))))
               ((R:segstate.parent.p.name is r)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                  <
                  0.1)
                 ((0.555672 0.360766))
                 ((0.468503 -0.0379583)))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  6.3)
                 ((R:segstate.parent.pp.ph_cplace is a)
                  ((R:segstate.parent.pp.ph_ctype is s)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                     is
                     0)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      2.2)
                     ((0.533175 -0.424383))
                     ((0.637494 -0.106088)))
                    ((0.911481 0.0788415)))
                   ((0.81912 0.268342)))
                  ((R:segstate.parent.p.name is pau)
                   ((0.470931 -0.501045))
                   ((R:segstate.parent.p.name is t)
                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                      <
                      2)
                     ((name is w_2)
                      ((0.405407 -0.37803))
                      ((0.402474 -0.649187)))
                     ((0.8038 0.0797333)))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      1.2)
                     ((0.795479 -0.23183))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                       is
                       0)
                      ((0.434976 -0.0703091))
                      ((0.818607 0.206197)))))))
                 ((0.379348 -0.542979)))))))))))
        ((name is aa_3)
         ((R:segstate.parent.n.name is z)
          ((R:segstate.parent.pp.ph_vfront is 1)
           ((0.879308 0.805395))
           ((R:segstate.parent.R:SylStructure.parent.last_accent < 0.5)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
              <
              1.2)
             ((0.495269 0.066312))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
               <
               0.3)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                <
                0.1)
               ((0.527934 0.514942))
               ((0.874994 0.296847)))
              ((R:segstate.parent.pp.ph_ctype is r)
               ((0.46957 0.528052))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 3.7)
                ((1.0081 0.831597))
                ((0.733583 1.13926))))))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
              <
              0.1)
             ((0.860498 0.33188))
             ((0.623618 0.0520245)))))
          ((R:segstate.parent.R:SylStructure.parent.syl_out < 8.5)
           ((R:segstate.parent.nn.ph_cplace is a)
            ((0.527305 -0.0500313))
            ((0.261348 -0.446156)))
           ((0.19847 -0.625693))))
         ((name is ae_2)
          ((R:segstate.parent.lisp_coda_nasal is 0)
           ((R:segstate.parent.p.name is l)
            ((0.534719 1.65928))
            ((0.888262 0.637416)))
           ((0.558237 -0.41866)))
          ((name is ih_2)
           ((R:segstate.parent.lisp_coda_stop is 0)
            ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 2.2)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
               <
               0.3)
              ((0.663094 -0.300415))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                is
                0)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                 <
                 1.2)
                ((R:segstate.parent.pp.ph_ctype is 0)
                 ((0.374619 -0.548417))
                 ((0.142848 -0.677971)))
                ((0.0999722 -0.700377)))
               ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                 is
                 content)
                ((0.711159 -0.26283))
                ((0.298736 -0.620192)))))
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 3.8)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 4.2)
               ((0.0456312 -0.720292))
               ((0.122928 -0.668746)))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                <
                1.2)
               ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 2.4)
                ((0.298984 -0.62209))
                ((0.290754 -0.468863)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                 is
                 0)
                ((0.0558071 -0.714761))
                ((0.263123 -0.599557))))))
            ((0.596395 -0.30294)))
           ((name is k_3)
            ((R:segstate.parent.R:SylStructure.parent.next_accent
              <
              1.2)
             ((R:segstate.parent.p.name is ay)
              ((0.274979 -1.13693))
              ((0.377806 -0.894557)))
             ((0.500169 -0.735971)))
            ((R:segstate.parent.R:SylStructure.parent.parent.gpos
              is
              content)
             ((p.name is ay_3)
              ((R:segstate.parent.ph_ctype is s)
               ((name is k_1)
                ((0.925597 0.841657))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                  is
                  0)
                 ((0.665178 0.250587))
                 ((0.851407 0.557405))))
               ((0.710841 -0.0722682)))
              ((name is ay_3)
               ((R:segstate.parent.n.name is k)
                ((0.349871 -0.274856))
                ((R:segstate.parent.R:SylStructure.parent.position_type
                  is
                  single)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                   <
                   0.2)
                  ((0.577873 1.14211))
                  ((0.597797 0.468203)))
                 ((R:segstate.parent.nn.ph_cplace is 0)
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    1.2)
                   ((0.596863 0.0885381))
                   ((0.588175 -0.177227)))
                  ((1.08276 0.416176)))))
               ((name is w_3)
                ((R:segstate.parent.nn.ph_cplace is a)
                 ((0.954921 0.0981659))
                 ((1.43846 1.20857)))
                ((name is t_2)
                 ((R:segstate.parent.syl_final is 0)
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    4.2)
                   ((2.11726 1.60734))
                   ((1.30077 0.728735)))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    3.4)
                   ((R:segstate.parent.pp.ph_ctype is 0)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                      <
                      0.3)
                     ((0.185155 -0.393635))
                     ((7.91724e-06 -0.429951)))
                    ((0.404958 -0.215377)))
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     1.6)
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      3.4)
                     ((5.62519e-06 -0.429947))
                     ((0.947249 -0.0145397)))
                    ((1.55133 0.514162)))))
                 ((name is ah_1)
                  ((p.name is l_3)
                   ((0.904592 1.09976))
                   ((p.name is w_3)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                      is
                      0)
                     ((0.498124 -0.0470106))
                     ((0.529967 -0.235803)))
                    ((0.661909 0.401726))))
                  ((name is aa_1)
                   ((p.name is w_3)
                    ((0.737546 -0.0149639))
                    ((R:segstate.parent.pp.ph_ctype is s)
                     ((0.609927 0.308623))
                     ((0.662639 0.956088))))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                     <
                     0.3)
                    ((name is ao_2)
                     ((1.30401 0.783565))
                     ((p.name is b_3)
                      ((1.01635 0.647125))
                      ((name is uw_3)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                         <
                         0.3)
                        ((1.24743 0.854203))
                        ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                          <
                          1.1)
                         ((0.792347 0.317451))
                         ((0.875972 -0.0604989))))
                       ((R:segstate.parent.p.name is v)
                        ((0.991499 0.459867))
                        ((R:segstate.parent.lisp_coda_stop is 0)
                         ((R:segstate.parent.ph_vrnd is -)
                          ((R:segstate.parent.pp.ph_ctype is s)
                           ((R:segstate.parent.p.name is r)
                            ((p.name is r_3)
                             ((0.49305 -0.039961))
                             ((R:segstate.parent.R:SylStructure.parent.next_accent
                               <
                               1.5)
                              ((0.616381 -0.224144))
                              ((0.760186 -0.743149))))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                              <
                              0.3)
                             ((0.445543 -0.298136))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                               is
                               0)
                              ((0.555927 -0.116859))
                              ((R:segstate.parent.R:SylStructure.parent.syl_in
                                <
                                5.5)
                               ((1.2206 0.255057))
                               ((0.638535 0.101678))))))
                           ((p.name is r_3)
                            ((R:segstate.parent.pp.ph_vrnd is -)
                             ((1.1561 0.672978))
                             ((0.603148 0.163017)))
                            ((R:segstate.parent.p.name is r)
                             ((name is iy_2)
                              ((0.456667 -0.575743))
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                <
                                0.3)
                               ((0.673072 0.17371))
                               ((0.544263 -0.200972))))
                             ((name is ay_1)
                              ((0.619489 0.446464))
                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                <
                                2.8)
                               ((0.521732 -0.246796))
                               ((R:segstate.parent.pp.ph_ctype is n)
                                ((1.03411 0.310841))
                                ((R:segstate.parent.p.name is w)
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                   is
                                   0)
                                  ((0.954084 0.104708))
                                  ((0.643127 -0.257245)))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                   is
                                   0)
                                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                    <
                                    4.6)
                                   ((0.671907 0.0689966))
                                   ((0.808001 0.410079)))
                                  ((p.name is l_3)
                                   ((0.531871 0.224791))
                                   ((0.709075 -0.136291)))))))))))
                          ((R:segstate.parent.ph_cplace is a)
                           ((R:segstate.parent.lisp_coda_glide is 0)
                            ((name is l_2)
                             ((0.666095 -0.530471))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                               is
                               0)
                              ((name is r_3)
                               ((R:segstate.parent.nn.ph_vrnd is -)
                                ((0.306245 -0.527693))
                                ((0.429481 -0.229493)))
                               ((R:segstate.parent.p.name is t)
                                ((0.612794 -0.33106))
                                ((R:segstate.parent.pp.ph_ctype is 0)
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                   is
                                   0)
                                  ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                                    <
                                    0.1)
                                   ((0.611834 -0.345052))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                     is
                                     0)
                                    ((0.599535 -0.0991768))
                                    ((0.763736 0.165663))))
                                  ((0.563986 -0.367555)))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                   <
                                   0.1)
                                  ((1.29793 -0.0072703))
                                  ((1.06069 0.25273))))))
                              ((R:segstate.parent.nn.ph_vrnd is -)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                 is
                                 0)
                                ((1.20554 0.361924))
                                ((0.968501 0.0445291)))
                               ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                 <
                                 2.4)
                                ((0.523386 -0.362367))
                                ((0.85985 0.110533))))))
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              4.9)
                             ((1.27469 0.417054))
                             ((0.810818 -0.0351177))))
                           ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                             <
                             2.2)
                            ((R:segstate.parent.lisp_coda_nasal is 0)
                             ((R:segstate.parent.ph_vheight is 3)
                              ((0.41518 -0.597475))
                              ((name is uw_1)
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                 is
                                 0)
                                ((0.490845 -0.26883))
                                ((0.32309 -0.505616)))
                               ((R:segstate.parent.syl_final is 0)
                                ((R:segstate.parent.R:SylStructure.parent.last_accent
                                  <
                                  1.4)
                                 ((0.445122 -0.483503))
                                 ((0.716329 -0.0803664)))
                                ((R:segstate.parent.nn.ph_cplace is v)
                                 ((0.703708 -0.390206))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                   <
                                   1.2)
                                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                                    <
                                    7.2)
                                   ((1.39341 0.42847))
                                   ((1.08971 0.297154)))
                                  ((R:segstate.parent.pp.ph_cplace
                                    is
                                    a)
                                   ((1.14589 0.174554))
                                   ((0.82939 -0.113352))))))))
                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                               <
                               8.8)
                              ((0.641223 -0.396112))
                              ((0.551407 -0.630683))))
                            ((R:segstate.parent.nn.ph_vc is +)
                             ((0.513676 -0.478837))
                             ((0.49216 -0.783301))))))
                         ((R:segstate.parent.p.name is aa)
                          ((1.20698 0.387149))
                          ((R:segstate.parent.n.name is r)
                           ((0.714137 0.16109))
                           ((R:segstate.parent.nn.ph_cplace is a)
                            ((R:segstate.parent.n.ph_vc is +)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                               <
                               1.2)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                is
                                0)
                               ((R:segstate.parent.p.ph_vc is +)
                                ((0.371577 -0.459258))
                                ((0.607095 -0.259469)))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                                 is
                                 0)
                                ((0.788134 0.121388))
                                ((0.656837 -0.204188))))
                              ((R:segstate.parent.n.name is ax)
                               ((0.894716 -0.0755335))
                               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                 <
                                 1.2)
                                ((0.206177 -0.643953))
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                  is
                                  0)
                                 ((0.69546 -0.183265))
                                 ((0.249243 -0.475659))))))
                             ((R:segstate.parent.R:SylStructure.parent.asyl_in
                               <
                               2.1)
                              ((R:segstate.parent.n.name is s)
                               ((0.808764 -0.178124))
                               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                 <
                                 4.6)
                                ((R:segstate.parent.R:SylStructure.parent.syl_in
                                  <
                                  4.9)
                                 ((1.33477 0.397784))
                                 ((0.863923 0.243797)))
                                ((0.731659 -0.0898162))))
                              ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                <
                                3.4)
                               ((0.33092 -0.519856))
                               ((0.733759 -0.035243)))))
                            ((R:segstate.parent.ph_ctype is n)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                               is
                               0)
                              ((0.395827 -0.414846))
                              ((1.21932 0.294128)))
                             ((R:segstate.parent.n.name is z)
                              ((1.03802 0.000426563))
                              ((R:segstate.parent.pp.ph_cplace is v)
                               ((0.752751 -0.0720414))
                               ((name is t_1)
                                ((0.607245 -0.113783))
                                ((R:segstate.parent.p.ph_vlng is d)
                                 ((0.727844 -0.165264))
                                 ((R:segstate.parent.pos_in_syl is 3)
                                  ((R:segstate.parent.lisp_coda_fric
                                    is
                                    0)
                                   ((R:segstate.parent.lisp_onset_stop
                                     is
                                     0)
                                    ((0.392579 -0.428624))
                                    ((0.429779 -0.518365)))
                                   ((0.391466 -0.667808)))
                                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                                    <
                                    8.4)
                                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                     <
                                     2.4)
                                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                      <
                                      2.8)
                                     ((0.436586 -0.546246))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                       <
                                       0.3)
                                      ((R:segstate.parent.n.ph_vc is +)
                                       ((0.406565 -0.573104))
                                       ((0.629849 -0.393717)))
                                      ((R:segstate.parent.ph_vrnd is -)
                                       ((0.508403 -0.45358))
                                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                         is
                                         0)
                                        ((0.637899 -0.159118))
                                        ((0.784618 -0.0263912))))))
                                    ((R:segstate.parent.lisp_onset_stop
                                      is
                                      0)
                                     ((R:segstate.parent.pp.ph_ctype
                                       is
                                       0)
                                      ((0.482063 -0.588912))
                                      ((0.171218 -0.73421)))
                                     ((0.304211 -0.429225))))
                                   ((R:segstate.parent.R:SylStructure.parent.last_accent
                                     <
                                     1.6)
                                    ((0.628384 -0.341528))
                                    ((0.632326 -0.110717))))))))))))))))))
                    ((R:segstate.parent.p.ph_vheight is 2)
                     ((name is n_1)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                        <
                        0.3)
                       ((0.643781 -0.22985))
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         7.1)
                        ((0.10448 -0.569881))
                        ((0.251778 -0.457052))))
                      ((name is d_1)
                       ((1.44672 0.695874))
                       ((name is d_2)
                        ((1.07765 0.587604))
                        ((name is n_2)
                         ((R:segstate.parent.p.ph_vlng is d)
                          ((1.12301 0.857777))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                            is
                            0)
                           ((0.623098 -0.367857))
                           ((1.03006 0.232703))))
                         ((name is g_1)
                          ((0.398043 0.46638))
                          ((R:segstate.parent.nn.ph_vlng is a)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                             is
                             0)
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              7.8)
                             ((0.735518 -0.492049))
                             ((0.222563 -0.750467)))
                            ((0.614234 -0.245927)))
                           ((p.name is ah_3)
                            ((1.30559 0.516889))
                            ((R:segstate.parent.nn.ph_vrnd is -)
                             ((R:segstate.parent.R:SylStructure.parent.syl_in
                               <
                               5.6)
                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                <
                                5.8)
                               ((1.94828 0.950394))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                 <
                                 1.2)
                                ((1.46427 0.368956))
                                ((0.470943 -0.234825))))
                              ((R:segstate.parent.p.ph_vlng is s)
                               ((0.646444 -0.419614))
                               ((0.946246 0.0126416))))
                             ((name is s_3)
                              ((0.286261 -0.511929))
                              ((R:segstate.parent.lisp_onset_fric is 0)
                               ((R:segstate.parent.ph_ctype is n)
                                ((1.13151 0.282383))
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                  is
                                  0)
                                 ((0.838485 0.053853))
                                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                                   <
                                   1.3)
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                    <
                                    0.3)
                                   ((R:segstate.parent.pp.ph_ctype
                                     is
                                     l)
                                    ((0.565013 -0.389771))
                                    ((0.823092 -0.0271439)))
                                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                                     <
                                     3.3)
                                    ((0.621893 -0.344111))
                                    ((0.716003 -0.68472))))
                                  ((R:segstate.parent.p.ph_vlng is d)
                                   ((0.730767 0.0431804))
                                   ((0.668451 -0.238032))))))
                               ((R:segstate.parent.R:SylStructure.parent.syl_out
                                 <
                                 5.4)
                                ((0.976139 -0.215008))
                                ((0.567525 -0.642027)))))))))))))
                     ((name is eh_3)
                      ((R:segstate.parent.p.name is r)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         3.6)
                        ((0.145516 -0.534704))
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          9.6)
                         ((0.375258 -0.298474))
                         ((0.497934 -0.105193))))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         5)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                          <
                          1.2)
                         ((1.32386 0.288941))
                         ((1.97534 1.48399)))
                        ((0.873363 -0.135513))))
                      ((R:segstate.parent.n.name is uw)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                         <
                         5.4)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                          is
                          0)
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           5.5)
                          ((0.752799 0.124214))
                          ((0.812513 -0.225024)))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                           is
                           0)
                          ((R:segstate.parent.lisp_coda_fric is 0)
                           ((R:segstate.parent.lisp_onset_fric is 0)
                            ((1.23779 0.268968))
                            ((0.603091 0.180397)))
                           ((0.85795 0.525649)))
                          ((0.659355 -0.0871165))))
                        ((0.685249 -0.285033)))
                       ((R:segstate.parent.ph_cplace is l)
                        ((name is w_1)
                         ((R:segstate.parent.R:SylStructure.parent.syl_in
                           <
                           5.1)
                          ((0.183867 -0.665244))
                          ((0.162012 -0.774601)))
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           4.9)
                          ((R:segstate.parent.ph_ctype is s)
                           ((0.631162 -0.613415))
                           ((0.884428 -0.0871754)))
                          ((R:segstate.parent.lisp_onset_fric is 0)
                           ((R:segstate.parent.nn.ph_cplace is a)
                            ((0.320089 -0.934103))
                            ((0.544767 -0.609166)))
                           ((0.630672 -0.256787)))))
                        ((name is l_3)
                         ((R:segstate.parent.p.name is k)
                          ((0.51827 -0.518352))
                          ((R:segstate.parent.lisp_onset_fric is 0)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                             is
                             0)
                            ((0.599928 -0.270011))
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                              <
                              2.7)
                             ((0.593353 -0.116992))
                             ((0.746236 0.43425))))
                           ((R:segstate.parent.pp.ph_ctype is 0)
                            ((0.571324 0.266925))
                            ((0.665254 0.457023)))))
                         ((R:segstate.parent.ph_ctype is l)
                          ((R:segstate.parent.p.name is b)
                           ((0.658881 -0.126224))
                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                             <
                             7)
                            ((R:segstate.parent.R:SylStructure.parent.asyl_in
                              <
                              2.4)
                             ((R:segstate.parent.R:SylStructure.parent.next_accent
                               <
                               2.5)
                              ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                <
                                3.5)
                               ((name is l_1)
                                ((0.748977 -0.282101))
                                ((0.407756 -0.563066)))
                               ((0.28327 -0.597986)))
                              ((0.351588 -0.763626)))
                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                               <
                               2.5)
                              ((0.76181 -0.411313))
                              ((0.808778 -0.181081))))
                            ((R:segstate.parent.lisp_coda_nasal is 0)
                             ((name is l_1)
                              ((0.141999 -0.612983))
                              ((R:segstate.parent.lisp_onset_stop is 0)
                               ((0.405148 -0.747614))
                               ((0.460927 -0.953254))))
                             ((0.33402 -0.549676)))))
                          ((p.name is b_3)
                           ((0.734268 0.349441))
                           ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                             <
                             1.4)
                            ((name is iy_2)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                               is
                               0)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                <
                                0.3)
                               ((0.364929 -0.782914))
                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                 <
                                 1.2)
                                ((0.731011 -0.295945))
                                ((0.503031 -0.596318))))
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                is
                                0)
                               ((R:segstate.parent.R:SylStructure.parent.syl_out
                                 <
                                 6.6)
                                ((0.569475 -0.627255))
                                ((0.356581 -0.773627)))
                               ((0.273944 -0.862686))))
                             ((R:segstate.parent.R:SylStructure.parent.position_type
                               is
                               final)
                              ((R:segstate.parent.ph_vrnd is +)
                               ((R:segstate.parent.ph_vheight is 1)
                                ((0.549758 -0.168879))
                                ((0.768261 -0.672312)))
                               ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                 <
                                 1.4)
                                ((name is iy_3)
                                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                   <
                                   0.1)
                                  ((0.420852 -0.361311))
                                  ((0.488775 -0.208114)))
                                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                   <
                                   5.5)
                                  ((R:segstate.parent.n.seg_onsetcoda
                                    is
                                    coda)
                                   ((0.554741 0.00630832))
                                   ((0.368214 -0.334497)))
                                  ((0.756625 0.0483192))))
                                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                  <
                                  2.7)
                                 ((1.19881 0.505816))
                                 ((p.name is l_3)
                                  ((0.391253 -0.266338))
                                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                    <
                                    4.2)
                                   ((0.659877 0.0955152))
                                   ((0.578393 -0.157869)))))))
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                                <
                                0.3)
                               ((p.name is p_3)
                                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                  <
                                  2.7)
                                 ((0.792548 0.0696308))
                                 ((0.291336 -0.439509)))
                                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                  is
                                  0)
                                 ((R:segstate.parent.pp.ph_vlng is a)
                                  ((0.372219 -0.548163))
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                    <
                                    0.3)
                                   ((0.670065 -0.166815))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                     is
                                     0)
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                                      <
                                      1.1)
                                     ((R:segstate.parent.nn.ph_vlng
                                       is
                                       a)
                                      ((0.332642 -0.425325))
                                      ((0.316478 -0.555025)))
                                     ((0.514149 -0.267922)))
                                    ((R:segstate.parent.p.name is r)
                                     ((0.228133 -0.464182))
                                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                       <
                                       7)
                                      ((0.625255 -0.136768))
                                      ((0.40357 -0.341364)))))))
                                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                   <
                                   2.4)
                                  ((R:segstate.parent.ph_vrnd is +)
                                   ((R:segstate.parent.ph_vheight is 1)
                                    ((0.350098 -0.549599))
                                    ((0.31005 -0.760637)))
                                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                     <
                                     3.5)
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                      is
                                      0)
                                     ((0.262117 -0.618157))
                                     ((R:segstate.parent.pp.ph_cplace
                                       is
                                       0)
                                      ((0.173353 -0.572925))
                                      ((0.418257 -0.374134))))
                                    ((0.446454 -0.361804))))
                                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                                    <
                                    2.8)
                                   ((0.764689 -0.0997554))
                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                                     <
                                     0.1)
                                    ((0.282534 -0.59319))
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                      is
                                      0)
                                     ((0.2905 -0.498858))
                                     ((0.438524 -0.325352))))))))
                               ((name is uw_3)
                                ((R:segstate.parent.pp.ph_ctype is 0)
                                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                   <
                                   2.5)
                                  ((0.358826 -0.393454))
                                  ((0.242561 -0.494128)))
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                   is
                                   0)
                                  ((0.120416 -0.595364))
                                  ((0.123572 -0.582429))))
                                ((R:segstate.parent.n.name is pau)
                                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                                   <
                                   4.8)
                                  ((0.515175 -0.270328))
                                  ((1.19279 0.295611)))
                                 ((R:segstate.parent.pp.ph_cplace is v)
                                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                                    <
                                    1.2)
                                   ((R:segstate.parent.p.name is r)
                                    ((0.585011 -0.212282))
                                    ((R:segstate.parent.p.name is y)
                                     ((0.509936 0.0175635))
                                     ((0.969264 0.346961))))
                                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                     <
                                     1.2)
                                    ((0.537426 -0.158582))
                                    ((0.334497 -0.504895))))
                                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                                    <
                                    3.3)
                                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                                     <
                                     4.6)
                                    ((name is uw_2)
                                     ((1.17551 0.354543))
                                     ((R:segstate.parent.n.name is d)
                                      ((0.89114 0.131882))
                                      ((R:segstate.parent.ph_cplace
                                        is
                                        a)
                                       ((R:segstate.parent.lisp_onset_fric
                                         is
                                         0)
                                        ((name is r_3)
                                         ((0.347594 -0.408448))
                                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                           <
                                           1.2)
                                          ((0.664015 -0.292899))
                                          ((0.713352 -0.0501978))))
                                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                          <
                                          1.2)
                                         ((0.915543 0.169736))
                                         ((0.508735 -0.257656))))
                                       ((R:segstate.parent.nn.ph_vrnd
                                         is
                                         -)
                                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                                          <
                                          3.1)
                                         ((R:segstate.parent.ph_vrnd
                                           is
                                           +)
                                          ((0.481989 -0.554462))
                                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                            <
                                            1.2)
                                           ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                                             <
                                             3.2)
                                            ((R:segstate.parent.nn.ph_vlng
                                              is
                                              a)
                                             ((0.37465 -0.363693))
                                             ((R:segstate.parent.p.name
                                               is
                                               r)
                                              ((0.146632 -0.583272))
                                              ((0.500563 -0.450614))))
                                            ((R:segstate.parent.pp.ph_vlng
                                              is
                                              s)
                                             ((0.350502 -0.19873))
                                             ((0.277934 -0.362501))))
                                           ((R:segstate.parent.nn.ph_vlng
                                             is
                                             a)
                                            ((0.322123 -0.452518))
                                            ((0.56673 -0.00487267)))))
                                         ((R:segstate.parent.R:SylStructure.parent.position_type
                                           is
                                           initial)
                                          ((0.632604 -0.0476147))
                                          ((0.392253 -0.264676))))
                                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                          is
                                          0)
                                         ((0.180184 -0.608524))
                                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                           <
                                           1.2)
                                          ((0.35541 -0.369586))
                                          ((0.194406 -0.581195))))))))
                                    ((name is r_1)
                                     ((0.476691 -0.148282))
                                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                       <
                                       7)
                                      ((name is uw_2)
                                       ((0.157352 -0.639424))
                                       ((R:segstate.parent.p.name is k)
                                        ((0.288743 -0.679875))
                                        ((R:segstate.parent.pp.ph_ctype
                                          is
                                          n)
                                         ((0.240822 -0.618313))
                                         ((name is r_3)
                                          ((0.216193 -0.599305))
                                          ((p.name is w_3)
                                           ((0.109616 -0.597692))
                                           ((R:segstate.parent.ph_vheight
                                             is
                                             3)
                                            ((0.46671 -0.528068))
                                            ((R:segstate.parent.nn.ph_cplace
                                              is
                                              a)
                                             ((0.759017 -0.0903331))
                                             ((R:segstate.parent.nn.ph_vc
                                               is
                                               +)
                                              ((R:segstate.parent.R:SylStructure.parent.syl_out
                                                <
                                                6.8)
                                               ((R:segstate.parent.R:SylStructure.parent.syl_out
                                                 <
                                                 5.1)
                                                ((0.388278 -0.441348))
                                                ((0.63036 -0.0975751)))
                                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                                 is
                                                 0)
                                                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                                  <
                                                  1.2)
                                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                                   is
                                                   0)
                                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                                                    is
                                                    0)
                                                   ((0.596337 -0.21807))
                                                   ((0.468296
                                                     -0.417833)))
                                                  ((0.487694 -0.513243)))
                                                 ((0.504757 -0.25661)))
                                                ((0.355113 -0.48642))))
                                              ((0.474305 -0.568658))))))))))
                                      ((R:segstate.parent.ph_vheight
                                        is
                                        1)
                                       ((R:segstate.parent.nn.ph_vlng
                                         is
                                         s)
                                        ((0.48222 -0.161719))
                                        ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                          <
                                          8.2)
                                         ((0.209532 -0.493891))
                                         ((0.149643 -0.608759))))
                                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                         is
                                         0)
                                        ((0.405734 -0.334761))
                                        ((R:segstate.parent.pp.ph_ctype
                                          is
                                          0)
                                         ((0.739432 -0.220656))
                                         ((1.03786 0.135798))))))))
                                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                     <
                                     3)
                                    ((1.306 0.154793))
                                    ((R:segstate.parent.p.name is l)
                                     ((0.476357 -0.356768))
                                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                       <
                                       0.7)
                                      ((0.862874 0.156863))
                                      ((R:segstate.parent.nn.ph_vlng
                                        is
                                        a)
                                       ((0.473492 -0.321602))
                                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                                         <
                                         4.2)
                                        ((0.623491 -0.0670035))
                                        ((0.462818 -0.267632))))))))))))))
                            ((name is er_1)
                             ((0.654572 0.402762))
                             ((name is iy_2)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                is
                                0)
                               ((0.886036 -0.13691))
                               ((0.983055 0.776818)))
                              ((p.name is n_3)
                               ((R:segstate.parent.pp.ph_vfront is 2)
                                ((0.877228 -0.305053))
                                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                  <
                                  3.4)
                                 ((0.574931 -0.682054))
                                 ((0.208851 -0.907309))))
                               ((p.name is l_3)
                                ((R:segstate.parent.ph_vheight is 1)
                                 ((R:segstate.parent.lisp_coda_fric
                                   is
                                   0)
                                  ((0.29895 -0.197837))
                                  ((0.839904 0.227457)))
                                 ((name is ae_1)
                                  ((0.103671 -0.81979))
                                  ((name is eh_1)
                                   ((0.048158 -0.775802))
                                   ((R:segstate.parent.ph_vrnd is +)
                                    ((0.351628 -0.65553))
                                    ((R:segstate.parent.lisp_coda_nasal
                                      is
                                      0)
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                       is
                                       0)
                                      ((R:segstate.parent.pp.ph_vc
                                        is
                                        +)
                                       ((R:segstate.parent.ph_vheight
                                         is
                                         2)
                                        ((0.243012 -0.454627))
                                        ((0.223019 -0.569392)))
                                       ((0.633227 -0.195215)))
                                      ((0.32586 -0.58364)))
                                     ((0.497034 -0.0375891)))))))
                                ((name is ey_2)
                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                                   is
                                   0)
                                  ((0.411195 -0.810153))
                                  ((0.558204 -0.499833)))
                                 ((name is ay_2)
                                  ((R:segstate.parent.n.name is k)
                                   ((0.252951 -0.822243))
                                   ((R:segstate.parent.n.name is t)
                                    ((0.410114 -0.810641))
                                    ((0.671047 -0.200886))))
                                  ((name is r_1)
                                   ((R:segstate.parent.pp.ph_vc is +)
                                    ((0.672244 -0.138552))
                                    ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                      <
                                      0.6)
                                     ((0.676191 -0.214434))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                                       is
                                       0)
                                      ((R:segstate.parent.pos_in_syl
                                        is
                                        1)
                                       ((0.353572 -0.415144))
                                       ((0.233316 -0.585462)))
                                      ((0.0644172 -0.671056)))))
                                   ((R:segstate.parent.p.name is y)
                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                                      <
                                      0.1)
                                     ((p.name is y_3)
                                      ((0.922601 0.254943))
                                      ((R:segstate.parent.ph_vheight
                                        is
                                        1)
                                       ((0.196254 -0.590188))
                                       ((0.850574 -0.169458))))
                                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                       is
                                       0)
                                      ((0.569852 -0.384013))
                                      ((R:segstate.parent.ph_vheight
                                        is
                                        3)
                                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                                         is
                                         0)
                                        ((0.183674 -0.731172))
                                        ((0.415796 -0.632109)))
                                       ((0.188882 -0.581272)))))
                                    ((name is ao_2)
                                     ((0.909371 0.248479))
                                     ((R:segstate.parent.n.name is l)
                                      ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                        <
                                        1.1)
                                       ((R:segstate.parent.nn.ph_cplace
                                         is
                                         a)
                                        ((0.459447 -0.257924))
                                        ((R:segstate.parent.nn.ph_cplace
                                          is
                                          0)
                                         ((0.456425 -0.448884))
                                         ((0.127781 -0.714858))))
                                       ((0.772074 -0.0945789)))
                                      ((name is d_2)
                                       ((R:segstate.parent.pp.ph_vrnd
                                         is
                                         -)
                                        ((0.459989 -0.374377))
                                        ((1.13774 0.528558)))
                                       ((R:segstate.parent.n.name is z)
                                        ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                          <
                                          1.8)
                                         ((0.827683 0.439403))
                                         ((0.783379 -0.11814)))
                                        ((R:segstate.parent.p.name
                                          is
                                          g)
                                         ((name is r_2)
                                          ((0.68544 0.296485))
                                          ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                            <
                                            3)
                                           ((0.659742 -0.0236539))
                                           ((0.546189 -0.299907))))
                                         ((R:segstate.parent.pp.ph_vlng
                                           is
                                           s)
                                          ((R:segstate.parent.pp.ph_vfront
                                            is
                                            3)
                                           ((1.06233 0.342102))
                                           ((name is ax_3)
                                            ((0.630481 0.261859))
                                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                              is
                                              0)
                                             ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                               <
                                               1.2)
                                              ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                                                <
                                                5.5)
                                               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                                 is
                                                 0)
                                                ((0.662932 -0.21101))
                                                ((0.367548 -0.524865)))
                                               ((0.195781 -0.572173)))
                                              ((0.574298 -0.140089)))
                                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                               <
                                               1.3)
                                              ((R:segstate.parent.ph_cplace
                                                is
                                                a)
                                               ((0.481267 -0.515107))
                                               ((0.860848 -0.0515313)))
                                              ((1.08011 0.230282))))))
                                          ((p.name is ao_3)
                                           ((0.873892 -0.582532))
                                           ((R:segstate.parent.n.name
                                             is
                                             ey)
                                            ((name is r_2)
                                             ((0.501357 0.247515))
                                             ((0.37461 -0.192278)))
                                            ((p.name is s_3)
                                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                                               <
                                               6.6)
                                              ((0.522371 -0.370823))
                                              ((0.55324 -0.545131)))
                                             ((R:segstate.parent.n.name
                                               is
                                               r)
                                              ((R:segstate.parent.nn.ph_cplace
                                                is
                                                0)
                                               ((1.42497 0.588116))
                                               ((0.506776 -0.295393)))
                                              ((name is t_3)
                                               ((R:segstate.parent.nn.ph_vrnd
                                                 is
                                                 -)
                                                ((0.249864 -0.63424))
                                                ((0.709774 -0.274044)))
                                               ((R:segstate.parent.nn.ph_vrnd
                                                 is
                                                 -)
                                                ((R:segstate.parent.lisp_coda_stop
                                                  is
                                                  0)
                                                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                                                   <
                                                   2.6)
                                                  ((0.962753 0.239866))
                                                  ((R:segstate.parent.pp.ph_cplace
                                                    is
                                                    a)
                                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                                     is
                                                     0)
                                                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                                                      <
                                                      4)
                                                     ((0.867857
                                                       -0.344554))
                                                     ((0.921635
                                                       0.113123)))
                                                    ((1.14972 0.332973)))
                                                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                                     <
                                                     0.3)
                                                    ((0.279615
                                                      -0.481938))
                                                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                                      is
                                                      0)
                                                     ((1.2332
                                                       0.0453619))
                                                     ((0.788092
                                                       -0.246246))))))
                                                 ((R:segstate.parent.R:SylStructure.parent.next_accent
                                                   <
                                                   1.4)
                                                  ((R:segstate.parent.pos_in_syl
                                                    is
                                                    3)
                                                   ((0.665976
                                                     -0.283297))
                                                   ((0.134655
                                                     -0.600794)))
                                                  ((0.821966
                                                    -0.00182194))))
                                                ((R:segstate.parent.n.name
                                                  is
                                                  g)
                                                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                                                   is
                                                   0)
                                                  ((0.810838 -0.177622))
                                                  ((0.701976 0.174512)))
                                                 ((name is eh_1)
                                                  ((0.308862 -0.605659))
                                                  ((name is ao_3)
                                                   ((0.388222
                                                     -0.557491))
                                                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                                                     <
                                                     4.6)
                                                    ((name is ah_3)
                                                     ((1.40358
                                                       0.250353))
                                                     ((R:segstate.parent.pp.ph_cplace
                                                       is
                                                       p)
                                                      ((0.836647
                                                        0.117222))
                                                      ((R:segstate.parent.lisp_onset_fric
                                                        is
                                                        0)
                                                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                                         <
                                                         1.2)
                                                        ((name is r_3)
                                                         ((0.487643
                                                           -0.230228))
                                                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                                                           <
                                                           0.1)
                                                          ((R:segstate.parent.ph_vheight
                                                            is
                                                            2)
                                                           ((0.234165
                                                             -0.488873))
                                                           ((0.241629
                                                             -0.661538)))
                                                          ((R:segstate.parent.pp.ph_ctype
                                                            is
                                                            0)
                                                           ((R:segstate.parent.R:SylStructure.parent.asyl_in
                                                             <
                                                             1.2)
                                                            ((0.569227
                                                              -0.162297))
                                                            ((R:segstate.parent.pp.ph_vrnd
                                                              is
                                                              -)
                                                             ((0.284212
                                                               -0.369938))
                                                             ((0.331996
                                                               -0.497959))))
                                                           ((R:segstate.parent.ph_vrnd
                                                             is
                                                             -)
                                                            ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                                              <
                                                              1.1)
                                                             ((0.51288
                                                               -0.236426))
                                                             ((R:segstate.parent.R:SylStructure.parent.last_accent
                                                               <
                                                               1.2)
                                                              ((0.559326
                                                                -0.321338))
                                                              ((0.332828
                                                                -0.548575))))
                                                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                                              <
                                                              1.1)
                                                             ((0.521405
                                                               -0.415758))
                                                             ((0.313629
                                                               -0.697942)))))))
                                                        ((R:segstate.parent.R:SylStructure.parent.position_type
                                                          is
                                                          final)
                                                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                                                           is
                                                           0)
                                                          ((0.346259
                                                            -0.478766))
                                                          ((0.292525
                                                            -0.350797)))
                                                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                                           is
                                                           0)
                                                          ((R:segstate.parent.R:SylStructure.parent.syl_in
                                                            <
                                                            5.2)
                                                           ((0.445195
                                                             -0.349939))
                                                           ((0.686228
                                                             0.106498)))
                                                          ((R:segstate.parent.pp.ph_cplace
                                                            is
                                                            a)
                                                           ((0.483725
                                                             -0.477109))
                                                           ((R:segstate.parent.pos_in_syl
                                                             is
                                                             1)
                                                            ((0.410551
                                                              -0.341235))
                                                            ((0.554244
                                                              -0.0549756)))))))
                                                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                                         is
                                                         0)
                                                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                                          <
                                                          1.2)
                                                         ((0.65673
                                                           0.114053))
                                                         ((0.679682
                                                           -0.151782)))
                                                        ((0.537552
                                                          -0.355959))))))
                                                    ((R:segstate.parent.pos_in_syl
                                                      is
                                                      2)
                                                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                                                       <
                                                       4.5)
                                                      ((R:segstate.parent.n.name
                                                        is
                                                        d)
                                                       ((0.438003
                                                         -0.11834))
                                                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                                         <
                                                         4.2)
                                                        ((R:segstate.parent.R:SylStructure.parent.next_accent
                                                          <
                                                          2.7)
                                                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                                                           is
                                                           0)
                                                          ((0.340881
                                                            -0.627196))
                                                          ((0.362617
                                                            -0.449048)))
                                                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                                                           is
                                                           0)
                                                          ((0.269427
                                                            -0.496952))
                                                          ((0.476613
                                                            -0.223455))))
                                                        ((0.644038
                                                          -0.236294))))
                                                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                                                        <
                                                        0.1)
                                                       ((0.718461
                                                         0.0729354))
                                                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                                         <
                                                         3.5)
                                                        ((0.546549
                                                          -0.0995204))
                                                        ((0.408178
                                                          -0.396667)))))
                                                     ((R:segstate.parent.p.name
                                                       is
                                                       p)
                                                      ((0.295172
                                                        -0.537209))
                                                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                                                        is
                                                        0)
                                                       ((R:segstate.parent.lisp_onset_fric
                                                         is
                                                         0)
                                                        ((name is ah_2)
                                                         ((0.366956
                                                           -0.281019))
                                                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                                           <
                                                           3.2)
                                                          ((R:segstate.parent.R:SylStructure.parent.position_type
                                                            is
                                                            final)
                                                           ((0.935473
                                                             0.296737))
                                                           ((R:segstate.parent.lisp_coda_fric
                                                             is
                                                             0)
                                                            ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                                                              <
                                                              1.1)
                                                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                                                               <
                                                               9.5)
                                                              ((R:segstate.parent.ph_vheight
                                                                is
                                                                2)
                                                               ((0.691129
                                                                 0.072549))
                                                               ((0.756254
                                                                 -0.0161521)))
                                                              ((0.63606
                                                                -0.240231)))
                                                             ((0.426919
                                                               -0.406341)))
                                                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                                                              <
                                                              8.9)
                                                             ((0.70994
                                                               -0.106596))
                                                             ((1.09727
                                                               0.286482)))))
                                                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                                                            <
                                                            0.1)
                                                           ((0.822736
                                                             -0.109054))
                                                           ((1.61747
                                                             0.66815)))))
                                                        ((0.464849
                                                          -0.339843)))
                                                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                                         <
                                                         1.2)
                                                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                                                          <
                                                          0.1)
                                                         ((0.845442
                                                           0.0272196))
                                                         ((0.489735
                                                           -0.328857)))
                                                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                                                          <
                                                          3.3)
                                                         ((0.373228
                                                           -0.509783))
                                                         ((0.543892
                                                           -0.241477))))))))))))))))))))))))))))))))))))))))))))))
             ((R:segstate.parent.p.ph_vc is +)
              ((name is z_1)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                 <
                 0.3)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  0.9)
                 ((0.525412 0.219511))
                 ((1.14819 0.901719)))
                ((R:segstate.parent.n.name is dh)
                 ((0.784305 0.512364))
                 ((R:segstate.parent.n.name is s)
                  ((0.427963 -0.512623))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                    is
                    0)
                   ((R:segstate.parent.n.name is pau)
                    ((0.405095 -0.0910394))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                      is
                      0)
                     ((0.870311 0.505171))
                     ((0.504337 0.0673041))))
                   ((0.305169 -0.350784))))))
               ((p.name is ah_3)
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  4.4)
                 ((0.822043 -0.12768))
                 ((1.19148 0.458037)))
                ((R:segstate.parent.n.name is s)
                 ((name is z_2)
                  ((0.403455 -0.910392))
                  ((0.518973 -0.478015)))
                 ((name is t_3)
                  ((0.203542 -0.728008))
                  ((R:segstate.parent.n.name is hh)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                     <
                     0.1)
                    ((0.78476 0.0591385))
                    ((0.734119 0.327578)))
                   ((name is z_2)
                    ((R:segstate.parent.nn.ph_cplace is l)
                     ((0.373255 -0.815956))
                     ((R:segstate.parent.nn.ph_vrnd is -)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                        is
                        0)
                       ((0.385375 -0.7303))
                       ((0.562601 -0.399916)))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                        <
                        1.8)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                         <
                         0.2)
                        ((0.674194 0.343775))
                        ((0.570881 -0.189448)))
                       ((0.760373 -0.498183)))))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                      <
                      1.2)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                       <
                       0.3)
                      ((name is z_3)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                         <
                         0.1)
                        ((0.334002 -0.353581))
                        ((0.762247 0.0556898)))
                       ((1.04297 0.436525)))
                      ((R:segstate.parent.nn.ph_cplace is a)
                       ((0.164451 -0.560738))
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         2.7)
                        ((0.782202 0.140489))
                        ((R:segstate.parent.R:SylStructure.parent.next_accent
                          <
                          3)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                           is
                           0)
                          ((R:segstate.parent.R:SylStructure.parent.last_accent
                            <
                            3)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                             <
                             1.2)
                            ((0.462446 -0.439646))
                            ((R:segstate.parent.R:SylStructure.parent.syl_in
                              <
                              2.6)
                             ((0.359436 -0.314043))
                             ((0.766032 -0.0954907))))
                           ((0.222606 -0.589018)))
                          ((0.246193 -0.612547)))
                         ((0.814167 0.0025756))))))
                     ((0.882653 0.681415)))))))))
              ((name is er_1)
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 1.2)
                ((0.595959 -0.157015))
                ((0.564845 0.274812)))
               ((R:segstate.parent.ph_vheight is 1)
                ((p.name is w_3)
                 ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                   is
                   in)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                     is
                     0)
                    ((0.158357 -0.308736))
                    ((0.121402 -0.387501)))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                     <
                     0.2)
                    ((0.126793 -0.394467))
                    ((0.0951951 -0.442107))))
                  ((0.184289 -0.546445)))
                 ((R:segstate.parent.pp.ph_vlng is l)
                  ((0.733942 0.382202))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                     <
                     0.2)
                    ((0.754222 0.146957))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                      <
                      0.1)
                     ((0.432595 -0.383486))
                     ((name is ih_3)
                      ((0.604138 -0.209332))
                      ((0.455059 -0.0601062)))))
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     3.5)
                    ((0.366413 -0.276637))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                      is
                      0)
                     ((0.345712 -0.453142))
                     ((0.203962 -0.51641)))))))
                ((name is ah_3)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   3)
                  ((1.94123 0.640867))
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    7.9)
                   ((0.19026 -0.488626))
                   ((0.398393 -0.236292))))
                 ((R:segstate.parent.n.name is t)
                  ((name is ah_1)
                   ((0.438902 -0.404787))
                   ((0.567624 -0.0471254)))
                  ((R:segstate.parent.pos_in_syl is 1)
                   ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                     <
                     1.1)
                    ((R:segstate.parent.n.seg_onsetcoda is coda)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                       is
                       0)
                      ((0.553312 -0.490583))
                      ((0.657005 -0.198377)))
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       3)
                      ((0.444581 -0.370024))
                      ((0.215731 -0.653642))))
                    ((name is eh_3)
                     ((0.308583 -0.37806))
                     ((R:segstate.parent.n.name is z)
                      ((R:segstate.parent.R:SylStructure.parent.next_accent
                        <
                        2)
                       ((R:segstate.parent.nn.ph_vrnd is -)
                        ((0.190671 -0.549122))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                          <
                          1.9)
                         ((0.0195748 -0.639724))
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           4.5)
                          ((name is aa_1)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                             <
                             0.1)
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              7.4)
                             ((0.0421862 -0.596208))
                             ((0.0331918 -0.607213)))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                              is
                              0)
                             ((1.51657e-07 -0.619791))
                             ((0.0331917 -0.607213))))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                             <
                             0.3)
                            ((0.0927697 -0.608488))
                            ((R:segstate.parent.R:SylStructure.parent.syl_in
                              <
                              1.8)
                             ((0.051148 -0.628481))
                             ((0.022172 -0.653885)))))
                          ((0.204091 -0.554204)))))
                       ((R:segstate.parent.R:SylStructure.parent.asyl_in
                         <
                         1.2)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                          <
                          0.1)
                         ((0.0752473 -0.601279))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                           is
                           0)
                          ((R:segstate.parent.R:SylStructure.parent.asyl_in
                            <
                            0.1)
                           ((0.168564 -0.528051))
                           ((0.115465 -0.603856)))
                          ((name is aa_1)
                           ((0.172715 -0.531749))
                           ((0.352639 -0.38266)))))
                        ((0.0389069 -0.625682))))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                        <
                        0.3)
                       ((R:segstate.parent.p.name is t)
                        ((0.223219 -0.560892))
                        ((0.335184 -0.457367)))
                       ((name is r_1)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                          is
                          0)
                         ((0.264557 -0.551519))
                         ((0.243567 -0.612617)))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                          is
                          0)
                         ((0.224355 -0.846406))
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           1.4)
                          ((0.23863 -0.593824))
                          ((name is r_3)
                           ((0.0915258 -0.654716))
                           ((name is r_2)
                            ((0.161375 -0.750078))
                            ((0.203612 -0.728675)))))))))))
                   ((name is ah_2)
                    ((R:segstate.parent.R:SylStructure.parent.last_accent
                      <
                      1)
                     ((4.37052e-06 -0.766457))
                     ((0.0626695 -0.750275)))
                    ((0.0982403 -0.812277)))))))))))))))))))))
 ((name is n_2)
  ((R:segstate.parent.seg_onsetcoda is coda)
   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
     <
     0.1)
    ((R:segstate.parent.p.ph_vheight is 1)
     ((0.859085 -0.44075))
     ((R:segstate.parent.R:SylStructure.parent.last_accent < 2)
      ((R:segstate.parent.pp.ph_cplace is p)
       ((0.0921848 -1.26432))
       ((R:segstate.parent.p.ph_vheight is 3)
        ((0.144931 -1.24541))
        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
          is
          0)
         ((0.19664 -1.17731))
         ((R:segstate.parent.pp.ph_cplace is l)
          ((0.195257 -1.11856))
          ((0.331446 -0.996434))))))
      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
        is
        0)
       ((0.28159 -1.04962))
       ((0.398154 -0.958613)))))
    ((1.09675 0.0120901)))
   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress is 0)
    ((0.885677 1.04549))
    ((0.737893 -0.315028))))
  ((R:segstate.parent.seg_onsetcoda is coda)
   ((name is r_3)
    ((R:segstate.parent.p.ph_vheight is 3)
     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
       is
       0)
      ((1.31552 0.607818))
      ((0.797751 1.31953)))
     ((1.03259 3.45933)))
    ((R:segstate.parent.ph_ctype is s)
     ((R:segstate.parent.p.ph_vc is +)
      ((name is d_1)
       ((R:segstate.parent.lisp_onset_fric is 0)
        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
          is
          0)
         ((1.29427 0.735463))
         ((0.892378 0.239206)))
        ((2.16564 1.7992)))
       ((R:segstate.parent.p.name is ih)
        ((R:segstate.parent.pos_in_syl is 2)
         ((R:segstate.parent.ph_cplace is a)
          ((1.03542 0.516038))
          ((R:segstate.parent.R:SylStructure.parent.syl_in < 9)
           ((1.0665 0.065694))
           ((0.897206 -0.302051))))
         ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.2)
          ((0.73271 -0.12623))
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
            is
            0)
           ((0.754718 -0.306771))
           ((0.328127 -0.76239)))))
        ((name is k_3)
         ((0.809414 -0.424435))
         ((R:segstate.parent.n.name is pau)
          ((R:segstate.parent.p.name is ae)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
             is
             0)
            ((1.54405 0.0247443))
            ((0.506236 -0.535042)))
           ((R:segstate.parent.pp.ph_ctype is l)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
              is
              0)
             ((0.675008 0.273699))
             ((0.765865 -0.391311)))
            ((R:segstate.parent.pp.ph_ctype is f)
             ((R:segstate.parent.R:SylStructure.parent.last_accent
               <
               1.2)
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 8.5)
               ((0.751617 0.418115))
               ((0.745351 0.0928902)))
              ((0.558594 -0.14469)))
             ((name is t_2)
              ((3.1965 1.36386))
              ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                <
                0.2)
               ((R:segstate.parent.p.ph_vlng is d)
                ((0.859245 0.331028))
                ((1.0437 -0.189792)))
               ((R:segstate.parent.R:SylStructure.parent.position_type
                 is
                 final)
                ((R:segstate.parent.p.name is er)
                 ((0.492036 0.0235119))
                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                   <
                   6.4)
                  ((0.776482 0.195229))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((0.779364 0.300284))
                   ((0.744504 0.567457)))))
                ((R:segstate.parent.p.ph_vlng is l)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                   is
                   0)
                  ((1.12171 0.618593))
                  ((1.02207 0.079424)))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                   <
                   1.2)
                  ((1.36401 0.905401))
                  ((R:segstate.parent.pp.ph_cplace is l)
                   ((0.724335 0.728875))
                   ((0.941123 0.386364)))))))))))
          ((R:segstate.parent.ph_cplace is a)
           ((1.79361 1.33236))
           ((1.63253 0.596085)))))))
      ((R:segstate.parent.p.name is r)
       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
         is
         0)
        ((1.5782 0.790675))
        ((0.81209 0.0223408)))
       ((R:segstate.parent.ph_cplace is a)
        ((name is d_2)
         ((R:segstate.parent.R:SylStructure.parent.syl_in < 11)
          ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.5)
           ((0.307218 -0.541529))
           ((0.136343 -0.649979)))
          ((0.569349 -0.327101)))
         ((name is d_1)
          ((R:segstate.parent.pp.ph_vfront is 1)
           ((0.921583 -0.177556))
           ((R:segstate.parent.lisp_coda_nasal is 0)
            ((8.19635e-06 -0.676287))
            ((0.383808 -0.378749))))
          ((R:segstate.parent.lisp_coda_fric is 0)
           ((R:segstate.parent.pp.ph_vfront is 2)
            ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.6)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.4)
              ((0.720796 0.108413))
              ((0.512261 -0.165497)))
             ((0.610292 0.40393)))
            ((name is d_3)
             ((0.704699 0.139304))
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.3)
              ((0.537696 -0.108732))
              ((0.495045 -0.412202)))))
           ((R:segstate.parent.pos_in_syl is 4)
            ((0.595434 0.190671))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
              <
              1.2)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.6)
              ((0.697501 0.148655))
              ((0.573174 -0.288998)))
             ((R:segstate.parent.nn.ph_vc is 0)
              ((0.210266 -0.702775))
              ((0.777883 -0.300529))))))))
        ((R:segstate.parent.n.name is pau)
         ((0.51922 -0.432046))
         ((0.404199 -0.908849))))))
     ((name is iy_3)
      ((R:segstate.parent.n.name is pau)
       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
         is
         0)
        ((R:segstate.parent.pp.ph_ctype is 0)
         ((1.41193 2.71953))
         ((0.921299 1.86761)))
        ((1.19104 1.41472)))
       ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.6)
        ((0.892373 0.0982777))
        ((1.42919 1.124))))
      ((name is iy_2)
       ((R:segstate.parent.nn.ph_vc is 0)
        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
          is
          0)
         ((0.400797 -0.76567))
         ((R:segstate.parent.pp.ph_vc is +)
          ((0.176985 -0.939601))
          ((0.124444 -0.958831))))
        ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 4)
         ((1.55011 0.662119))
         ((1.08091 -0.336426))))
       ((name is m_2)
        ((R:segstate.parent.R:SylStructure.parent.syl_in < 8)
         ((1.17895 -0.343652))
         ((R:segstate.parent.p.ph_vheight is 2)
          ((0.506913 -0.686522))
          ((0.17029 -0.931617))))
        ((name is ng_2)
         ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.5)
          ((0.192597 -1.11544))
          ((0.377248 -0.897939)))
         ((R:segstate.parent.lisp_coda_glide is 0)
          ((R:segstate.parent.ph_cplace is a)
           ((name is z_1)
            ((R:segstate.parent.pos_in_syl is 2)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.8)
              ((1.58564 0.498879))
              ((1.97438 0.215658)))
             ((0.237397 -0.975025)))
            ((name is s_1)
             ((R:segstate.parent.lisp_coda_stop is 0)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                is
                0)
               ((0.990351 0.743377))
               ((0.752504 0.187768)))
              ((R:segstate.parent.n.name is pau)
               ((0.47484 -0.54629))
               ((1.1126 0.0320204))))
             ((R:segstate.parent.n.name is t)
              ((name is n_3)
               ((0.922973 0.694438))
               ((R:segstate.parent.lisp_coda_fric is 0)
                ((0.576426 -0.128872))
                ((name is s_3)
                 ((1.04528 0.0650469))
                 ((0.93646 0.555789)))))
              ((p.name is ax_3)
               ((R:segstate.parent.pp.ph_cplace is p)
                ((R:segstate.parent.R:SylStructure.parent.syl_in
                  <
                  11.2)
                 ((0.919255 3.01589))
                 ((1.48104 2.10708)))
                ((R:segstate.parent.pp.ph_cplace is a)
                 ((0.922882 0.995064))
                 ((1.18884 1.76629))))
               ((name is n_1)
                ((R:segstate.parent.p.ph_vlng is s)
                 ((p.name is ae_3)
                  ((0.787995 0.609713))
                  ((1.47574 1.14057)))
                 ((R:segstate.parent.pp.ph_cplace is a)
                  ((1.25953 0.205459))
                  ((0.715391 -0.209352))))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                  <
                  0.3)
                 ((name is s_2)
                  ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                    <
                    2.2)
                   ((R:segstate.parent.pos_in_syl is 2)
                    ((0.685542 2.2659))
                    ((0.561913 1.70954)))
                   ((0.9664 1.164)))
                  ((R:segstate.parent.pp.ph_ctype is f)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                     is
                     0)
                    ((1.19907 1.23971))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      9.4)
                     ((1.00436 0.396948))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                       <
                       1.2)
                      ((1.20211 0.851696))
                      ((1.03816 1.33193)))))
                   ((name is z_2)
                    ((R:segstate.parent.p.ph_vheight is 2)
                     ((1.67201 -0.184296))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_in
                       <
                       3.5)
                      ((1.04139 1.57138))
                      ((0.758485 1.74759))))
                    ((R:segstate.parent.p.name is er)
                     ((0.996605 3.94767))
                     ((R:segstate.parent.pp.ph_vfront is 1)
                      ((1.02547 0.618681))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                        <
                        7.8)
                       ((name is n_3)
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          2.4)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                           is
                           0)
                          ((1.32302 1.67886))
                          ((1.25982 0.994056)))
                         ((1.82482 2.70793)))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          2.4)
                         ((1.53617 1.61956))
                         ((R:segstate.parent.pos_in_syl is 3)
                          ((0.972256 1.26423))
                          ((0.642049 0.56588)))))
                       ((R:segstate.parent.lisp_coda_fric is 0)
                        ((0.874623 0.659381))
                        ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                          <
                          2.2)
                         ((1.19957 1.54526))
                         ((0.774685 0.868236))))))))))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   3.6)
                  ((0.812791 -0.115698))
                  ((1.54557 0.645947)))))))))
           ((R:segstate.parent.R:SylStructure.parent.position_type
             is
             final)
            ((name is er_3)
             ((R:segstate.parent.pp.ph_vlng is s)
              ((0.880005 1.04102))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                is
                0)
               ((1.74473 2.13156))
               ((R:segstate.parent.n.name is pau)
                ((1.11863 1.16149))
                ((1.41038 1.84992)))))
             ((name is ax_2)
              ((R:segstate.parent.lisp_onset_nasal is 0)
               ((R:segstate.parent.p.name is sh)
                ((0.614236 -0.120549))
                ((R:segstate.parent.lisp_onset_glide is 0)
                 ((R:segstate.parent.lisp_coda_nasal is 0)
                  ((R:segstate.parent.n.name is d)
                   ((0.928433 1.09679))
                   ((1.63324 1.60829)))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    7.2)
                   ((0.826104 0.422037))
                   ((1.18427 1.27423))))
                 ((1.08149 0.153536))))
               ((1.21804 2.11476)))
              ((R:segstate.parent.ph_vheight is 3)
               ((R:segstate.parent.lisp_coda_nasal is 0)
                ((R:segstate.parent.R:SylStructure.parent.last_accent
                  <
                  1.8)
                 ((1.17406 0.274623))
                 ((1.31122 0.847998)))
                ((R:segstate.parent.pp.ph_vlng is a)
                 ((2.17418 1.53011))
                 ((1.35663 0.983227))))
               ((R:segstate.parent.ph_ctype is r)
                ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                  <
                  2.2)
                 ((R:segstate.parent.pp.ph_cplace is a)
                  ((0.645362 -0.598939))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((1.283 0.329066))
                   ((name is er_1)
                    ((0.962036 -0.322283))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      11.5)
                     ((0.85836 0.0500861))
                     ((1.05779 0.187522))))))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                   <
                   3.5)
                  ((0.728655 -0.464156))
                  ((0.323079 -0.720433))))
                ((p.name is l_3)
                 ((R:segstate.parent.nn.ph_vc is 0)
                  ((0.315996 -0.530998))
                  ((0.965936 -0.143619)))
                 ((R:segstate.parent.lisp_coda_nasal is 0)
                  ((p.name is n_3)
                   ((2.10362 1.49027))
                   ((R:segstate.parent.n.name is t)
                    ((0.834685 -0.136497))
                    ((R:segstate.parent.n.name is z)
                     ((0.768759 -0.163202))
                     ((R:segstate.parent.lisp_onset_glide is 0)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.1)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         6.7)
                        ((R:segstate.parent.p.name is t)
                         ((0.675179 -0.0206507))
                         ((0.933229 0.134525)))
                        ((R:segstate.parent.ph_vrnd is -)
                         ((R:segstate.parent.pp.ph_vfront is 1)
                          ((1.6675 1.00921))
                          ((R:segstate.parent.R:SylStructure.parent.syl_in
                            <
                            12.2)
                           ((0.97915 0.222118))
                           ((1.6304 0.703814))))
                         ((1.22886 0.046288))))
                       ((R:segstate.parent.R:SylStructure.parent.asyl_in
                         <
                         1.4)
                        ((R:segstate.parent.ph_vrnd is -)
                         ((1.98192 1.63561))
                         ((1.4337 0.579487)))
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          7.2)
                         ((0.853399 0.228102))
                         ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                           <
                           1.2)
                          ((1.09233 0.431377))
                          ((R:segstate.parent.R:SylStructure.parent.asyl_in
                            <
                            3.5)
                           ((2.22004 1.34601))
                           ((1.10257 0.741078)))))))
                      ((R:segstate.parent.lisp_coda_fric is 0)
                       ((R:segstate.parent.ph_vrnd is +)
                        ((0.742534 -0.361228))
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          14.5)
                         ((0.902444 0.302184))
                         ((0.577399 -0.2828))))
                       ((R:segstate.parent.pp.ph_cplace is a)
                        ((1.23476 0.770824))
                        ((1.00121 0.390149))))))))
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    2.1)
                   ((R:segstate.parent.ph_vheight is 2)
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      3.1)
                     ((1.30925 0.357385))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       8)
                      ((R:segstate.parent.pos_in_syl is 1)
                       ((R:segstate.parent.pp.ph_ctype is 0)
                        ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                          <
                          3.2)
                         ((R:segstate.parent.p.name is sh)
                          ((0.259074 -0.406165))
                          ((R:segstate.parent.pp.ph_vlng is s)
                           ((0.352475 -0.282476))
                           ((0.703165 0.00267507))))
                         ((1.02154 0.139337)))
                        ((1.31067 0.334461)))
                       ((0.440848 -0.302736)))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                        <
                        8.4)
                       ((0.540472 -0.36379))
                       ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                         <
                         2.2)
                        ((0.298709 -0.293753))
                        ((0.48126 -0.0534173))))))
                    ((name is ih_1)
                     ((0.223241 -0.351159))
                     ((name is ng_1)
                      ((0.70975 -0.263268))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        14.6)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                         is
                         0)
                        ((0.840699 0.109821))
                        ((R:segstate.parent.nn.ph_vc is 0)
                         ((0.579296 0.154546))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                           is
                           0)
                          ((1.07784 0.410822))
                          ((1.20016 1.03612)))))
                       ((1.22012 0.850796))))))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                     <
                     0.1)
                    ((1.40912 0.919935))
                    ((1.04866 0.301604))))))))))
            ((name is ih_1)
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 5.1)
              ((1.42798 0.493348))
              ((R:segstate.parent.lisp_coda_nasal is 0)
               ((0.331203 -0.2812))
               ((0.134651 -0.416121))))
             ((R:segstate.parent.lisp_onset_glide is 0)
              ((name is m_3)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                 is
                 0)
                ((0.291863 -0.360945))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                  <
                  0.1)
                 ((0.42652 -0.213752))
                 ((1.12849 0.482794))))
               ((name is eh_1)
                ((R:segstate.parent.lisp_coda_nasal is 0)
                 ((0.408634 0.117978))
                 ((0.422583 -0.490439)))
                ((R:segstate.parent.n.name is m)
                 ((name is ih_3)
                  ((0.867496 1.24002))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    4.5)
                   ((1.50514 0.921336))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     7)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                      is
                      0)
                     ((1.01835 -0.0272843))
                     ((0.937513 0.472105)))
                    ((0.672008 -0.270779)))))
                 ((name is eh_2)
                  ((1.02039 2.66949))
                  ((R:segstate.parent.ph_vheight is 1)
                   ((R:segstate.parent.lisp_onset_fric is 0)
                    ((name is ih_3)
                     ((1.21562 0.481664))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       5.5)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.3)
                       ((1.74768 1.41923))
                       ((1.91063 2.19222)))
                      ((1.35539 0.932923))))
                    ((R:segstate.parent.pp.ph_ctype is f)
                     ((1.77857 1.12571))
                     ((2.14351 2.58855))))
                   ((name is eh_3)
                    ((0.638963 -0.203369))
                    ((p.name is b_3)
                     ((1.55234 1.97811))
                     ((R:segstate.parent.p.name is ih)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                        is
                        0)
                       ((1.01272 1.39579))
                       ((1.06588 1.70471)))
                      ((R:segstate.parent.n.name is n)
                       ((R:segstate.parent.lisp_onset_nasal is 0)
                        ((R:segstate.parent.lisp_onset_fric is 0)
                         ((R:segstate.parent.R:SylStructure.parent.last_accent
                           <
                           2)
                          ((1.00357 0.628416))
                          ((1.26359 1.13761)))
                         ((1.26684 1.52142)))
                        ((1.48188 1.93805)))
                       ((name is ae_2)
                        ((1.72124 1.66461))
                        ((R:segstate.parent.p.name is dh)
                         ((1.10571 -0.221299))
                         ((R:segstate.parent.p.name is pau)
                          ((R:segstate.parent.R:SylStructure.parent.last_accent
                            <
                            0.8)
                           ((1.55338 2.03026))
                           ((1.21956 0.737064)))
                          ((name is ey_1)
                           ((0.957685 1.27028))
                           ((R:segstate.parent.p.name is n)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                              <
                              0.1)
                             ((1.39682 0.710928))
                             ((1.31113 1.29806)))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                              is
                              0)
                             ((R:segstate.parent.R:SylStructure.parent.sub_phrases
                               <
                               0.2)
                              ((name is ey_3)
                               ((0.988365 0.101629))
                               ((R:segstate.parent.p.name is b)
                                ((1.0317 0.2613))
                                ((R:segstate.parent.R:SylStructure.parent.next_accent
                                  <
                                  0.4)
                                 ((R:segstate.parent.p.ph_vheight is 2)
                                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                                    <
                                    1.1)
                                   ((1.05944 0.567433))
                                   ((1.34212 1.41981)))
                                  ((R:segstate.parent.pos_in_syl is 2)
                                   ((0.759658 0.315946))
                                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                     <
                                     6)
                                    ((R:segstate.parent.pp.ph_vc is +)
                                     ((1.12574 0.62864))
                                     ((1.17796 1.32703)))
                                    ((R:segstate.parent.ph_vrnd is -)
                                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                       <
                                       7.2)
                                      ((1.39138 0.918047))
                                      ((1.1787 0.582589)))
                                     ((1.1978 0.39976))))))
                                 ((R:segstate.parent.p.seg_onsetcoda
                                   is
                                   coda)
                                  ((0.799725 -0.272478))
                                  ((1.17766 0.93932))))))
                              ((1.63168 1.20435)))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                               is
                               0)
                              ((1.2474 0.534863))
                              ((R:segstate.parent.ph_vheight is 2)
                               ((1.19976 0.387719))
                               ((1.01951 0.124867)))))))))))))))))))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                is
                0)
               ((p.name is w_3)
                ((0.941788 1.06939))
                ((R:segstate.parent.ph_vheight is 2)
                 ((R:segstate.parent.n.name is k)
                  ((0.462183 -0.283378))
                  ((R:segstate.parent.p.name is w)
                   ((0.527841 -0.0779205))
                   ((R:segstate.parent.pp.ph_ctype is s)
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      5.1)
                     ((0.863472 0.374237))
                     ((0.818621 0.0140297)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                      is
                      0)
                     ((1.71894 0.484174))
                     ((0.965593 0.668699))))))
                 ((p.name is l_3)
                  ((1.03505 -0.101072))
                  ((name is uw_2)
                   ((0.795781 -0.160888))
                   ((name is uw_1)
                    ((0.694308 -0.0787904))
                    ((R:segstate.parent.ph_vheight is 1)
                     ((R:segstate.parent.lisp_coda_stop is 0)
                      ((1.85258 1.3997))
                      ((1.39805 0.938289)))
                     ((R:segstate.parent.lisp_coda_nasal is 0)
                      ((R:segstate.parent.n.name is t)
                       ((0.775194 0.151105))
                       ((R:segstate.parent.p.name is l)
                        ((1.44715 1.12416))
                        ((R:segstate.parent.pp.ph_ctype is l)
                         ((1.37004 1.11524))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                           is
                           0)
                          ((R:segstate.parent.pos_in_syl is 1)
                           ((1.29886 0.529932))
                           ((1.2422 0.977631)))
                          ((1.11021 0.335768))))))
                      ((R:segstate.parent.n.name is pau)
                       ((1.28162 0.361823))
                       ((0.870155 -0.0454819))))))))))
               ((0.913943 -0.154689)))))))
          ((name is eh_3)
           ((R:segstate.parent.R:SylStructure.parent.syl_codasize
             <
             2.2)
            ((1.67842 0.86836))
            ((1.04265 2.31437)))
           ((name is ao_1)
            ((1.58702 1.37859))
            ((name is z_2)
             ((1.32403 1.5053))
             ((name is r_2)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 4)
               ((0.935703 -0.0574169))
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 11.4)
                ((0.235172 -0.82683))
                ((0.382865 -0.570986))))
              ((name is z_1)
               ((0.0893442 -1.06288))
               ((R:segstate.parent.ph_vrnd is +)
                ((R:segstate.parent.pp.ph_ctype is 0)
                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                   <
                   1.2)
                  ((0.688322 -0.330694))
                  ((0.22029 -0.695892)))
                 ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                   <
                   2.2)
                  ((R:segstate.parent.R:SylStructure.parent.position_type
                    is
                    final)
                   ((1.22137 -0.204154))
                   ((1.24883 0.201429)))
                  ((0.716744 -0.302585))))
                ((R:segstate.parent.p.name is b)
                 ((0.146513 -0.492602))
                 ((R:segstate.parent.p.name is s)
                  ((p.name is s_3)
                   ((1.01284 -0.0228708))
                   ((0.608192 -0.341276)))
                  ((R:segstate.parent.p.name is aa)
                   ((3.17866 1.30483))
                   ((name is r_1)
                    ((p.name is ao_3)
                     ((0.446761 0.158729))
                     ((0.393619 -0.534549)))
                    ((R:segstate.parent.p.name is ao)
                     ((1.35873 -0.186415))
                     ((R:segstate.parent.R:SylStructure.parent.next_accent
                       <
                       1.2)
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        7.7)
                       ((R:segstate.parent.n.name is l)
                        ((1.07702 0.127188))
                        ((R:segstate.parent.p.ph_vheight is 2)
                         ((R:segstate.parent.pp.ph_ctype is f)
                          ((1.26317 0.455881))
                          ((0.897304 0.259045)))
                         ((R:segstate.parent.R:SylStructure.parent.position_type
                           is
                           final)
                          ((1.98013 0.65378))
                          ((R:segstate.parent.n.name is r)
                           ((2.58688 1.42991))
                           ((1.5861 1.06583))))))
                       ((R:segstate.parent.p.name is ow)
                        ((1.64737 0.826383))
                        ((p.name is eh_3)
                         ((0.515291 0.749271))
                         ((R:segstate.parent.R:SylStructure.parent.asyl_in
                           <
                           6)
                          ((R:segstate.parent.pos_in_syl is 2)
                           ((R:segstate.parent.R:SylStructure.parent.syl_in
                             <
                             14)
                            ((R:segstate.parent.p.ph_vc is +)
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                               is
                               0)
                              ((0.853328 0.153968))
                              ((R:segstate.parent.pp.ph_ctype is s)
                               ((1.03665 0.325555))
                               ((1.1508 0.640096))))
                             ((1.92075 0.963893)))
                            ((0.890502 -0.106216)))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                             is
                             0)
                            ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                              <
                              2)
                             ((R:segstate.parent.R:SylStructure.parent.last_accent
                               <
                               5.5)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                                is
                                0)
                               ((R:segstate.parent.R:SylStructure.parent.last_accent
                                 <
                                 3)
                                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                                  <
                                  7)
                                 ((1.90209 0.497564))
                                 ((1.26605 0.143764)))
                                ((1.31715 -0.0335323)))
                               ((1.19397 -0.0240955)))
                              ((1.32058 0.571003)))
                             ((0.726351 -0.234311)))
                            ((0.406689 -0.43551))))
                          ((2.49048 0.820674))))))
                      ((0.797226 -0.190378)))))))))))))))))))))
   ((R:segstate.parent.p.ph_vlng is a)
    ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
      <
      2.2)
     ((R:segstate.parent.lisp_onset_nasal is 0)
      ((R:segstate.parent.ph_ctype is f)
       ((p.name is ax_3)
        ((1.46887 0.885695))
        ((R:segstate.parent.ph_cplace is a)
         ((0.76563 -0.229837))
         ((1.48116 0.42129))))
       ((R:segstate.parent.ph_cplace is a)
        ((R:segstate.parent.ph_ctype is s)
         ((R:segstate.parent.pp.ph_ctype is f)
          ((1.32759 1.12847))
          ((1.43627 1.74358)))
         ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.5)
          ((1.30994 0.338772))
          ((R:segstate.parent.pp.ph_cplace is d)
           ((1.70906 0.691055))
           ((1.00295 0.816999)))))
        ((p.name is ax_3)
         ((R:segstate.parent.nn.ph_cplace is a)
          ((0.964147 1.14377))
          ((1.30761 1.02406)))
         ((R:segstate.parent.pp.ph_ctype is s)
          ((R:segstate.parent.nn.ph_cplace is a)
           ((1.23636 0.106856))
           ((0.942231 0.386454)))
          ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 2.2)
           ((R:segstate.parent.R:SylStructure.parent.last_accent < 3)
            ((R:segstate.parent.R:SylStructure.parent.last_accent
              <
              1.2)
             ((0.99743 0.557491))
             ((0.606713 0.356771)))
            ((1.64758 1.16899)))
           ((0.835831 0.249644)))))))
      ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.2)
       ((0.878159 -0.0748626))
       ((1.09963 0.161865))))
     ((R:segstate.parent.pp.ph_ctype is l)
      ((0.678696 -0.224696))
      ((R:segstate.parent.lisp_coda_stop is 0)
       ((R:segstate.parent.lisp_onset_glide is 0)
        ((R:segstate.parent.ph_ctype is f)
         ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.2)
          ((0.818813 0.302774))
          ((0.797195 0.0876505)))
         ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
           <
           3.1)
          ((R:segstate.parent.R:SylStructure.parent.syl_in < 11)
           ((0.619504 -0.38977))
           ((0.738762 -0.180095)))
          ((0.744027 -0.0102458))))
        ((R:segstate.parent.pp.ph_ctype is f)
         ((0.780571 0.219301))
         ((0.70401 0.360422))))
       ((R:segstate.parent.R:SylStructure.parent.syl_in < 14.8)
        ((1.01557 0.562733))
        ((0.907744 0.0683497))))))
    ((name is hh_2)
     ((R:segstate.parent.n.name is ih)
      ((1.79769 1.48113))
      ((1.13317 0.0678979)))
     ((R:segstate.parent.p.name is r)
      ((R:segstate.parent.R:SylStructure.parent.sub_phrases < 0.1)
       ((R:segstate.parent.R:SylStructure.parent.position_type
         is
         final)
        ((1.63234 0.362608))
        ((R:segstate.parent.pp.ph_vrnd is +)
         ((2.72202 1.71014))
         ((1.1659 0.561527))))
       ((1.05342 0.0103494)))
      ((name is l_3)
       ((R:segstate.parent.n.name is iy)
        ((0.726962 1.22912))
        ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 2)
         ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize < 1.1)
          ((R:segstate.parent.pp.ph_ctype is f)
           ((0.700304 -0.28752))
           ((1.00024 -0.157456)))
          ((0.930169 0.369896)))
         ((0.820706 1.0283))))
       ((R:segstate.parent.p.name is l)
        ((p.name is l_3)
         ((1.00247 -0.0977117))
         ((R:segstate.parent.ph_cplace is a)
          ((1.98525 1.24197))
          ((1.19173 0.558809))))
        ((p.name is ng_3)
         ((0.530303 -0.763097))
         ((R:segstate.parent.pos_in_syl is 0)
          ((R:segstate.parent.lisp_onset_glide is 0)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
             is
             0)
            ((name is t_3)
             ((1.32995 1.10014))
             ((p.name is d_3)
              ((0.410428 -0.618752))
              ((R:segstate.parent.ph_cplace is d)
               ((name is dh_1)
                ((1.17242 0.166462))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                  <
                  0.1)
                 ((0.556824 -0.116848))
                 ((name is dh_3)
                  ((0.262724 -0.311013))
                  ((0.340243 -0.663633)))))
               ((p.name is pau_5)
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  1.2)
                 ((0.368096 -0.582417))
                 ((0.830122 -0.188542)))
                ((R:segstate.parent.p.name is d)
                 ((1.2928 0.747521))
                 ((name is d_3)
                  ((1.7272 0.860114))
                  ((name is s_1)
                   ((1.17328 0.590424))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     3.3)
                    ((R:segstate.parent.pp.ph_vfront is 1)
                     ((0.637062 -0.366264))
                     ((R:segstate.parent.lisp_coda_nasal is 0)
                      ((R:segstate.parent.ph_ctype is n)
                       ((0.526182 -0.284819))
                       ((R:segstate.parent.ph_cplace is a)
                        ((0.993282 0.488476))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                          is
                          0)
                         ((0.748491 0.138935))
                         ((0.647244 -0.137099)))))
                      ((R:segstate.parent.lisp_onset_stop is 0)
                       ((0.47728 -0.0528968))
                       ((0.660316 -0.265134)))))
                    ((R:segstate.parent.ph_cplace is a)
                     ((R:segstate.parent.ph_ctype is n)
                      ((0.393112 -0.344325))
                      ((R:segstate.parent.pp.ph_ctype is r)
                       ((0.732104 0.398144))
                       ((R:segstate.parent.R:SylStructure.parent.asyl_in
                         <
                         2.2)
                        ((0.880063 -0.373315))
                        ((R:segstate.parent.nn.ph_cplace is a)
                         ((0.740075 -0.112602))
                         ((0.979397 0.265818))))))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       6.1)
                      ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                        <
                        2.2)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.stress
                         is
                         0)
                        ((R:segstate.parent.nn.ph_cplace is a)
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           5.2)
                          ((1.22564 0.546017))
                          ((2.88429 1.13896)))
                         ((1.01829 0.272414)))
                        ((1.01141 0.135234)))
                       ((R:segstate.parent.lisp_coda_fric is 0)
                        ((1.20969 0.275547))
                        ((0.974974 0.0165234))))
                      ((R:segstate.parent.R:SylStructure.parent.asyl_in
                        <
                        5.2)
                       ((R:segstate.parent.n.name is iy)
                        ((1.1829 -0.280186))
                        ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                          <
                          2.2)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                           <
                           1.1)
                          ((0.658706 -0.0262807))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.stress
                            is
                            0)
                           ((1.02891 0.149283))
                           ((1.0216 0.544506))))
                         ((0.632653 -0.0660629))))
                       ((0.825932 -0.24103)))))))))))))
            ((R:segstate.parent.ph_cplace is d)
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 9.5)
              ((0.770918 0.00484293))
              ((1.34246 0.713486)))
             ((name is sh_3)
              ((0.827622 0.347643))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 9.1)
               ((name is sh_1)
                ((0.261495 -0.527266))
                ((R:segstate.parent.pp.ph_ctype is s)
                 ((R:segstate.parent.p.ph_vheight is 2)
                  ((0.527938 -0.189927))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    8.5)
                   ((0.739652 0.0415788))
                   ((1.1938 0.326535))))
                 ((R:segstate.parent.lisp_onset_stop is 0)
                  ((name is s_1)
                   ((1.2401 0.43712))
                   ((R:segstate.parent.ph_cplace is b)
                    ((0.550762 -0.450617))
                    ((R:segstate.parent.p.name is n)
                     ((0.532074 -0.491054))
                     ((R:segstate.parent.R:SylStructure.parent.sub_phrases
                       <
                       0.2)
                      ((R:segstate.parent.p.ph_vheight is 2)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         10.8)
                        ((0.749254 -0.176803))
                        ((0.612062 -0.129987)))
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         10)
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          2.2)
                         ((1.15742 0.120537))
                         ((0.583672 -0.206444)))
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          11.4)
                         ((1.12875 0.435419))
                         ((0.787171 0.0246547)))))
                      ((0.822063 -0.321447))))))
                  ((R:segstate.parent.ph_cplace is l)
                   ((R:segstate.parent.nn.ph_cplace is a)
                    ((0.680501 -0.172369))
                    ((0.824327 0.0302024)))
                   ((R:segstate.parent.p.ph_vheight is 2)
                    ((R:segstate.parent.p.name is ey)
                     ((0.287215 -0.575957))
                     ((0.338 -0.421294)))
                    ((R:segstate.parent.pp.ph_vrnd is -)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       9.5)
                      ((0.701188 -0.257988))
                      ((0.827266 -0.0924693)))
                     ((R:segstate.parent.p.ph_vheight is 3)
                      ((0.549105 -0.204814))
                      ((R:segstate.parent.lisp_coda_nasal is 0)
                       ((0.407031 -0.497575))
                       ((0.452809 -0.331474))))))))))
               ((R:segstate.parent.p.ph_vheight is 2)
                ((0.558517 -0.17786))
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  5.1)
                 ((R:segstate.parent.ph_ctype is s)
                  ((0.753503 0.0512666))
                  ((1.32753 0.322314)))
                 ((0.809478 -0.102607))))))))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
             <
             1.2)
            ((name is l_1)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.6)
              ((1.99048 1.50113))
              ((1.32861 0.638998)))
             ((R:segstate.parent.ph_cplace is a)
              ((R:segstate.parent.ph_ctype is r)
               ((R:segstate.parent.p.ph_vlng is l)
                ((1.03149 -0.182849))
                ((1.48606 0.496818)))
               ((R:segstate.parent.p.ph_vheight is 1)
                ((0.787133 0.0968587))
                ((0.8802 -0.408081))))
              ((R:segstate.parent.ph_ctype is s)
               ((R:segstate.parent.R:SylStructure.parent.last_accent
                 <
                 2)
                ((1.10935 0.322302))
                ((0.757088 0.750402)))
               ((R:segstate.parent.R:SylStructure.parent.sub_phrases
                 <
                 0.1)
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  2.1)
                 ((1.02407 -0.0325369))
                 ((1.3885 0.439642)))
                ((0.797183 0.398975))))))
            ((name is l_1)
             ((0.256807 -0.543923))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
               <
               0.3)
              ((R:segstate.parent.pp.ph_cplace is a)
               ((1.1928 0.121102))
               ((0.454137 -0.490444)))
              ((R:segstate.parent.R:SylStructure.parent.sub_phrases
                <
                0.2)
               ((R:segstate.parent.nn.ph_vlng is s)
                ((0.988386 -0.139409))
                ((R:segstate.parent.ph_ctype is f)
                 ((0.818235 -0.0417273))
                 ((R:segstate.parent.pp.ph_ctype is s)
                  ((0.840866 0.219623))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    7.3)
                   ((R:segstate.parent.ph_ctype is r)
                    ((0.774153 0.164408))
                    ((1.46741 0.678028)))
                   ((1.02509 0.861855))))))
               ((R:segstate.parent.ph_ctype is r)
                ((0.749622 0.0916315))
                ((0.743633 -0.304807))))))))
          ((name is l_1)
           ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5)
            ((0.0622595 -0.694295))
            ((0.0529102 -0.704319)))
           ((R:segstate.parent.p.name is g)
            ((0.828176 0.27867))
            ((name is t_3)
             ((0.265066 -0.348801))
             ((R:segstate.parent.lisp_onset_fric is 0)
              ((name is r_1)
               ((0.639146 0.159061))
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 5)
                ((0.359214 -0.589781))
                ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                  <
                  2.2)
                 ((R:segstate.parent.R:SylStructure.parent.position_type
                   is
                   final)
                  ((0.354289 -0.508807))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                    <
                    1.2)
                   ((0.422257 -0.346227))
                   ((0.871744 0.0052117))))
                 ((0.802231 0.00771674)))))
              ((p.name is s_3)
               ((R:segstate.parent.nn.ph_cplace is a)
                ((0.5876 0.0909203))
                ((0.543126 -0.537014)))
               ((R:segstate.parent.n.seg_onsetcoda is coda)
                ((R:segstate.parent.lisp_coda_glide is 0)
                 ((R:segstate.parent.ph_cplace is a)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                    <
                    0.3)
                   ((0.341585 -0.357306))
                   ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                     <
                     2.1)
                    ((0.542114 -0.282456))
                    ((0.634747 -0.0515382))))
                  ((0.838514 0.0463662)))
                 ((0.893405 0.22915)))
                ((1.67809 0.811233))))))))))))))))))
)
)


(provide 'cmu_us_bdl_dur)


